_rc() {
    local i cur prev opts cmd
    COMPREPLY=()
    if [[ "${BASH_VERSINFO[0]}" -ge 4 ]]; then
        cur="$2"
    else
        cur="${COMP_WORDS[COMP_CWORD]}"
    fi
    prev="$3"
    cmd=""
    opts=""

    for i in "${COMP_WORDS[@]:0:COMP_CWORD}"
    do
        case "${cmd},${i}" in
            ",$1")
                cmd="rc"
                ;;
            rc,admin)
                cmd="rc__subcmd__admin"
                ;;
            rc,alias)
                cmd="rc__subcmd__alias"
                ;;
            rc,anonymous)
                cmd="rc__subcmd__anonymous"
                ;;
            rc,bucket)
                cmd="rc__subcmd__bucket"
                ;;
            rc,cat)
                cmd="rc__subcmd__cat"
                ;;
            rc,completions)
                cmd="rc__subcmd__completions"
                ;;
            rc,cors)
                cmd="rc__subcmd__cors"
                ;;
            rc,cp)
                cmd="rc__subcmd__cp"
                ;;
            rc,diff)
                cmd="rc__subcmd__diff"
                ;;
            rc,event)
                cmd="rc__subcmd__event"
                ;;
            rc,find)
                cmd="rc__subcmd__find"
                ;;
            rc,head)
                cmd="rc__subcmd__head"
                ;;
            rc,help)
                cmd="rc__subcmd__help"
                ;;
            rc,ilm)
                cmd="rc__subcmd__ilm"
                ;;
            rc,ls)
                cmd="rc__subcmd__ls"
                ;;
            rc,mb)
                cmd="rc__subcmd__mb"
                ;;
            rc,mirror)
                cmd="rc__subcmd__mirror"
                ;;
            rc,mv)
                cmd="rc__subcmd__mv"
                ;;
            rc,object)
                cmd="rc__subcmd__object"
                ;;
            rc,pipe)
                cmd="rc__subcmd__pipe"
                ;;
            rc,quota)
                cmd="rc__subcmd__quota"
                ;;
            rc,rb)
                cmd="rc__subcmd__rb"
                ;;
            rc,replicate)
                cmd="rc__subcmd__replicate"
                ;;
            rc,rm)
                cmd="rc__subcmd__rm"
                ;;
            rc,share)
                cmd="rc__subcmd__share"
                ;;
            rc,sql)
                cmd="rc__subcmd__sql"
                ;;
            rc,stat)
                cmd="rc__subcmd__stat"
                ;;
            rc,tag)
                cmd="rc__subcmd__tag"
                ;;
            rc,tree)
                cmd="rc__subcmd__tree"
                ;;
            rc,version)
                cmd="rc__subcmd__version"
                ;;
            rc__subcmd__admin,access-key)
                cmd="rc__subcmd__admin__subcmd__access__subcmd__key"
                ;;
            rc__subcmd__admin,decommission)
                cmd="rc__subcmd__admin__subcmd__decommission"
                ;;
            rc__subcmd__admin,expand)
                cmd="rc__subcmd__admin__subcmd__expand"
                ;;
            rc__subcmd__admin,group)
                cmd="rc__subcmd__admin__subcmd__group"
                ;;
            rc__subcmd__admin,heal)
                cmd="rc__subcmd__admin__subcmd__heal"
                ;;
            rc__subcmd__admin,help)
                cmd="rc__subcmd__admin__subcmd__help"
                ;;
            rc__subcmd__admin,info)
                cmd="rc__subcmd__admin__subcmd__info"
                ;;
            rc__subcmd__admin,policy)
                cmd="rc__subcmd__admin__subcmd__policy"
                ;;
            rc__subcmd__admin,pool)
                cmd="rc__subcmd__admin__subcmd__pool"
                ;;
            rc__subcmd__admin,rebalance)
                cmd="rc__subcmd__admin__subcmd__rebalance"
                ;;
            rc__subcmd__admin,replicate)
                cmd="rc__subcmd__admin__subcmd__replicate"
                ;;
            rc__subcmd__admin,service)
                cmd="rc__subcmd__admin__subcmd__service"
                ;;
            rc__subcmd__admin,service-account)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__account"
                ;;
            rc__subcmd__admin,user)
                cmd="rc__subcmd__admin__subcmd__user"
                ;;
            rc__subcmd__admin__subcmd__access__subcmd__key,help)
                cmd="rc__subcmd__admin__subcmd__access__subcmd__key__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__access__subcmd__key,info)
                cmd="rc__subcmd__admin__subcmd__access__subcmd__key__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__access__subcmd__key__subcmd__help,help)
                cmd="rc__subcmd__admin__subcmd__access__subcmd__key__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__access__subcmd__key__subcmd__help,info)
                cmd="rc__subcmd__admin__subcmd__access__subcmd__key__subcmd__help__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__decommission,cancel)
                cmd="rc__subcmd__admin__subcmd__decommission__subcmd__cancel"
                ;;
            rc__subcmd__admin__subcmd__decommission,clear)
                cmd="rc__subcmd__admin__subcmd__decommission__subcmd__clear"
                ;;
            rc__subcmd__admin__subcmd__decommission,help)
                cmd="rc__subcmd__admin__subcmd__decommission__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__decommission,start)
                cmd="rc__subcmd__admin__subcmd__decommission__subcmd__start"
                ;;
            rc__subcmd__admin__subcmd__decommission,status)
                cmd="rc__subcmd__admin__subcmd__decommission__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__decommission__subcmd__help,cancel)
                cmd="rc__subcmd__admin__subcmd__decommission__subcmd__help__subcmd__cancel"
                ;;
            rc__subcmd__admin__subcmd__decommission__subcmd__help,clear)
                cmd="rc__subcmd__admin__subcmd__decommission__subcmd__help__subcmd__clear"
                ;;
            rc__subcmd__admin__subcmd__decommission__subcmd__help,help)
                cmd="rc__subcmd__admin__subcmd__decommission__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__decommission__subcmd__help,start)
                cmd="rc__subcmd__admin__subcmd__decommission__subcmd__help__subcmd__start"
                ;;
            rc__subcmd__admin__subcmd__decommission__subcmd__help,status)
                cmd="rc__subcmd__admin__subcmd__decommission__subcmd__help__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__expand,help)
                cmd="rc__subcmd__admin__subcmd__expand__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__expand,start)
                cmd="rc__subcmd__admin__subcmd__expand__subcmd__start"
                ;;
            rc__subcmd__admin__subcmd__expand,status)
                cmd="rc__subcmd__admin__subcmd__expand__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__expand,stop)
                cmd="rc__subcmd__admin__subcmd__expand__subcmd__stop"
                ;;
            rc__subcmd__admin__subcmd__expand__subcmd__help,help)
                cmd="rc__subcmd__admin__subcmd__expand__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__expand__subcmd__help,start)
                cmd="rc__subcmd__admin__subcmd__expand__subcmd__help__subcmd__start"
                ;;
            rc__subcmd__admin__subcmd__expand__subcmd__help,status)
                cmd="rc__subcmd__admin__subcmd__expand__subcmd__help__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__expand__subcmd__help,stop)
                cmd="rc__subcmd__admin__subcmd__expand__subcmd__help__subcmd__stop"
                ;;
            rc__subcmd__admin__subcmd__group,add)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__add"
                ;;
            rc__subcmd__admin__subcmd__group,add-members)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__add__subcmd__members"
                ;;
            rc__subcmd__admin__subcmd__group,disable)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__disable"
                ;;
            rc__subcmd__admin__subcmd__group,enable)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__enable"
                ;;
            rc__subcmd__admin__subcmd__group,help)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__group,info)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__group,ls)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__ls"
                ;;
            rc__subcmd__admin__subcmd__group,rm)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__rm"
                ;;
            rc__subcmd__admin__subcmd__group,rm-members)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__rm__subcmd__members"
                ;;
            rc__subcmd__admin__subcmd__group__subcmd__help,add)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__add"
                ;;
            rc__subcmd__admin__subcmd__group__subcmd__help,add-members)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__add__subcmd__members"
                ;;
            rc__subcmd__admin__subcmd__group__subcmd__help,disable)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__disable"
                ;;
            rc__subcmd__admin__subcmd__group__subcmd__help,enable)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__enable"
                ;;
            rc__subcmd__admin__subcmd__group__subcmd__help,help)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__group__subcmd__help,info)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__group__subcmd__help,ls)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__ls"
                ;;
            rc__subcmd__admin__subcmd__group__subcmd__help,rm)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__rm"
                ;;
            rc__subcmd__admin__subcmd__group__subcmd__help,rm-members)
                cmd="rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__rm__subcmd__members"
                ;;
            rc__subcmd__admin__subcmd__heal,help)
                cmd="rc__subcmd__admin__subcmd__heal__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__heal,start)
                cmd="rc__subcmd__admin__subcmd__heal__subcmd__start"
                ;;
            rc__subcmd__admin__subcmd__heal,status)
                cmd="rc__subcmd__admin__subcmd__heal__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__heal,stop)
                cmd="rc__subcmd__admin__subcmd__heal__subcmd__stop"
                ;;
            rc__subcmd__admin__subcmd__heal__subcmd__help,help)
                cmd="rc__subcmd__admin__subcmd__heal__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__heal__subcmd__help,start)
                cmd="rc__subcmd__admin__subcmd__heal__subcmd__help__subcmd__start"
                ;;
            rc__subcmd__admin__subcmd__heal__subcmd__help,status)
                cmd="rc__subcmd__admin__subcmd__heal__subcmd__help__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__heal__subcmd__help,stop)
                cmd="rc__subcmd__admin__subcmd__heal__subcmd__help__subcmd__stop"
                ;;
            rc__subcmd__admin__subcmd__help,access-key)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__access__subcmd__key"
                ;;
            rc__subcmd__admin__subcmd__help,decommission)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__decommission"
                ;;
            rc__subcmd__admin__subcmd__help,expand)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__expand"
                ;;
            rc__subcmd__admin__subcmd__help,group)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__group"
                ;;
            rc__subcmd__admin__subcmd__help,heal)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__heal"
                ;;
            rc__subcmd__admin__subcmd__help,help)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__help,info)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__help,policy)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__policy"
                ;;
            rc__subcmd__admin__subcmd__help,pool)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__pool"
                ;;
            rc__subcmd__admin__subcmd__help,rebalance)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__rebalance"
                ;;
            rc__subcmd__admin__subcmd__help,replicate)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__replicate"
                ;;
            rc__subcmd__admin__subcmd__help,service)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__service"
                ;;
            rc__subcmd__admin__subcmd__help,service-account)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__account"
                ;;
            rc__subcmd__admin__subcmd__help,user)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__user"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__access__subcmd__key,info)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__access__subcmd__key__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__decommission,cancel)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__decommission__subcmd__cancel"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__decommission,clear)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__decommission__subcmd__clear"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__decommission,start)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__decommission__subcmd__start"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__decommission,status)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__decommission__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__expand,start)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__expand__subcmd__start"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__expand,status)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__expand__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__expand,stop)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__expand__subcmd__stop"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__group,add)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__add"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__group,add-members)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__add__subcmd__members"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__group,disable)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__disable"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__group,enable)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__enable"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__group,info)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__group,ls)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__ls"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__group,rm)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__rm"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__group,rm-members)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__rm__subcmd__members"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__heal,start)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__heal__subcmd__start"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__heal,status)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__heal__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__heal,stop)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__heal__subcmd__stop"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__info,cluster)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__info__subcmd__cluster"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__info,disk)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__info__subcmd__disk"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__info,server)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__info__subcmd__server"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__policy,attach)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__policy__subcmd__attach"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__policy,create)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__policy__subcmd__create"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__policy,info)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__policy__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__policy,ls)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__policy__subcmd__ls"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__policy,rm)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__policy__subcmd__rm"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__pool,list)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__pool__subcmd__list"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__pool,status)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__pool__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__rebalance,start)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__rebalance__subcmd__start"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__rebalance,status)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__rebalance__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__rebalance,stop)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__rebalance__subcmd__stop"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__replicate,add)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__replicate__subcmd__add"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__replicate,info)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__replicate__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__replicate,remove)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__replicate__subcmd__remove"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__replicate,status)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__replicate__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__service,freeze)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__freeze"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__service,restart)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__restart"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__service,stop)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__stop"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__service,unfreeze)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__unfreeze"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__account,create)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__account__subcmd__create"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__account,info)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__account__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__account,ls)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__account__subcmd__ls"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__account,rm)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__account__subcmd__rm"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__user,add)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__user__subcmd__add"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__user,disable)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__user__subcmd__disable"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__user,enable)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__user__subcmd__enable"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__user,info)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__user__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__user,ls)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__user__subcmd__ls"
                ;;
            rc__subcmd__admin__subcmd__help__subcmd__user,rm)
                cmd="rc__subcmd__admin__subcmd__help__subcmd__user__subcmd__rm"
                ;;
            rc__subcmd__admin__subcmd__info,cluster)
                cmd="rc__subcmd__admin__subcmd__info__subcmd__cluster"
                ;;
            rc__subcmd__admin__subcmd__info,disk)
                cmd="rc__subcmd__admin__subcmd__info__subcmd__disk"
                ;;
            rc__subcmd__admin__subcmd__info,help)
                cmd="rc__subcmd__admin__subcmd__info__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__info,server)
                cmd="rc__subcmd__admin__subcmd__info__subcmd__server"
                ;;
            rc__subcmd__admin__subcmd__info__subcmd__help,cluster)
                cmd="rc__subcmd__admin__subcmd__info__subcmd__help__subcmd__cluster"
                ;;
            rc__subcmd__admin__subcmd__info__subcmd__help,disk)
                cmd="rc__subcmd__admin__subcmd__info__subcmd__help__subcmd__disk"
                ;;
            rc__subcmd__admin__subcmd__info__subcmd__help,help)
                cmd="rc__subcmd__admin__subcmd__info__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__info__subcmd__help,server)
                cmd="rc__subcmd__admin__subcmd__info__subcmd__help__subcmd__server"
                ;;
            rc__subcmd__admin__subcmd__policy,attach)
                cmd="rc__subcmd__admin__subcmd__policy__subcmd__attach"
                ;;
            rc__subcmd__admin__subcmd__policy,create)
                cmd="rc__subcmd__admin__subcmd__policy__subcmd__create"
                ;;
            rc__subcmd__admin__subcmd__policy,help)
                cmd="rc__subcmd__admin__subcmd__policy__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__policy,info)
                cmd="rc__subcmd__admin__subcmd__policy__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__policy,ls)
                cmd="rc__subcmd__admin__subcmd__policy__subcmd__ls"
                ;;
            rc__subcmd__admin__subcmd__policy,rm)
                cmd="rc__subcmd__admin__subcmd__policy__subcmd__rm"
                ;;
            rc__subcmd__admin__subcmd__policy__subcmd__help,attach)
                cmd="rc__subcmd__admin__subcmd__policy__subcmd__help__subcmd__attach"
                ;;
            rc__subcmd__admin__subcmd__policy__subcmd__help,create)
                cmd="rc__subcmd__admin__subcmd__policy__subcmd__help__subcmd__create"
                ;;
            rc__subcmd__admin__subcmd__policy__subcmd__help,help)
                cmd="rc__subcmd__admin__subcmd__policy__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__policy__subcmd__help,info)
                cmd="rc__subcmd__admin__subcmd__policy__subcmd__help__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__policy__subcmd__help,ls)
                cmd="rc__subcmd__admin__subcmd__policy__subcmd__help__subcmd__ls"
                ;;
            rc__subcmd__admin__subcmd__policy__subcmd__help,rm)
                cmd="rc__subcmd__admin__subcmd__policy__subcmd__help__subcmd__rm"
                ;;
            rc__subcmd__admin__subcmd__pool,help)
                cmd="rc__subcmd__admin__subcmd__pool__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__pool,list)
                cmd="rc__subcmd__admin__subcmd__pool__subcmd__list"
                ;;
            rc__subcmd__admin__subcmd__pool,status)
                cmd="rc__subcmd__admin__subcmd__pool__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__pool__subcmd__help,help)
                cmd="rc__subcmd__admin__subcmd__pool__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__pool__subcmd__help,list)
                cmd="rc__subcmd__admin__subcmd__pool__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__admin__subcmd__pool__subcmd__help,status)
                cmd="rc__subcmd__admin__subcmd__pool__subcmd__help__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__rebalance,help)
                cmd="rc__subcmd__admin__subcmd__rebalance__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__rebalance,start)
                cmd="rc__subcmd__admin__subcmd__rebalance__subcmd__start"
                ;;
            rc__subcmd__admin__subcmd__rebalance,status)
                cmd="rc__subcmd__admin__subcmd__rebalance__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__rebalance,stop)
                cmd="rc__subcmd__admin__subcmd__rebalance__subcmd__stop"
                ;;
            rc__subcmd__admin__subcmd__rebalance__subcmd__help,help)
                cmd="rc__subcmd__admin__subcmd__rebalance__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__rebalance__subcmd__help,start)
                cmd="rc__subcmd__admin__subcmd__rebalance__subcmd__help__subcmd__start"
                ;;
            rc__subcmd__admin__subcmd__rebalance__subcmd__help,status)
                cmd="rc__subcmd__admin__subcmd__rebalance__subcmd__help__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__rebalance__subcmd__help,stop)
                cmd="rc__subcmd__admin__subcmd__rebalance__subcmd__help__subcmd__stop"
                ;;
            rc__subcmd__admin__subcmd__replicate,add)
                cmd="rc__subcmd__admin__subcmd__replicate__subcmd__add"
                ;;
            rc__subcmd__admin__subcmd__replicate,help)
                cmd="rc__subcmd__admin__subcmd__replicate__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__replicate,info)
                cmd="rc__subcmd__admin__subcmd__replicate__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__replicate,remove)
                cmd="rc__subcmd__admin__subcmd__replicate__subcmd__remove"
                ;;
            rc__subcmd__admin__subcmd__replicate,status)
                cmd="rc__subcmd__admin__subcmd__replicate__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__replicate__subcmd__help,add)
                cmd="rc__subcmd__admin__subcmd__replicate__subcmd__help__subcmd__add"
                ;;
            rc__subcmd__admin__subcmd__replicate__subcmd__help,help)
                cmd="rc__subcmd__admin__subcmd__replicate__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__replicate__subcmd__help,info)
                cmd="rc__subcmd__admin__subcmd__replicate__subcmd__help__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__replicate__subcmd__help,remove)
                cmd="rc__subcmd__admin__subcmd__replicate__subcmd__help__subcmd__remove"
                ;;
            rc__subcmd__admin__subcmd__replicate__subcmd__help,status)
                cmd="rc__subcmd__admin__subcmd__replicate__subcmd__help__subcmd__status"
                ;;
            rc__subcmd__admin__subcmd__service,freeze)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__freeze"
                ;;
            rc__subcmd__admin__subcmd__service,help)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__service,restart)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__restart"
                ;;
            rc__subcmd__admin__subcmd__service,stop)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__stop"
                ;;
            rc__subcmd__admin__subcmd__service,unfreeze)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__unfreeze"
                ;;
            rc__subcmd__admin__subcmd__service__subcmd__account,create)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__create"
                ;;
            rc__subcmd__admin__subcmd__service__subcmd__account,help)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__service__subcmd__account,info)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__service__subcmd__account,ls)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__ls"
                ;;
            rc__subcmd__admin__subcmd__service__subcmd__account,rm)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__rm"
                ;;
            rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help,create)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help__subcmd__create"
                ;;
            rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help,help)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help,info)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help,ls)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help__subcmd__ls"
                ;;
            rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help,rm)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help__subcmd__rm"
                ;;
            rc__subcmd__admin__subcmd__service__subcmd__help,freeze)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__help__subcmd__freeze"
                ;;
            rc__subcmd__admin__subcmd__service__subcmd__help,help)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__service__subcmd__help,restart)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__help__subcmd__restart"
                ;;
            rc__subcmd__admin__subcmd__service__subcmd__help,stop)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__help__subcmd__stop"
                ;;
            rc__subcmd__admin__subcmd__service__subcmd__help,unfreeze)
                cmd="rc__subcmd__admin__subcmd__service__subcmd__help__subcmd__unfreeze"
                ;;
            rc__subcmd__admin__subcmd__user,add)
                cmd="rc__subcmd__admin__subcmd__user__subcmd__add"
                ;;
            rc__subcmd__admin__subcmd__user,disable)
                cmd="rc__subcmd__admin__subcmd__user__subcmd__disable"
                ;;
            rc__subcmd__admin__subcmd__user,enable)
                cmd="rc__subcmd__admin__subcmd__user__subcmd__enable"
                ;;
            rc__subcmd__admin__subcmd__user,help)
                cmd="rc__subcmd__admin__subcmd__user__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__user,info)
                cmd="rc__subcmd__admin__subcmd__user__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__user,ls)
                cmd="rc__subcmd__admin__subcmd__user__subcmd__ls"
                ;;
            rc__subcmd__admin__subcmd__user,rm)
                cmd="rc__subcmd__admin__subcmd__user__subcmd__rm"
                ;;
            rc__subcmd__admin__subcmd__user__subcmd__help,add)
                cmd="rc__subcmd__admin__subcmd__user__subcmd__help__subcmd__add"
                ;;
            rc__subcmd__admin__subcmd__user__subcmd__help,disable)
                cmd="rc__subcmd__admin__subcmd__user__subcmd__help__subcmd__disable"
                ;;
            rc__subcmd__admin__subcmd__user__subcmd__help,enable)
                cmd="rc__subcmd__admin__subcmd__user__subcmd__help__subcmd__enable"
                ;;
            rc__subcmd__admin__subcmd__user__subcmd__help,help)
                cmd="rc__subcmd__admin__subcmd__user__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__admin__subcmd__user__subcmd__help,info)
                cmd="rc__subcmd__admin__subcmd__user__subcmd__help__subcmd__info"
                ;;
            rc__subcmd__admin__subcmd__user__subcmd__help,ls)
                cmd="rc__subcmd__admin__subcmd__user__subcmd__help__subcmd__ls"
                ;;
            rc__subcmd__admin__subcmd__user__subcmd__help,rm)
                cmd="rc__subcmd__admin__subcmd__user__subcmd__help__subcmd__rm"
                ;;
            rc__subcmd__alias,help)
                cmd="rc__subcmd__alias__subcmd__help"
                ;;
            rc__subcmd__alias,list)
                cmd="rc__subcmd__alias__subcmd__list"
                ;;
            rc__subcmd__alias,remove)
                cmd="rc__subcmd__alias__subcmd__remove"
                ;;
            rc__subcmd__alias,set)
                cmd="rc__subcmd__alias__subcmd__set"
                ;;
            rc__subcmd__alias__subcmd__help,help)
                cmd="rc__subcmd__alias__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__alias__subcmd__help,list)
                cmd="rc__subcmd__alias__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__alias__subcmd__help,remove)
                cmd="rc__subcmd__alias__subcmd__help__subcmd__remove"
                ;;
            rc__subcmd__alias__subcmd__help,set)
                cmd="rc__subcmd__alias__subcmd__help__subcmd__set"
                ;;
            rc__subcmd__anonymous,get)
                cmd="rc__subcmd__anonymous__subcmd__get"
                ;;
            rc__subcmd__anonymous,get-json)
                cmd="rc__subcmd__anonymous__subcmd__get__subcmd__json"
                ;;
            rc__subcmd__anonymous,help)
                cmd="rc__subcmd__anonymous__subcmd__help"
                ;;
            rc__subcmd__anonymous,links)
                cmd="rc__subcmd__anonymous__subcmd__links"
                ;;
            rc__subcmd__anonymous,list)
                cmd="rc__subcmd__anonymous__subcmd__list"
                ;;
            rc__subcmd__anonymous,set)
                cmd="rc__subcmd__anonymous__subcmd__set"
                ;;
            rc__subcmd__anonymous,set-json)
                cmd="rc__subcmd__anonymous__subcmd__set__subcmd__json"
                ;;
            rc__subcmd__anonymous__subcmd__help,get)
                cmd="rc__subcmd__anonymous__subcmd__help__subcmd__get"
                ;;
            rc__subcmd__anonymous__subcmd__help,get-json)
                cmd="rc__subcmd__anonymous__subcmd__help__subcmd__get__subcmd__json"
                ;;
            rc__subcmd__anonymous__subcmd__help,help)
                cmd="rc__subcmd__anonymous__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__anonymous__subcmd__help,links)
                cmd="rc__subcmd__anonymous__subcmd__help__subcmd__links"
                ;;
            rc__subcmd__anonymous__subcmd__help,list)
                cmd="rc__subcmd__anonymous__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__anonymous__subcmd__help,set)
                cmd="rc__subcmd__anonymous__subcmd__help__subcmd__set"
                ;;
            rc__subcmd__anonymous__subcmd__help,set-json)
                cmd="rc__subcmd__anonymous__subcmd__help__subcmd__set__subcmd__json"
                ;;
            rc__subcmd__bucket,anonymous)
                cmd="rc__subcmd__bucket__subcmd__anonymous"
                ;;
            rc__subcmd__bucket,cors)
                cmd="rc__subcmd__bucket__subcmd__cors"
                ;;
            rc__subcmd__bucket,create)
                cmd="rc__subcmd__bucket__subcmd__create"
                ;;
            rc__subcmd__bucket,encryption)
                cmd="rc__subcmd__bucket__subcmd__encryption"
                ;;
            rc__subcmd__bucket,event)
                cmd="rc__subcmd__bucket__subcmd__event"
                ;;
            rc__subcmd__bucket,help)
                cmd="rc__subcmd__bucket__subcmd__help"
                ;;
            rc__subcmd__bucket,lifecycle)
                cmd="rc__subcmd__bucket__subcmd__lifecycle"
                ;;
            rc__subcmd__bucket,list)
                cmd="rc__subcmd__bucket__subcmd__list"
                ;;
            rc__subcmd__bucket,quota)
                cmd="rc__subcmd__bucket__subcmd__quota"
                ;;
            rc__subcmd__bucket,remove)
                cmd="rc__subcmd__bucket__subcmd__remove"
                ;;
            rc__subcmd__bucket,replication)
                cmd="rc__subcmd__bucket__subcmd__replication"
                ;;
            rc__subcmd__bucket,version)
                cmd="rc__subcmd__bucket__subcmd__version"
                ;;
            rc__subcmd__bucket__subcmd__anonymous,get)
                cmd="rc__subcmd__bucket__subcmd__anonymous__subcmd__get"
                ;;
            rc__subcmd__bucket__subcmd__anonymous,get-json)
                cmd="rc__subcmd__bucket__subcmd__anonymous__subcmd__get__subcmd__json"
                ;;
            rc__subcmd__bucket__subcmd__anonymous,help)
                cmd="rc__subcmd__bucket__subcmd__anonymous__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__anonymous,links)
                cmd="rc__subcmd__bucket__subcmd__anonymous__subcmd__links"
                ;;
            rc__subcmd__bucket__subcmd__anonymous,list)
                cmd="rc__subcmd__bucket__subcmd__anonymous__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__anonymous,set)
                cmd="rc__subcmd__bucket__subcmd__anonymous__subcmd__set"
                ;;
            rc__subcmd__bucket__subcmd__anonymous,set-json)
                cmd="rc__subcmd__bucket__subcmd__anonymous__subcmd__set__subcmd__json"
                ;;
            rc__subcmd__bucket__subcmd__anonymous__subcmd__help,get)
                cmd="rc__subcmd__bucket__subcmd__anonymous__subcmd__help__subcmd__get"
                ;;
            rc__subcmd__bucket__subcmd__anonymous__subcmd__help,get-json)
                cmd="rc__subcmd__bucket__subcmd__anonymous__subcmd__help__subcmd__get__subcmd__json"
                ;;
            rc__subcmd__bucket__subcmd__anonymous__subcmd__help,help)
                cmd="rc__subcmd__bucket__subcmd__anonymous__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__anonymous__subcmd__help,links)
                cmd="rc__subcmd__bucket__subcmd__anonymous__subcmd__help__subcmd__links"
                ;;
            rc__subcmd__bucket__subcmd__anonymous__subcmd__help,list)
                cmd="rc__subcmd__bucket__subcmd__anonymous__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__anonymous__subcmd__help,set)
                cmd="rc__subcmd__bucket__subcmd__anonymous__subcmd__help__subcmd__set"
                ;;
            rc__subcmd__bucket__subcmd__anonymous__subcmd__help,set-json)
                cmd="rc__subcmd__bucket__subcmd__anonymous__subcmd__help__subcmd__set__subcmd__json"
                ;;
            rc__subcmd__bucket__subcmd__cors,help)
                cmd="rc__subcmd__bucket__subcmd__cors__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__cors,list)
                cmd="rc__subcmd__bucket__subcmd__cors__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__cors,remove)
                cmd="rc__subcmd__bucket__subcmd__cors__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__cors,set)
                cmd="rc__subcmd__bucket__subcmd__cors__subcmd__set"
                ;;
            rc__subcmd__bucket__subcmd__cors__subcmd__help,help)
                cmd="rc__subcmd__bucket__subcmd__cors__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__cors__subcmd__help,list)
                cmd="rc__subcmd__bucket__subcmd__cors__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__cors__subcmd__help,remove)
                cmd="rc__subcmd__bucket__subcmd__cors__subcmd__help__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__cors__subcmd__help,set)
                cmd="rc__subcmd__bucket__subcmd__cors__subcmd__help__subcmd__set"
                ;;
            rc__subcmd__bucket__subcmd__encryption,clear)
                cmd="rc__subcmd__bucket__subcmd__encryption__subcmd__clear"
                ;;
            rc__subcmd__bucket__subcmd__encryption,help)
                cmd="rc__subcmd__bucket__subcmd__encryption__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__encryption,info)
                cmd="rc__subcmd__bucket__subcmd__encryption__subcmd__info"
                ;;
            rc__subcmd__bucket__subcmd__encryption,set)
                cmd="rc__subcmd__bucket__subcmd__encryption__subcmd__set"
                ;;
            rc__subcmd__bucket__subcmd__encryption__subcmd__help,clear)
                cmd="rc__subcmd__bucket__subcmd__encryption__subcmd__help__subcmd__clear"
                ;;
            rc__subcmd__bucket__subcmd__encryption__subcmd__help,help)
                cmd="rc__subcmd__bucket__subcmd__encryption__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__encryption__subcmd__help,info)
                cmd="rc__subcmd__bucket__subcmd__encryption__subcmd__help__subcmd__info"
                ;;
            rc__subcmd__bucket__subcmd__encryption__subcmd__help,set)
                cmd="rc__subcmd__bucket__subcmd__encryption__subcmd__help__subcmd__set"
                ;;
            rc__subcmd__bucket__subcmd__event,add)
                cmd="rc__subcmd__bucket__subcmd__event__subcmd__add"
                ;;
            rc__subcmd__bucket__subcmd__event,help)
                cmd="rc__subcmd__bucket__subcmd__event__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__event,list)
                cmd="rc__subcmd__bucket__subcmd__event__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__event,remove)
                cmd="rc__subcmd__bucket__subcmd__event__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__event__subcmd__help,add)
                cmd="rc__subcmd__bucket__subcmd__event__subcmd__help__subcmd__add"
                ;;
            rc__subcmd__bucket__subcmd__event__subcmd__help,help)
                cmd="rc__subcmd__bucket__subcmd__event__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__event__subcmd__help,list)
                cmd="rc__subcmd__bucket__subcmd__event__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__event__subcmd__help,remove)
                cmd="rc__subcmd__bucket__subcmd__event__subcmd__help__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__help,anonymous)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__anonymous"
                ;;
            rc__subcmd__bucket__subcmd__help,cors)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__cors"
                ;;
            rc__subcmd__bucket__subcmd__help,create)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__create"
                ;;
            rc__subcmd__bucket__subcmd__help,encryption)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__encryption"
                ;;
            rc__subcmd__bucket__subcmd__help,event)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__event"
                ;;
            rc__subcmd__bucket__subcmd__help,help)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__help,lifecycle)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__lifecycle"
                ;;
            rc__subcmd__bucket__subcmd__help,list)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__help,quota)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__quota"
                ;;
            rc__subcmd__bucket__subcmd__help,remove)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__help,replication)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__replication"
                ;;
            rc__subcmd__bucket__subcmd__help,version)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__version"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__anonymous,get)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__anonymous__subcmd__get"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__anonymous,get-json)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__anonymous__subcmd__get__subcmd__json"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__anonymous,links)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__anonymous__subcmd__links"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__anonymous,list)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__anonymous__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__anonymous,set)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__anonymous__subcmd__set"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__anonymous,set-json)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__anonymous__subcmd__set__subcmd__json"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__cors,list)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__cors__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__cors,remove)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__cors__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__cors,set)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__cors__subcmd__set"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__encryption,clear)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__encryption__subcmd__clear"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__encryption,info)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__encryption__subcmd__info"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__encryption,set)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__encryption__subcmd__set"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__event,add)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__event__subcmd__add"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__event,list)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__event__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__event,remove)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__event__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__lifecycle,restore)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__restore"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__lifecycle,rule)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__lifecycle,tier)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule,add)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule__subcmd__add"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule,edit)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule__subcmd__edit"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule,export)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule__subcmd__export"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule,import)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule__subcmd__import"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule,list)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule,remove)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier,add)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier__subcmd__add"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier,edit)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier__subcmd__edit"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier,info)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier__subcmd__info"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier,list)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier,remove)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__quota,clear)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__quota__subcmd__clear"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__quota,info)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__quota__subcmd__info"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__quota,set)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__quota__subcmd__set"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__replication,add)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__replication__subcmd__add"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__replication,export)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__replication__subcmd__export"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__replication,import)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__replication__subcmd__import"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__replication,list)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__replication__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__replication,remove)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__replication__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__replication,status)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__replication__subcmd__status"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__replication,update)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__replication__subcmd__update"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__version,enable)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__version__subcmd__enable"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__version,info)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__version__subcmd__info"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__version,list)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__version__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__help__subcmd__version,suspend)
                cmd="rc__subcmd__bucket__subcmd__help__subcmd__version__subcmd__suspend"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle,help)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle,restore)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__restore"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle,rule)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle,tier)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__help,help)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__help,restore)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__restore"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__help,rule)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__help,tier)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule,add)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule__subcmd__add"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule,edit)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule__subcmd__edit"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule,export)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule__subcmd__export"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule,import)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule__subcmd__import"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule,list)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule,remove)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier,add)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier__subcmd__add"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier,edit)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier__subcmd__edit"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier,info)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier__subcmd__info"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier,list)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier,remove)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule,add)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__add"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule,edit)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__edit"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule,export)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__export"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule,help)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule,import)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__import"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule,list)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule,remove)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help,add)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help__subcmd__add"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help,edit)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help__subcmd__edit"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help,export)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help__subcmd__export"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help,help)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help,import)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help__subcmd__import"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help,list)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help,remove)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier,add)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__add"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier,edit)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__edit"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier,help)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier,info)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__info"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier,list)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier,remove)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help,add)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help__subcmd__add"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help,edit)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help__subcmd__edit"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help,help)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help,info)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help__subcmd__info"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help,list)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help,remove)
                cmd="rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__quota,clear)
                cmd="rc__subcmd__bucket__subcmd__quota__subcmd__clear"
                ;;
            rc__subcmd__bucket__subcmd__quota,help)
                cmd="rc__subcmd__bucket__subcmd__quota__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__quota,info)
                cmd="rc__subcmd__bucket__subcmd__quota__subcmd__info"
                ;;
            rc__subcmd__bucket__subcmd__quota,set)
                cmd="rc__subcmd__bucket__subcmd__quota__subcmd__set"
                ;;
            rc__subcmd__bucket__subcmd__quota__subcmd__help,clear)
                cmd="rc__subcmd__bucket__subcmd__quota__subcmd__help__subcmd__clear"
                ;;
            rc__subcmd__bucket__subcmd__quota__subcmd__help,help)
                cmd="rc__subcmd__bucket__subcmd__quota__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__quota__subcmd__help,info)
                cmd="rc__subcmd__bucket__subcmd__quota__subcmd__help__subcmd__info"
                ;;
            rc__subcmd__bucket__subcmd__quota__subcmd__help,set)
                cmd="rc__subcmd__bucket__subcmd__quota__subcmd__help__subcmd__set"
                ;;
            rc__subcmd__bucket__subcmd__replication,add)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__add"
                ;;
            rc__subcmd__bucket__subcmd__replication,export)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__export"
                ;;
            rc__subcmd__bucket__subcmd__replication,help)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__replication,import)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__import"
                ;;
            rc__subcmd__bucket__subcmd__replication,list)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__replication,remove)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__replication,status)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__status"
                ;;
            rc__subcmd__bucket__subcmd__replication,update)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__update"
                ;;
            rc__subcmd__bucket__subcmd__replication__subcmd__help,add)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__add"
                ;;
            rc__subcmd__bucket__subcmd__replication__subcmd__help,export)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__export"
                ;;
            rc__subcmd__bucket__subcmd__replication__subcmd__help,help)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__replication__subcmd__help,import)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__import"
                ;;
            rc__subcmd__bucket__subcmd__replication__subcmd__help,list)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__replication__subcmd__help,remove)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__remove"
                ;;
            rc__subcmd__bucket__subcmd__replication__subcmd__help,status)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__status"
                ;;
            rc__subcmd__bucket__subcmd__replication__subcmd__help,update)
                cmd="rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__update"
                ;;
            rc__subcmd__bucket__subcmd__version,enable)
                cmd="rc__subcmd__bucket__subcmd__version__subcmd__enable"
                ;;
            rc__subcmd__bucket__subcmd__version,help)
                cmd="rc__subcmd__bucket__subcmd__version__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__version,info)
                cmd="rc__subcmd__bucket__subcmd__version__subcmd__info"
                ;;
            rc__subcmd__bucket__subcmd__version,list)
                cmd="rc__subcmd__bucket__subcmd__version__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__version,suspend)
                cmd="rc__subcmd__bucket__subcmd__version__subcmd__suspend"
                ;;
            rc__subcmd__bucket__subcmd__version__subcmd__help,enable)
                cmd="rc__subcmd__bucket__subcmd__version__subcmd__help__subcmd__enable"
                ;;
            rc__subcmd__bucket__subcmd__version__subcmd__help,help)
                cmd="rc__subcmd__bucket__subcmd__version__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__bucket__subcmd__version__subcmd__help,info)
                cmd="rc__subcmd__bucket__subcmd__version__subcmd__help__subcmd__info"
                ;;
            rc__subcmd__bucket__subcmd__version__subcmd__help,list)
                cmd="rc__subcmd__bucket__subcmd__version__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__bucket__subcmd__version__subcmd__help,suspend)
                cmd="rc__subcmd__bucket__subcmd__version__subcmd__help__subcmd__suspend"
                ;;
            rc__subcmd__cors,help)
                cmd="rc__subcmd__cors__subcmd__help"
                ;;
            rc__subcmd__cors,list)
                cmd="rc__subcmd__cors__subcmd__list"
                ;;
            rc__subcmd__cors,remove)
                cmd="rc__subcmd__cors__subcmd__remove"
                ;;
            rc__subcmd__cors,set)
                cmd="rc__subcmd__cors__subcmd__set"
                ;;
            rc__subcmd__cors__subcmd__help,help)
                cmd="rc__subcmd__cors__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__cors__subcmd__help,list)
                cmd="rc__subcmd__cors__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__cors__subcmd__help,remove)
                cmd="rc__subcmd__cors__subcmd__help__subcmd__remove"
                ;;
            rc__subcmd__cors__subcmd__help,set)
                cmd="rc__subcmd__cors__subcmd__help__subcmd__set"
                ;;
            rc__subcmd__event,add)
                cmd="rc__subcmd__event__subcmd__add"
                ;;
            rc__subcmd__event,help)
                cmd="rc__subcmd__event__subcmd__help"
                ;;
            rc__subcmd__event,list)
                cmd="rc__subcmd__event__subcmd__list"
                ;;
            rc__subcmd__event,remove)
                cmd="rc__subcmd__event__subcmd__remove"
                ;;
            rc__subcmd__event__subcmd__help,add)
                cmd="rc__subcmd__event__subcmd__help__subcmd__add"
                ;;
            rc__subcmd__event__subcmd__help,help)
                cmd="rc__subcmd__event__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__event__subcmd__help,list)
                cmd="rc__subcmd__event__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__event__subcmd__help,remove)
                cmd="rc__subcmd__event__subcmd__help__subcmd__remove"
                ;;
            rc__subcmd__help,admin)
                cmd="rc__subcmd__help__subcmd__admin"
                ;;
            rc__subcmd__help,alias)
                cmd="rc__subcmd__help__subcmd__alias"
                ;;
            rc__subcmd__help,anonymous)
                cmd="rc__subcmd__help__subcmd__anonymous"
                ;;
            rc__subcmd__help,bucket)
                cmd="rc__subcmd__help__subcmd__bucket"
                ;;
            rc__subcmd__help,cat)
                cmd="rc__subcmd__help__subcmd__cat"
                ;;
            rc__subcmd__help,completions)
                cmd="rc__subcmd__help__subcmd__completions"
                ;;
            rc__subcmd__help,cors)
                cmd="rc__subcmd__help__subcmd__cors"
                ;;
            rc__subcmd__help,cp)
                cmd="rc__subcmd__help__subcmd__cp"
                ;;
            rc__subcmd__help,diff)
                cmd="rc__subcmd__help__subcmd__diff"
                ;;
            rc__subcmd__help,event)
                cmd="rc__subcmd__help__subcmd__event"
                ;;
            rc__subcmd__help,find)
                cmd="rc__subcmd__help__subcmd__find"
                ;;
            rc__subcmd__help,head)
                cmd="rc__subcmd__help__subcmd__head"
                ;;
            rc__subcmd__help,help)
                cmd="rc__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__help,ilm)
                cmd="rc__subcmd__help__subcmd__ilm"
                ;;
            rc__subcmd__help,ls)
                cmd="rc__subcmd__help__subcmd__ls"
                ;;
            rc__subcmd__help,mb)
                cmd="rc__subcmd__help__subcmd__mb"
                ;;
            rc__subcmd__help,mirror)
                cmd="rc__subcmd__help__subcmd__mirror"
                ;;
            rc__subcmd__help,mv)
                cmd="rc__subcmd__help__subcmd__mv"
                ;;
            rc__subcmd__help,object)
                cmd="rc__subcmd__help__subcmd__object"
                ;;
            rc__subcmd__help,pipe)
                cmd="rc__subcmd__help__subcmd__pipe"
                ;;
            rc__subcmd__help,quota)
                cmd="rc__subcmd__help__subcmd__quota"
                ;;
            rc__subcmd__help,rb)
                cmd="rc__subcmd__help__subcmd__rb"
                ;;
            rc__subcmd__help,replicate)
                cmd="rc__subcmd__help__subcmd__replicate"
                ;;
            rc__subcmd__help,rm)
                cmd="rc__subcmd__help__subcmd__rm"
                ;;
            rc__subcmd__help,share)
                cmd="rc__subcmd__help__subcmd__share"
                ;;
            rc__subcmd__help,sql)
                cmd="rc__subcmd__help__subcmd__sql"
                ;;
            rc__subcmd__help,stat)
                cmd="rc__subcmd__help__subcmd__stat"
                ;;
            rc__subcmd__help,tag)
                cmd="rc__subcmd__help__subcmd__tag"
                ;;
            rc__subcmd__help,tree)
                cmd="rc__subcmd__help__subcmd__tree"
                ;;
            rc__subcmd__help,version)
                cmd="rc__subcmd__help__subcmd__version"
                ;;
            rc__subcmd__help__subcmd__admin,access-key)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__access__subcmd__key"
                ;;
            rc__subcmd__help__subcmd__admin,decommission)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__decommission"
                ;;
            rc__subcmd__help__subcmd__admin,expand)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__expand"
                ;;
            rc__subcmd__help__subcmd__admin,group)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__group"
                ;;
            rc__subcmd__help__subcmd__admin,heal)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__heal"
                ;;
            rc__subcmd__help__subcmd__admin,info)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__info"
                ;;
            rc__subcmd__help__subcmd__admin,policy)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__policy"
                ;;
            rc__subcmd__help__subcmd__admin,pool)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__pool"
                ;;
            rc__subcmd__help__subcmd__admin,rebalance)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__rebalance"
                ;;
            rc__subcmd__help__subcmd__admin,replicate)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__replicate"
                ;;
            rc__subcmd__help__subcmd__admin,service)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__service"
                ;;
            rc__subcmd__help__subcmd__admin,service-account)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__account"
                ;;
            rc__subcmd__help__subcmd__admin,user)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__user"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__access__subcmd__key,info)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__access__subcmd__key__subcmd__info"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__decommission,cancel)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__decommission__subcmd__cancel"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__decommission,clear)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__decommission__subcmd__clear"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__decommission,start)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__decommission__subcmd__start"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__decommission,status)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__decommission__subcmd__status"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__expand,start)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__expand__subcmd__start"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__expand,status)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__expand__subcmd__status"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__expand,stop)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__expand__subcmd__stop"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__group,add)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__add"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__group,add-members)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__add__subcmd__members"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__group,disable)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__disable"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__group,enable)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__enable"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__group,info)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__info"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__group,ls)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__ls"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__group,rm)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__rm"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__group,rm-members)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__rm__subcmd__members"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__heal,start)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__heal__subcmd__start"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__heal,status)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__heal__subcmd__status"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__heal,stop)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__heal__subcmd__stop"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__info,cluster)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__info__subcmd__cluster"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__info,disk)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__info__subcmd__disk"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__info,server)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__info__subcmd__server"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__policy,attach)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__policy__subcmd__attach"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__policy,create)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__policy__subcmd__create"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__policy,info)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__policy__subcmd__info"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__policy,ls)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__policy__subcmd__ls"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__policy,rm)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__policy__subcmd__rm"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__pool,list)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__pool__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__pool,status)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__pool__subcmd__status"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__rebalance,start)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__rebalance__subcmd__start"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__rebalance,status)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__rebalance__subcmd__status"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__rebalance,stop)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__rebalance__subcmd__stop"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__replicate,add)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__replicate__subcmd__add"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__replicate,info)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__replicate__subcmd__info"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__replicate,remove)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__replicate__subcmd__remove"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__replicate,status)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__replicate__subcmd__status"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__service,freeze)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__freeze"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__service,restart)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__restart"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__service,stop)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__stop"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__service,unfreeze)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__unfreeze"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__account,create)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__account__subcmd__create"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__account,info)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__account__subcmd__info"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__account,ls)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__account__subcmd__ls"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__account,rm)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__account__subcmd__rm"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__user,add)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__user__subcmd__add"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__user,disable)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__user__subcmd__disable"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__user,enable)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__user__subcmd__enable"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__user,info)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__user__subcmd__info"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__user,ls)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__user__subcmd__ls"
                ;;
            rc__subcmd__help__subcmd__admin__subcmd__user,rm)
                cmd="rc__subcmd__help__subcmd__admin__subcmd__user__subcmd__rm"
                ;;
            rc__subcmd__help__subcmd__alias,list)
                cmd="rc__subcmd__help__subcmd__alias__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__alias,remove)
                cmd="rc__subcmd__help__subcmd__alias__subcmd__remove"
                ;;
            rc__subcmd__help__subcmd__alias,set)
                cmd="rc__subcmd__help__subcmd__alias__subcmd__set"
                ;;
            rc__subcmd__help__subcmd__anonymous,get)
                cmd="rc__subcmd__help__subcmd__anonymous__subcmd__get"
                ;;
            rc__subcmd__help__subcmd__anonymous,get-json)
                cmd="rc__subcmd__help__subcmd__anonymous__subcmd__get__subcmd__json"
                ;;
            rc__subcmd__help__subcmd__anonymous,links)
                cmd="rc__subcmd__help__subcmd__anonymous__subcmd__links"
                ;;
            rc__subcmd__help__subcmd__anonymous,list)
                cmd="rc__subcmd__help__subcmd__anonymous__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__anonymous,set)
                cmd="rc__subcmd__help__subcmd__anonymous__subcmd__set"
                ;;
            rc__subcmd__help__subcmd__anonymous,set-json)
                cmd="rc__subcmd__help__subcmd__anonymous__subcmd__set__subcmd__json"
                ;;
            rc__subcmd__help__subcmd__bucket,anonymous)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__anonymous"
                ;;
            rc__subcmd__help__subcmd__bucket,cors)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__cors"
                ;;
            rc__subcmd__help__subcmd__bucket,create)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__create"
                ;;
            rc__subcmd__help__subcmd__bucket,encryption)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__encryption"
                ;;
            rc__subcmd__help__subcmd__bucket,event)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__event"
                ;;
            rc__subcmd__help__subcmd__bucket,lifecycle)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__lifecycle"
                ;;
            rc__subcmd__help__subcmd__bucket,list)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__bucket,quota)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__quota"
                ;;
            rc__subcmd__help__subcmd__bucket,remove)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__remove"
                ;;
            rc__subcmd__help__subcmd__bucket,replication)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__replication"
                ;;
            rc__subcmd__help__subcmd__bucket,version)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__version"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__anonymous,get)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__anonymous__subcmd__get"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__anonymous,get-json)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__anonymous__subcmd__get__subcmd__json"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__anonymous,links)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__anonymous__subcmd__links"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__anonymous,list)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__anonymous__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__anonymous,set)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__anonymous__subcmd__set"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__anonymous,set-json)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__anonymous__subcmd__set__subcmd__json"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__cors,list)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__cors__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__cors,remove)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__cors__subcmd__remove"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__cors,set)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__cors__subcmd__set"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__encryption,clear)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__encryption__subcmd__clear"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__encryption,info)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__encryption__subcmd__info"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__encryption,set)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__encryption__subcmd__set"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__event,add)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__event__subcmd__add"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__event,list)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__event__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__event,remove)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__event__subcmd__remove"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__lifecycle,restore)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__restore"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__lifecycle,rule)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__lifecycle,tier)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule,add)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__add"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule,edit)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__edit"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule,export)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__export"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule,import)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__import"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule,list)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule,remove)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__remove"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier,add)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__add"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier,edit)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__edit"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier,info)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__info"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier,list)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier,remove)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__remove"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__quota,clear)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__quota__subcmd__clear"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__quota,info)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__quota__subcmd__info"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__quota,set)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__quota__subcmd__set"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__replication,add)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__replication__subcmd__add"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__replication,export)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__replication__subcmd__export"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__replication,import)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__replication__subcmd__import"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__replication,list)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__replication__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__replication,remove)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__replication__subcmd__remove"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__replication,status)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__replication__subcmd__status"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__replication,update)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__replication__subcmd__update"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__version,enable)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__version__subcmd__enable"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__version,info)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__version__subcmd__info"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__version,list)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__version__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__bucket__subcmd__version,suspend)
                cmd="rc__subcmd__help__subcmd__bucket__subcmd__version__subcmd__suspend"
                ;;
            rc__subcmd__help__subcmd__cors,list)
                cmd="rc__subcmd__help__subcmd__cors__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__cors,remove)
                cmd="rc__subcmd__help__subcmd__cors__subcmd__remove"
                ;;
            rc__subcmd__help__subcmd__cors,set)
                cmd="rc__subcmd__help__subcmd__cors__subcmd__set"
                ;;
            rc__subcmd__help__subcmd__event,add)
                cmd="rc__subcmd__help__subcmd__event__subcmd__add"
                ;;
            rc__subcmd__help__subcmd__event,list)
                cmd="rc__subcmd__help__subcmd__event__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__event,remove)
                cmd="rc__subcmd__help__subcmd__event__subcmd__remove"
                ;;
            rc__subcmd__help__subcmd__ilm,restore)
                cmd="rc__subcmd__help__subcmd__ilm__subcmd__restore"
                ;;
            rc__subcmd__help__subcmd__ilm,rule)
                cmd="rc__subcmd__help__subcmd__ilm__subcmd__rule"
                ;;
            rc__subcmd__help__subcmd__ilm,tier)
                cmd="rc__subcmd__help__subcmd__ilm__subcmd__tier"
                ;;
            rc__subcmd__help__subcmd__ilm__subcmd__rule,add)
                cmd="rc__subcmd__help__subcmd__ilm__subcmd__rule__subcmd__add"
                ;;
            rc__subcmd__help__subcmd__ilm__subcmd__rule,edit)
                cmd="rc__subcmd__help__subcmd__ilm__subcmd__rule__subcmd__edit"
                ;;
            rc__subcmd__help__subcmd__ilm__subcmd__rule,export)
                cmd="rc__subcmd__help__subcmd__ilm__subcmd__rule__subcmd__export"
                ;;
            rc__subcmd__help__subcmd__ilm__subcmd__rule,import)
                cmd="rc__subcmd__help__subcmd__ilm__subcmd__rule__subcmd__import"
                ;;
            rc__subcmd__help__subcmd__ilm__subcmd__rule,list)
                cmd="rc__subcmd__help__subcmd__ilm__subcmd__rule__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__ilm__subcmd__rule,remove)
                cmd="rc__subcmd__help__subcmd__ilm__subcmd__rule__subcmd__remove"
                ;;
            rc__subcmd__help__subcmd__ilm__subcmd__tier,add)
                cmd="rc__subcmd__help__subcmd__ilm__subcmd__tier__subcmd__add"
                ;;
            rc__subcmd__help__subcmd__ilm__subcmd__tier,edit)
                cmd="rc__subcmd__help__subcmd__ilm__subcmd__tier__subcmd__edit"
                ;;
            rc__subcmd__help__subcmd__ilm__subcmd__tier,info)
                cmd="rc__subcmd__help__subcmd__ilm__subcmd__tier__subcmd__info"
                ;;
            rc__subcmd__help__subcmd__ilm__subcmd__tier,list)
                cmd="rc__subcmd__help__subcmd__ilm__subcmd__tier__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__ilm__subcmd__tier,remove)
                cmd="rc__subcmd__help__subcmd__ilm__subcmd__tier__subcmd__remove"
                ;;
            rc__subcmd__help__subcmd__object,copy)
                cmd="rc__subcmd__help__subcmd__object__subcmd__copy"
                ;;
            rc__subcmd__help__subcmd__object,find)
                cmd="rc__subcmd__help__subcmd__object__subcmd__find"
                ;;
            rc__subcmd__help__subcmd__object,head)
                cmd="rc__subcmd__help__subcmd__object__subcmd__head"
                ;;
            rc__subcmd__help__subcmd__object,list)
                cmd="rc__subcmd__help__subcmd__object__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__object,move)
                cmd="rc__subcmd__help__subcmd__object__subcmd__move"
                ;;
            rc__subcmd__help__subcmd__object,remove)
                cmd="rc__subcmd__help__subcmd__object__subcmd__remove"
                ;;
            rc__subcmd__help__subcmd__object,share)
                cmd="rc__subcmd__help__subcmd__object__subcmd__share"
                ;;
            rc__subcmd__help__subcmd__object,show)
                cmd="rc__subcmd__help__subcmd__object__subcmd__show"
                ;;
            rc__subcmd__help__subcmd__object,stat)
                cmd="rc__subcmd__help__subcmd__object__subcmd__stat"
                ;;
            rc__subcmd__help__subcmd__object,tree)
                cmd="rc__subcmd__help__subcmd__object__subcmd__tree"
                ;;
            rc__subcmd__help__subcmd__quota,clear)
                cmd="rc__subcmd__help__subcmd__quota__subcmd__clear"
                ;;
            rc__subcmd__help__subcmd__quota,info)
                cmd="rc__subcmd__help__subcmd__quota__subcmd__info"
                ;;
            rc__subcmd__help__subcmd__quota,set)
                cmd="rc__subcmd__help__subcmd__quota__subcmd__set"
                ;;
            rc__subcmd__help__subcmd__replicate,add)
                cmd="rc__subcmd__help__subcmd__replicate__subcmd__add"
                ;;
            rc__subcmd__help__subcmd__replicate,export)
                cmd="rc__subcmd__help__subcmd__replicate__subcmd__export"
                ;;
            rc__subcmd__help__subcmd__replicate,import)
                cmd="rc__subcmd__help__subcmd__replicate__subcmd__import"
                ;;
            rc__subcmd__help__subcmd__replicate,list)
                cmd="rc__subcmd__help__subcmd__replicate__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__replicate,remove)
                cmd="rc__subcmd__help__subcmd__replicate__subcmd__remove"
                ;;
            rc__subcmd__help__subcmd__replicate,status)
                cmd="rc__subcmd__help__subcmd__replicate__subcmd__status"
                ;;
            rc__subcmd__help__subcmd__replicate,update)
                cmd="rc__subcmd__help__subcmd__replicate__subcmd__update"
                ;;
            rc__subcmd__help__subcmd__tag,list)
                cmd="rc__subcmd__help__subcmd__tag__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__tag,remove)
                cmd="rc__subcmd__help__subcmd__tag__subcmd__remove"
                ;;
            rc__subcmd__help__subcmd__tag,set)
                cmd="rc__subcmd__help__subcmd__tag__subcmd__set"
                ;;
            rc__subcmd__help__subcmd__version,enable)
                cmd="rc__subcmd__help__subcmd__version__subcmd__enable"
                ;;
            rc__subcmd__help__subcmd__version,info)
                cmd="rc__subcmd__help__subcmd__version__subcmd__info"
                ;;
            rc__subcmd__help__subcmd__version,list)
                cmd="rc__subcmd__help__subcmd__version__subcmd__list"
                ;;
            rc__subcmd__help__subcmd__version,suspend)
                cmd="rc__subcmd__help__subcmd__version__subcmd__suspend"
                ;;
            rc__subcmd__ilm,help)
                cmd="rc__subcmd__ilm__subcmd__help"
                ;;
            rc__subcmd__ilm,restore)
                cmd="rc__subcmd__ilm__subcmd__restore"
                ;;
            rc__subcmd__ilm,rule)
                cmd="rc__subcmd__ilm__subcmd__rule"
                ;;
            rc__subcmd__ilm,tier)
                cmd="rc__subcmd__ilm__subcmd__tier"
                ;;
            rc__subcmd__ilm__subcmd__help,help)
                cmd="rc__subcmd__ilm__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__ilm__subcmd__help,restore)
                cmd="rc__subcmd__ilm__subcmd__help__subcmd__restore"
                ;;
            rc__subcmd__ilm__subcmd__help,rule)
                cmd="rc__subcmd__ilm__subcmd__help__subcmd__rule"
                ;;
            rc__subcmd__ilm__subcmd__help,tier)
                cmd="rc__subcmd__ilm__subcmd__help__subcmd__tier"
                ;;
            rc__subcmd__ilm__subcmd__help__subcmd__rule,add)
                cmd="rc__subcmd__ilm__subcmd__help__subcmd__rule__subcmd__add"
                ;;
            rc__subcmd__ilm__subcmd__help__subcmd__rule,edit)
                cmd="rc__subcmd__ilm__subcmd__help__subcmd__rule__subcmd__edit"
                ;;
            rc__subcmd__ilm__subcmd__help__subcmd__rule,export)
                cmd="rc__subcmd__ilm__subcmd__help__subcmd__rule__subcmd__export"
                ;;
            rc__subcmd__ilm__subcmd__help__subcmd__rule,import)
                cmd="rc__subcmd__ilm__subcmd__help__subcmd__rule__subcmd__import"
                ;;
            rc__subcmd__ilm__subcmd__help__subcmd__rule,list)
                cmd="rc__subcmd__ilm__subcmd__help__subcmd__rule__subcmd__list"
                ;;
            rc__subcmd__ilm__subcmd__help__subcmd__rule,remove)
                cmd="rc__subcmd__ilm__subcmd__help__subcmd__rule__subcmd__remove"
                ;;
            rc__subcmd__ilm__subcmd__help__subcmd__tier,add)
                cmd="rc__subcmd__ilm__subcmd__help__subcmd__tier__subcmd__add"
                ;;
            rc__subcmd__ilm__subcmd__help__subcmd__tier,edit)
                cmd="rc__subcmd__ilm__subcmd__help__subcmd__tier__subcmd__edit"
                ;;
            rc__subcmd__ilm__subcmd__help__subcmd__tier,info)
                cmd="rc__subcmd__ilm__subcmd__help__subcmd__tier__subcmd__info"
                ;;
            rc__subcmd__ilm__subcmd__help__subcmd__tier,list)
                cmd="rc__subcmd__ilm__subcmd__help__subcmd__tier__subcmd__list"
                ;;
            rc__subcmd__ilm__subcmd__help__subcmd__tier,remove)
                cmd="rc__subcmd__ilm__subcmd__help__subcmd__tier__subcmd__remove"
                ;;
            rc__subcmd__ilm__subcmd__rule,add)
                cmd="rc__subcmd__ilm__subcmd__rule__subcmd__add"
                ;;
            rc__subcmd__ilm__subcmd__rule,edit)
                cmd="rc__subcmd__ilm__subcmd__rule__subcmd__edit"
                ;;
            rc__subcmd__ilm__subcmd__rule,export)
                cmd="rc__subcmd__ilm__subcmd__rule__subcmd__export"
                ;;
            rc__subcmd__ilm__subcmd__rule,help)
                cmd="rc__subcmd__ilm__subcmd__rule__subcmd__help"
                ;;
            rc__subcmd__ilm__subcmd__rule,import)
                cmd="rc__subcmd__ilm__subcmd__rule__subcmd__import"
                ;;
            rc__subcmd__ilm__subcmd__rule,list)
                cmd="rc__subcmd__ilm__subcmd__rule__subcmd__list"
                ;;
            rc__subcmd__ilm__subcmd__rule,remove)
                cmd="rc__subcmd__ilm__subcmd__rule__subcmd__remove"
                ;;
            rc__subcmd__ilm__subcmd__rule__subcmd__help,add)
                cmd="rc__subcmd__ilm__subcmd__rule__subcmd__help__subcmd__add"
                ;;
            rc__subcmd__ilm__subcmd__rule__subcmd__help,edit)
                cmd="rc__subcmd__ilm__subcmd__rule__subcmd__help__subcmd__edit"
                ;;
            rc__subcmd__ilm__subcmd__rule__subcmd__help,export)
                cmd="rc__subcmd__ilm__subcmd__rule__subcmd__help__subcmd__export"
                ;;
            rc__subcmd__ilm__subcmd__rule__subcmd__help,help)
                cmd="rc__subcmd__ilm__subcmd__rule__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__ilm__subcmd__rule__subcmd__help,import)
                cmd="rc__subcmd__ilm__subcmd__rule__subcmd__help__subcmd__import"
                ;;
            rc__subcmd__ilm__subcmd__rule__subcmd__help,list)
                cmd="rc__subcmd__ilm__subcmd__rule__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__ilm__subcmd__rule__subcmd__help,remove)
                cmd="rc__subcmd__ilm__subcmd__rule__subcmd__help__subcmd__remove"
                ;;
            rc__subcmd__ilm__subcmd__tier,add)
                cmd="rc__subcmd__ilm__subcmd__tier__subcmd__add"
                ;;
            rc__subcmd__ilm__subcmd__tier,edit)
                cmd="rc__subcmd__ilm__subcmd__tier__subcmd__edit"
                ;;
            rc__subcmd__ilm__subcmd__tier,help)
                cmd="rc__subcmd__ilm__subcmd__tier__subcmd__help"
                ;;
            rc__subcmd__ilm__subcmd__tier,info)
                cmd="rc__subcmd__ilm__subcmd__tier__subcmd__info"
                ;;
            rc__subcmd__ilm__subcmd__tier,list)
                cmd="rc__subcmd__ilm__subcmd__tier__subcmd__list"
                ;;
            rc__subcmd__ilm__subcmd__tier,remove)
                cmd="rc__subcmd__ilm__subcmd__tier__subcmd__remove"
                ;;
            rc__subcmd__ilm__subcmd__tier__subcmd__help,add)
                cmd="rc__subcmd__ilm__subcmd__tier__subcmd__help__subcmd__add"
                ;;
            rc__subcmd__ilm__subcmd__tier__subcmd__help,edit)
                cmd="rc__subcmd__ilm__subcmd__tier__subcmd__help__subcmd__edit"
                ;;
            rc__subcmd__ilm__subcmd__tier__subcmd__help,help)
                cmd="rc__subcmd__ilm__subcmd__tier__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__ilm__subcmd__tier__subcmd__help,info)
                cmd="rc__subcmd__ilm__subcmd__tier__subcmd__help__subcmd__info"
                ;;
            rc__subcmd__ilm__subcmd__tier__subcmd__help,list)
                cmd="rc__subcmd__ilm__subcmd__tier__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__ilm__subcmd__tier__subcmd__help,remove)
                cmd="rc__subcmd__ilm__subcmd__tier__subcmd__help__subcmd__remove"
                ;;
            rc__subcmd__object,copy)
                cmd="rc__subcmd__object__subcmd__copy"
                ;;
            rc__subcmd__object,find)
                cmd="rc__subcmd__object__subcmd__find"
                ;;
            rc__subcmd__object,head)
                cmd="rc__subcmd__object__subcmd__head"
                ;;
            rc__subcmd__object,help)
                cmd="rc__subcmd__object__subcmd__help"
                ;;
            rc__subcmd__object,list)
                cmd="rc__subcmd__object__subcmd__list"
                ;;
            rc__subcmd__object,move)
                cmd="rc__subcmd__object__subcmd__move"
                ;;
            rc__subcmd__object,remove)
                cmd="rc__subcmd__object__subcmd__remove"
                ;;
            rc__subcmd__object,share)
                cmd="rc__subcmd__object__subcmd__share"
                ;;
            rc__subcmd__object,show)
                cmd="rc__subcmd__object__subcmd__show"
                ;;
            rc__subcmd__object,stat)
                cmd="rc__subcmd__object__subcmd__stat"
                ;;
            rc__subcmd__object,tree)
                cmd="rc__subcmd__object__subcmd__tree"
                ;;
            rc__subcmd__object__subcmd__help,copy)
                cmd="rc__subcmd__object__subcmd__help__subcmd__copy"
                ;;
            rc__subcmd__object__subcmd__help,find)
                cmd="rc__subcmd__object__subcmd__help__subcmd__find"
                ;;
            rc__subcmd__object__subcmd__help,head)
                cmd="rc__subcmd__object__subcmd__help__subcmd__head"
                ;;
            rc__subcmd__object__subcmd__help,help)
                cmd="rc__subcmd__object__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__object__subcmd__help,list)
                cmd="rc__subcmd__object__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__object__subcmd__help,move)
                cmd="rc__subcmd__object__subcmd__help__subcmd__move"
                ;;
            rc__subcmd__object__subcmd__help,remove)
                cmd="rc__subcmd__object__subcmd__help__subcmd__remove"
                ;;
            rc__subcmd__object__subcmd__help,share)
                cmd="rc__subcmd__object__subcmd__help__subcmd__share"
                ;;
            rc__subcmd__object__subcmd__help,show)
                cmd="rc__subcmd__object__subcmd__help__subcmd__show"
                ;;
            rc__subcmd__object__subcmd__help,stat)
                cmd="rc__subcmd__object__subcmd__help__subcmd__stat"
                ;;
            rc__subcmd__object__subcmd__help,tree)
                cmd="rc__subcmd__object__subcmd__help__subcmd__tree"
                ;;
            rc__subcmd__quota,clear)
                cmd="rc__subcmd__quota__subcmd__clear"
                ;;
            rc__subcmd__quota,help)
                cmd="rc__subcmd__quota__subcmd__help"
                ;;
            rc__subcmd__quota,info)
                cmd="rc__subcmd__quota__subcmd__info"
                ;;
            rc__subcmd__quota,set)
                cmd="rc__subcmd__quota__subcmd__set"
                ;;
            rc__subcmd__quota__subcmd__help,clear)
                cmd="rc__subcmd__quota__subcmd__help__subcmd__clear"
                ;;
            rc__subcmd__quota__subcmd__help,help)
                cmd="rc__subcmd__quota__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__quota__subcmd__help,info)
                cmd="rc__subcmd__quota__subcmd__help__subcmd__info"
                ;;
            rc__subcmd__quota__subcmd__help,set)
                cmd="rc__subcmd__quota__subcmd__help__subcmd__set"
                ;;
            rc__subcmd__replicate,add)
                cmd="rc__subcmd__replicate__subcmd__add"
                ;;
            rc__subcmd__replicate,export)
                cmd="rc__subcmd__replicate__subcmd__export"
                ;;
            rc__subcmd__replicate,help)
                cmd="rc__subcmd__replicate__subcmd__help"
                ;;
            rc__subcmd__replicate,import)
                cmd="rc__subcmd__replicate__subcmd__import"
                ;;
            rc__subcmd__replicate,list)
                cmd="rc__subcmd__replicate__subcmd__list"
                ;;
            rc__subcmd__replicate,remove)
                cmd="rc__subcmd__replicate__subcmd__remove"
                ;;
            rc__subcmd__replicate,status)
                cmd="rc__subcmd__replicate__subcmd__status"
                ;;
            rc__subcmd__replicate,update)
                cmd="rc__subcmd__replicate__subcmd__update"
                ;;
            rc__subcmd__replicate__subcmd__help,add)
                cmd="rc__subcmd__replicate__subcmd__help__subcmd__add"
                ;;
            rc__subcmd__replicate__subcmd__help,export)
                cmd="rc__subcmd__replicate__subcmd__help__subcmd__export"
                ;;
            rc__subcmd__replicate__subcmd__help,help)
                cmd="rc__subcmd__replicate__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__replicate__subcmd__help,import)
                cmd="rc__subcmd__replicate__subcmd__help__subcmd__import"
                ;;
            rc__subcmd__replicate__subcmd__help,list)
                cmd="rc__subcmd__replicate__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__replicate__subcmd__help,remove)
                cmd="rc__subcmd__replicate__subcmd__help__subcmd__remove"
                ;;
            rc__subcmd__replicate__subcmd__help,status)
                cmd="rc__subcmd__replicate__subcmd__help__subcmd__status"
                ;;
            rc__subcmd__replicate__subcmd__help,update)
                cmd="rc__subcmd__replicate__subcmd__help__subcmd__update"
                ;;
            rc__subcmd__tag,help)
                cmd="rc__subcmd__tag__subcmd__help"
                ;;
            rc__subcmd__tag,list)
                cmd="rc__subcmd__tag__subcmd__list"
                ;;
            rc__subcmd__tag,remove)
                cmd="rc__subcmd__tag__subcmd__remove"
                ;;
            rc__subcmd__tag,set)
                cmd="rc__subcmd__tag__subcmd__set"
                ;;
            rc__subcmd__tag__subcmd__help,help)
                cmd="rc__subcmd__tag__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__tag__subcmd__help,list)
                cmd="rc__subcmd__tag__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__tag__subcmd__help,remove)
                cmd="rc__subcmd__tag__subcmd__help__subcmd__remove"
                ;;
            rc__subcmd__tag__subcmd__help,set)
                cmd="rc__subcmd__tag__subcmd__help__subcmd__set"
                ;;
            rc__subcmd__version,enable)
                cmd="rc__subcmd__version__subcmd__enable"
                ;;
            rc__subcmd__version,help)
                cmd="rc__subcmd__version__subcmd__help"
                ;;
            rc__subcmd__version,info)
                cmd="rc__subcmd__version__subcmd__info"
                ;;
            rc__subcmd__version,list)
                cmd="rc__subcmd__version__subcmd__list"
                ;;
            rc__subcmd__version,suspend)
                cmd="rc__subcmd__version__subcmd__suspend"
                ;;
            rc__subcmd__version__subcmd__help,enable)
                cmd="rc__subcmd__version__subcmd__help__subcmd__enable"
                ;;
            rc__subcmd__version__subcmd__help,help)
                cmd="rc__subcmd__version__subcmd__help__subcmd__help"
                ;;
            rc__subcmd__version__subcmd__help,info)
                cmd="rc__subcmd__version__subcmd__help__subcmd__info"
                ;;
            rc__subcmd__version__subcmd__help,list)
                cmd="rc__subcmd__version__subcmd__help__subcmd__list"
                ;;
            rc__subcmd__version__subcmd__help,suspend)
                cmd="rc__subcmd__version__subcmd__help__subcmd__suspend"
                ;;
            *)
                ;;
        esac
    done

    case "${cmd}" in
        rc)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 1 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version info heal pool expand decommission rebalance user policy group service-account access-key service replicate help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__access__subcmd__key)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version info help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__access__subcmd__key__subcmd__help)
            opts="info help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__access__subcmd__key__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__access__subcmd__key__subcmd__help__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__access__subcmd__key__subcmd__info)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__decommission)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version start status cancel clear help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__decommission__subcmd__cancel)
            opts="-q -H -h -V --by-id --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__decommission__subcmd__clear)
            opts="-q -H -h -V --by-id --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__decommission__subcmd__help)
            opts="start status cancel clear help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__decommission__subcmd__help__subcmd__cancel)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__decommission__subcmd__help__subcmd__clear)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__decommission__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__decommission__subcmd__help__subcmd__start)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__decommission__subcmd__help__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__decommission__subcmd__start)
            opts="-q -H -h -V --by-id --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__decommission__subcmd__status)
            opts="-q -H -h -V --by-id --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__expand)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version start status stop help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__expand__subcmd__help)
            opts="start status stop help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__expand__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__expand__subcmd__help__subcmd__start)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__expand__subcmd__help__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__expand__subcmd__help__subcmd__stop)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__expand__subcmd__start)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__expand__subcmd__status)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__expand__subcmd__stop)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version ls add info rm enable disable add-members rm-members help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__add)
            opts="-q -H -h -V --members --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --members)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__add__subcmd__members)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__disable)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__enable)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__help)
            opts="ls add info rm enable disable add-members rm-members help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__add__subcmd__members)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__disable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__enable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__ls)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__rm)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__help__subcmd__rm__subcmd__members)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__info)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__ls)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__rm)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__group__subcmd__rm__subcmd__members)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__heal)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version status start stop help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__heal__subcmd__help)
            opts="status start stop help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__heal__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__heal__subcmd__help__subcmd__start)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__heal__subcmd__help__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__heal__subcmd__help__subcmd__stop)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__heal__subcmd__start)
            opts="-b -p -q -H -h -V --bucket --prefix --scan-mode --remove --recreate --dry-run --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --bucket)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -b)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --prefix)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -p)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --scan-mode)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__heal__subcmd__status)
            opts="-b -p -q -H -h -V --bucket --prefix --client-token --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --bucket)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -b)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --prefix)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -p)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --client-token)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__heal__subcmd__stop)
            opts="-b -p -q -H -h -V --bucket --prefix --client-token --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --bucket)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -b)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --prefix)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -p)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --client-token)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help)
            opts="info heal pool expand decommission rebalance user policy group service-account access-key service replicate help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__access__subcmd__key)
            opts="info"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__access__subcmd__key__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__decommission)
            opts="start status cancel clear"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__decommission__subcmd__cancel)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__decommission__subcmd__clear)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__decommission__subcmd__start)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__decommission__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__expand)
            opts="start status stop"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__expand__subcmd__start)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__expand__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__expand__subcmd__stop)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__group)
            opts="ls add info rm enable disable add-members rm-members"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__add__subcmd__members)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__disable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__enable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__ls)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__rm)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__group__subcmd__rm__subcmd__members)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__heal)
            opts="status start stop"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__heal__subcmd__start)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__heal__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__heal__subcmd__stop)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__info)
            opts="cluster server disk"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__info__subcmd__cluster)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__info__subcmd__disk)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__info__subcmd__server)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__policy)
            opts="ls create info rm attach"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__policy__subcmd__attach)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__policy__subcmd__create)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__policy__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__policy__subcmd__ls)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__policy__subcmd__rm)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__pool)
            opts="list status"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__pool__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__pool__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__rebalance)
            opts="start status stop"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__rebalance__subcmd__start)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__rebalance__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__rebalance__subcmd__stop)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__replicate)
            opts="add info status remove"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__replicate__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__replicate__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__replicate__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__replicate__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__service)
            opts="restart stop freeze unfreeze"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__account)
            opts="ls create info rm"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__account__subcmd__create)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__account__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__account__subcmd__ls)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__account__subcmd__rm)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__freeze)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__restart)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__stop)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__service__subcmd__unfreeze)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__user)
            opts="ls add info rm enable disable"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__user__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__user__subcmd__disable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__user__subcmd__enable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__user__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__user__subcmd__ls)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__help__subcmd__user__subcmd__rm)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__info)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version cluster server disk help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__info__subcmd__cluster)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__info__subcmd__disk)
            opts="-q -H -h -V --offline --healing --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__info__subcmd__help)
            opts="cluster server disk help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__info__subcmd__help__subcmd__cluster)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__info__subcmd__help__subcmd__disk)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__info__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__info__subcmd__help__subcmd__server)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__info__subcmd__server)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__policy)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version ls create info rm attach help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__policy__subcmd__attach)
            opts="-q -H -h -V --user --group --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --user)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --group)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__policy__subcmd__create)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__policy__subcmd__help)
            opts="ls create info rm attach help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__policy__subcmd__help__subcmd__attach)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__policy__subcmd__help__subcmd__create)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__policy__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__policy__subcmd__help__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__policy__subcmd__help__subcmd__ls)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__policy__subcmd__help__subcmd__rm)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__policy__subcmd__info)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__policy__subcmd__ls)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__policy__subcmd__rm)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__pool)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version list status help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__pool__subcmd__help)
            opts="list status help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__pool__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__pool__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__pool__subcmd__help__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__pool__subcmd__list)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__pool__subcmd__status)
            opts="-q -H -h -V --by-id --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__rebalance)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version start status stop help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__rebalance__subcmd__help)
            opts="start status stop help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__rebalance__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__rebalance__subcmd__help__subcmd__start)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__rebalance__subcmd__help__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__rebalance__subcmd__help__subcmd__stop)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__rebalance__subcmd__start)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__rebalance__subcmd__status)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__rebalance__subcmd__stop)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__replicate)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version add info status remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__replicate__subcmd__add)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__replicate__subcmd__help)
            opts="add info status remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__replicate__subcmd__help__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__replicate__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__replicate__subcmd__help__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__replicate__subcmd__help__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__replicate__subcmd__help__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__replicate__subcmd__info)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__replicate__subcmd__remove)
            opts="-q -H -h -V --site --all --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --site)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__replicate__subcmd__status)
            opts="-q -H -h -V --buckets --users --groups --policies --metrics --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version restart stop freeze unfreeze help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__account)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version ls create info rm help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__create)
            opts="-q -H -h -V --name --description --policy --expiry --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --name)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --description)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --policy)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --expiry)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help)
            opts="ls create info rm help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help__subcmd__create)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help__subcmd__ls)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__help__subcmd__rm)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__info)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__ls)
            opts="-q -H -h -V --user --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --user)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__account__subcmd__rm)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__freeze)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__help)
            opts="restart stop freeze unfreeze help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__help__subcmd__freeze)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__help__subcmd__restart)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__help__subcmd__stop)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__help__subcmd__unfreeze)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__restart)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__stop)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__service__subcmd__unfreeze)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__user)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version ls add info rm enable disable help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__user__subcmd__add)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__user__subcmd__disable)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__user__subcmd__enable)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__user__subcmd__help)
            opts="ls add info rm enable disable help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__user__subcmd__help__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__user__subcmd__help__subcmd__disable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__user__subcmd__help__subcmd__enable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__user__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__user__subcmd__help__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__user__subcmd__help__subcmd__ls)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__user__subcmd__help__subcmd__rm)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__user__subcmd__info)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__user__subcmd__ls)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__admin__subcmd__user__subcmd__rm)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__alias)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version set list remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__alias__subcmd__help)
            opts="set list remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__alias__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__alias__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__alias__subcmd__help__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__alias__subcmd__help__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__alias__subcmd__list)
            opts="-l -q -H -h -V --long --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__alias__subcmd__remove)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__alias__subcmd__set)
            opts="-q -H -h -V --anonymous --client-cert --client-key --region --signature --bucket-lookup --insecure --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --client-cert)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --client-key)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --region)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --signature)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --bucket-lookup)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__anonymous)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version set set-json get get-json list links help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__anonymous__subcmd__get)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__anonymous__subcmd__get__subcmd__json)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__anonymous__subcmd__help)
            opts="set set-json get get-json list links help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__anonymous__subcmd__help__subcmd__get)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__anonymous__subcmd__help__subcmd__get__subcmd__json)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__anonymous__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__anonymous__subcmd__help__subcmd__links)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__anonymous__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__anonymous__subcmd__help__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__anonymous__subcmd__help__subcmd__set__subcmd__json)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__anonymous__subcmd__links)
            opts="-r -q -H -h -V --recursive --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__anonymous__subcmd__list)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__anonymous__subcmd__set)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__anonymous__subcmd__set__subcmd__json)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version list create remove event cors encryption version quota anonymous lifecycle replication help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__anonymous)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version set set-json get get-json list links help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__anonymous__subcmd__get)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__anonymous__subcmd__get__subcmd__json)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__anonymous__subcmd__help)
            opts="set set-json get get-json list links help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__anonymous__subcmd__help__subcmd__get)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__anonymous__subcmd__help__subcmd__get__subcmd__json)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__anonymous__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__anonymous__subcmd__help__subcmd__links)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__anonymous__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__anonymous__subcmd__help__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__anonymous__subcmd__help__subcmd__set__subcmd__json)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__anonymous__subcmd__links)
            opts="-r -q -H -h -V --recursive --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__anonymous__subcmd__list)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__anonymous__subcmd__set)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__anonymous__subcmd__set__subcmd__json)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__cors)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version list set remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__cors__subcmd__help)
            opts="list set remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__cors__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__cors__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__cors__subcmd__help__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__cors__subcmd__help__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__cors__subcmd__list)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__cors__subcmd__remove)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__cors__subcmd__set)
            opts="-q -H -h -V --file --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --file)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__create)
            opts="-p -q -H -h -V --ignore-existing --region --with-lock --with-versioning --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --region)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__encryption)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version set info clear help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__encryption__subcmd__clear)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__encryption__subcmd__help)
            opts="set info clear help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__encryption__subcmd__help__subcmd__clear)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__encryption__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__encryption__subcmd__help__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__encryption__subcmd__help__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__encryption__subcmd__info)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__encryption__subcmd__set)
            opts="-q -H -h -V --mode --key-id --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --mode)
                    COMPREPLY=($(compgen -W "sse-s3 sse-kms" -- "${cur}"))
                    return 0
                    ;;
                --key-id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__event)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version add list remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__event__subcmd__add)
            opts="-q -H -h -V --event --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --event)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__event__subcmd__help)
            opts="add list remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__event__subcmd__help__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__event__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__event__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__event__subcmd__help__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__event__subcmd__list)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__event__subcmd__remove)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help)
            opts="list create remove event cors encryption version quota anonymous lifecycle replication help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__anonymous)
            opts="set set-json get get-json list links"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__anonymous__subcmd__get)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__anonymous__subcmd__get__subcmd__json)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__anonymous__subcmd__links)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__anonymous__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__anonymous__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__anonymous__subcmd__set__subcmd__json)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__cors)
            opts="list set remove"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__cors__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__cors__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__cors__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__create)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__encryption)
            opts="set info clear"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__encryption__subcmd__clear)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__encryption__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__encryption__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__event)
            opts="add list remove"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__event__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__event__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__event__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__lifecycle)
            opts="rule tier restore"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__restore)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule)
            opts="add edit list remove export import"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule__subcmd__edit)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule__subcmd__export)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule__subcmd__import)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__rule__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier)
            opts="add edit list info remove"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier__subcmd__edit)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__lifecycle__subcmd__tier__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__quota)
            opts="set info clear"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__quota__subcmd__clear)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__quota__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__quota__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__replication)
            opts="add update list status remove export import"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__replication__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__replication__subcmd__export)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__replication__subcmd__import)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__replication__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__replication__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__replication__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__replication__subcmd__update)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__version)
            opts="enable suspend info list"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__version__subcmd__enable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__version__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__version__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__help__subcmd__version__subcmd__suspend)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version rule tier restore help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help)
            opts="rule tier restore help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__restore)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule)
            opts="add edit list remove export import"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule__subcmd__edit)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule__subcmd__export)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule__subcmd__import)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__rule__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier)
            opts="add edit list info remove"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier__subcmd__edit)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__help__subcmd__tier__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__restore)
            opts="-q -H -h -V --days --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version add edit list remove export import help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__add)
            opts="-q -H -h -V --expiry-days --expiry-date --transition-days --transition-date --storage-class --noncurrent-expiry-days --noncurrent-transition-days --noncurrent-transition-storage-class --prefix --expired-object-delete-marker --newer-noncurrent-versions --disable --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --expiry-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --expiry-date)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --transition-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --transition-date)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --noncurrent-expiry-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --noncurrent-transition-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --noncurrent-transition-storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --prefix)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --newer-noncurrent-versions)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__edit)
            opts="-q -H -h -V --id --expiry-days --expiry-date --transition-days --transition-date --storage-class --noncurrent-expiry-days --noncurrent-transition-days --noncurrent-transition-storage-class --prefix --expired-object-delete-marker --newer-noncurrent-versions --disable --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --expiry-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --expiry-date)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --transition-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --transition-date)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --noncurrent-expiry-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --noncurrent-transition-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --noncurrent-transition-storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --prefix)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --expired-object-delete-marker)
                    COMPREPLY=($(compgen -W "true false" -- "${cur}"))
                    return 0
                    ;;
                --newer-noncurrent-versions)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --disable)
                    COMPREPLY=($(compgen -W "true false" -- "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__export)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help)
            opts="add edit list remove export import help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help__subcmd__edit)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help__subcmd__export)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help__subcmd__import)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__help__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__import)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__list)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__remove)
            opts="-q -H -h -V --id --all --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version add edit list info remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__add)
            opts="-q -H -h -V --endpoint --access-key --secret-key --bucket --prefix --region --storage-class --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --endpoint)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --access-key)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --secret-key)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --bucket)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --prefix)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --region)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__edit)
            opts="-q -H -h -V --access-key --secret-key --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --access-key)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --secret-key)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help)
            opts="add edit list info remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help__subcmd__edit)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__help__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__info)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__list)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__remove)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__list)
            opts="-r -q -H -h -V --recursive --versions --incomplete --summarize --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__quota)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version set info clear help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__quota__subcmd__clear)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__quota__subcmd__help)
            opts="set info clear help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__quota__subcmd__help__subcmd__clear)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__quota__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__quota__subcmd__help__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__quota__subcmd__help__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__quota__subcmd__info)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__quota__subcmd__set)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__remove)
            opts="-q -H -h -V --force --dangerous --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version add update list status remove export import help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__add)
            opts="-q -H -h -V --remote-bucket --replicate --priority --storage-class --bandwidth --sync --prefix --id --healthcheck-seconds --disable-proxy --insecure --ca-cert --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --remote-bucket)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --replicate)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --priority)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --bandwidth)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --prefix)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --healthcheck-seconds)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --ca-cert)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__export)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__help)
            opts="add update list status remove export import help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__export)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__import)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__help__subcmd__update)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__import)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__list)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__remove)
            opts="-q -H -h -V --id --all --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__status)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__replication__subcmd__update)
            opts="-q -H -h -V --id --replicate --priority --storage-class --bandwidth --sync --prefix --healthcheck-seconds --disable-proxy --insecure --ca-cert --status --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --replicate)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --priority)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --bandwidth)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --sync)
                    COMPREPLY=($(compgen -W "true false" -- "${cur}"))
                    return 0
                    ;;
                --prefix)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --healthcheck-seconds)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --disable-proxy)
                    COMPREPLY=($(compgen -W "true false" -- "${cur}"))
                    return 0
                    ;;
                --ca-cert)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --status)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__version)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version enable suspend info list help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__version__subcmd__enable)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__version__subcmd__help)
            opts="enable suspend info list help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__version__subcmd__help__subcmd__enable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__version__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__version__subcmd__help__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__version__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__version__subcmd__help__subcmd__suspend)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__version__subcmd__info)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__version__subcmd__list)
            opts="-n -q -H -h -V --max --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --max)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -n)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__bucket__subcmd__version__subcmd__suspend)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__cat)
            opts="-q -H -h -V --enc-key --rewind --version-id --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --enc-key)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --rewind)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --version-id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__completions)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version bash elvish fish powershell zsh"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__cors)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version list set remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__cors__subcmd__help)
            opts="list set remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__cors__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__cors__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__cors__subcmd__help__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__cors__subcmd__help__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__cors__subcmd__list)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__cors__subcmd__remove)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__cors__subcmd__set)
            opts="-q -H -h -V --file --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --file)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__cp)
            opts="-r -p -q -H -h -V --recursive --preserve --continue-on-error --overwrite --dry-run --storage-class --content-type --enc-s3 --enc-kms --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --content-type)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --enc-s3)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --enc-kms)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__diff)
            opts="-r -q -H -h -V --recursive --diff-only --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__event)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version add list remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__event__subcmd__add)
            opts="-q -H -h -V --event --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --event)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__event__subcmd__help)
            opts="add list remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__event__subcmd__help__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__event__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__event__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__event__subcmd__help__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__event__subcmd__list)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__event__subcmd__remove)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__find)
            opts="-q -H -h -V --name --larger --smaller --newer --older --maxdepth --count --exec --print --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --name)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --larger)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --smaller)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --newer)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --older)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --maxdepth)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --exec)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__head)
            opts="-n -c -q -H -h -V --lines --bytes --version-id --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --lines)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -n)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --bytes)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -c)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --version-id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help)
            opts="alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin)
            opts="info heal pool expand decommission rebalance user policy group service-account access-key service replicate"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__access__subcmd__key)
            opts="info"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__access__subcmd__key__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__decommission)
            opts="start status cancel clear"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__decommission__subcmd__cancel)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__decommission__subcmd__clear)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__decommission__subcmd__start)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__decommission__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__expand)
            opts="start status stop"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__expand__subcmd__start)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__expand__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__expand__subcmd__stop)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__group)
            opts="ls add info rm enable disable add-members rm-members"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__add__subcmd__members)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__disable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__enable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__ls)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__rm)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__group__subcmd__rm__subcmd__members)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__heal)
            opts="status start stop"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__heal__subcmd__start)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__heal__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__heal__subcmd__stop)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__info)
            opts="cluster server disk"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__info__subcmd__cluster)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__info__subcmd__disk)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__info__subcmd__server)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__policy)
            opts="ls create info rm attach"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__policy__subcmd__attach)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__policy__subcmd__create)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__policy__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__policy__subcmd__ls)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__policy__subcmd__rm)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__pool)
            opts="list status"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__pool__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__pool__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__rebalance)
            opts="start status stop"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__rebalance__subcmd__start)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__rebalance__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__rebalance__subcmd__stop)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__replicate)
            opts="add info status remove"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__replicate__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__replicate__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__replicate__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__replicate__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__service)
            opts="restart stop freeze unfreeze"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__account)
            opts="ls create info rm"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__account__subcmd__create)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__account__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__account__subcmd__ls)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__account__subcmd__rm)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__freeze)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__restart)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__stop)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__service__subcmd__unfreeze)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__user)
            opts="ls add info rm enable disable"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__user__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__user__subcmd__disable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__user__subcmd__enable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__user__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__user__subcmd__ls)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__admin__subcmd__user__subcmd__rm)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__alias)
            opts="set list remove"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__alias__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__alias__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__alias__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__anonymous)
            opts="set set-json get get-json list links"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__anonymous__subcmd__get)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__anonymous__subcmd__get__subcmd__json)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__anonymous__subcmd__links)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__anonymous__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__anonymous__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__anonymous__subcmd__set__subcmd__json)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket)
            opts="list create remove event cors encryption version quota anonymous lifecycle replication"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__anonymous)
            opts="set set-json get get-json list links"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__anonymous__subcmd__get)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__anonymous__subcmd__get__subcmd__json)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__anonymous__subcmd__links)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__anonymous__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__anonymous__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__anonymous__subcmd__set__subcmd__json)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__cors)
            opts="list set remove"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__cors__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__cors__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__cors__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__create)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__encryption)
            opts="set info clear"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__encryption__subcmd__clear)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__encryption__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__encryption__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__event)
            opts="add list remove"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__event__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__event__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__event__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__lifecycle)
            opts="rule tier restore"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__restore)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule)
            opts="add edit list remove export import"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__edit)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__export)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__import)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__rule__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier)
            opts="add edit list info remove"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__edit)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__lifecycle__subcmd__tier__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 6 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__quota)
            opts="set info clear"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__quota__subcmd__clear)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__quota__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__quota__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__replication)
            opts="add update list status remove export import"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__replication__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__replication__subcmd__export)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__replication__subcmd__import)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__replication__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__replication__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__replication__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__replication__subcmd__update)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__version)
            opts="enable suspend info list"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__version__subcmd__enable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__version__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__version__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__bucket__subcmd__version__subcmd__suspend)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__cat)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__completions)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__cors)
            opts="list set remove"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__cors__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__cors__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__cors__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__cp)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__diff)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__event)
            opts="add list remove"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__event__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__event__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__event__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__find)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__head)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ilm)
            opts="rule tier restore"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ilm__subcmd__restore)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ilm__subcmd__rule)
            opts="add edit list remove export import"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ilm__subcmd__rule__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ilm__subcmd__rule__subcmd__edit)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ilm__subcmd__rule__subcmd__export)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ilm__subcmd__rule__subcmd__import)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ilm__subcmd__rule__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ilm__subcmd__rule__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ilm__subcmd__tier)
            opts="add edit list info remove"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ilm__subcmd__tier__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ilm__subcmd__tier__subcmd__edit)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ilm__subcmd__tier__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ilm__subcmd__tier__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ilm__subcmd__tier__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__ls)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__mb)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__mirror)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__mv)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__object)
            opts="list copy move remove stat show head find tree share"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__object__subcmd__copy)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__object__subcmd__find)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__object__subcmd__head)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__object__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__object__subcmd__move)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__object__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__object__subcmd__share)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__object__subcmd__show)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__object__subcmd__stat)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__object__subcmd__tree)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__pipe)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__quota)
            opts="set info clear"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__quota__subcmd__clear)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__quota__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__quota__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__rb)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__replicate)
            opts="add update list status remove export import"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__replicate__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__replicate__subcmd__export)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__replicate__subcmd__import)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__replicate__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__replicate__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__replicate__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__replicate__subcmd__update)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__rm)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__share)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__sql)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__stat)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__tag)
            opts="list set remove"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__tag__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__tag__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__tag__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__tree)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__version)
            opts="enable suspend info list"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__version__subcmd__enable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__version__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__version__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__help__subcmd__version__subcmd__suspend)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version rule tier restore help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help)
            opts="rule tier restore help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help__subcmd__restore)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help__subcmd__rule)
            opts="add edit list remove export import"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help__subcmd__rule__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help__subcmd__rule__subcmd__edit)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help__subcmd__rule__subcmd__export)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help__subcmd__rule__subcmd__import)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help__subcmd__rule__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help__subcmd__rule__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help__subcmd__tier)
            opts="add edit list info remove"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help__subcmd__tier__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help__subcmd__tier__subcmd__edit)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help__subcmd__tier__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help__subcmd__tier__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__help__subcmd__tier__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__restore)
            opts="-q -H -h -V --days --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__rule)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version add edit list remove export import help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__rule__subcmd__add)
            opts="-q -H -h -V --expiry-days --expiry-date --transition-days --transition-date --storage-class --noncurrent-expiry-days --noncurrent-transition-days --noncurrent-transition-storage-class --prefix --expired-object-delete-marker --newer-noncurrent-versions --disable --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --expiry-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --expiry-date)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --transition-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --transition-date)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --noncurrent-expiry-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --noncurrent-transition-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --noncurrent-transition-storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --prefix)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --newer-noncurrent-versions)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__rule__subcmd__edit)
            opts="-q -H -h -V --id --expiry-days --expiry-date --transition-days --transition-date --storage-class --noncurrent-expiry-days --noncurrent-transition-days --noncurrent-transition-storage-class --prefix --expired-object-delete-marker --newer-noncurrent-versions --disable --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --expiry-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --expiry-date)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --transition-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --transition-date)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --noncurrent-expiry-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --noncurrent-transition-days)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --noncurrent-transition-storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --prefix)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --expired-object-delete-marker)
                    COMPREPLY=($(compgen -W "true false" -- "${cur}"))
                    return 0
                    ;;
                --newer-noncurrent-versions)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --disable)
                    COMPREPLY=($(compgen -W "true false" -- "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__rule__subcmd__export)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__rule__subcmd__help)
            opts="add edit list remove export import help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__rule__subcmd__help__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__rule__subcmd__help__subcmd__edit)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__rule__subcmd__help__subcmd__export)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__rule__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__rule__subcmd__help__subcmd__import)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__rule__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__rule__subcmd__help__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__rule__subcmd__import)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__rule__subcmd__list)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__rule__subcmd__remove)
            opts="-q -H -h -V --id --all --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__tier)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version add edit list info remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__tier__subcmd__add)
            opts="-q -H -h -V --endpoint --access-key --secret-key --bucket --prefix --region --storage-class --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --endpoint)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --access-key)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --secret-key)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --bucket)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --prefix)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --region)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__tier__subcmd__edit)
            opts="-q -H -h -V --access-key --secret-key --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --access-key)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --secret-key)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__tier__subcmd__help)
            opts="add edit list info remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__tier__subcmd__help__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__tier__subcmd__help__subcmd__edit)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__tier__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__tier__subcmd__help__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__tier__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__tier__subcmd__help__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 5 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__tier__subcmd__info)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__tier__subcmd__list)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ilm__subcmd__tier__subcmd__remove)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__ls)
            opts="-r -q -H -h -V --recursive --versions --incomplete --summarize --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__mb)
            opts="-p -q -H -h -V --ignore-existing --region --with-lock --with-versioning --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --region)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__mirror)
            opts="-n -P -H -h -V --remove --overwrite --dry-run --parallel --quiet --format --json --no-color --no-progress --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --parallel)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -P)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__mv)
            opts="-r -q -H -h -V --recursive --continue-on-error --dry-run --enc-s3 --enc-kms --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --enc-s3)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --enc-kms)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version list copy move remove stat show head find tree share help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__copy)
            opts="-r -p -q -H -h -V --recursive --preserve --continue-on-error --overwrite --dry-run --storage-class --content-type --enc-s3 --enc-kms --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --content-type)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --enc-s3)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --enc-kms)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__find)
            opts="-q -H -h -V --name --larger --smaller --newer --older --maxdepth --count --exec --print --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --name)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --larger)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --smaller)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --newer)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --older)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --maxdepth)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --exec)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__head)
            opts="-n -c -q -H -h -V --lines --bytes --version-id --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --lines)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -n)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --bytes)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -c)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --version-id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__help)
            opts="list copy move remove stat show head find tree share help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__help__subcmd__copy)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__help__subcmd__find)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__help__subcmd__head)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__help__subcmd__move)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__help__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__help__subcmd__share)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__help__subcmd__show)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__help__subcmd__stat)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__help__subcmd__tree)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__list)
            opts="-r -q -H -h -V --recursive --versions --incomplete --summarize --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__move)
            opts="-r -q -H -h -V --recursive --continue-on-error --dry-run --enc-s3 --enc-kms --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --enc-s3)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --enc-kms)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__remove)
            opts="-r -f -q -H -h -V --recursive --force --dry-run --incomplete --versions --bypass --purge --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__share)
            opts="-e -q -H -h -V --expire --upload --content-type --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --expire)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -e)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --content-type)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__show)
            opts="-q -H -h -V --enc-key --rewind --version-id --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --enc-key)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --rewind)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --version-id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__stat)
            opts="-q -H -h -V --version-id --rewind --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --version-id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --rewind)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__object__subcmd__tree)
            opts="-L -s -d -P -f -q -H -h -V --level --size --dirs-only --pattern --full-path --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --level)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -L)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --pattern)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -P)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__pipe)
            opts="-q -H -h -V --content-type --storage-class --enc-s3 --enc-kms --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --content-type)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --enc-kms)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__quota)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version set info clear help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__quota__subcmd__clear)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__quota__subcmd__help)
            opts="set info clear help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__quota__subcmd__help__subcmd__clear)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__quota__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__quota__subcmd__help__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__quota__subcmd__help__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__quota__subcmd__info)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__quota__subcmd__set)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__rb)
            opts="-q -H -h -V --force --dangerous --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version add update list status remove export import help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__add)
            opts="-q -H -h -V --remote-bucket --replicate --priority --storage-class --bandwidth --sync --prefix --id --healthcheck-seconds --disable-proxy --insecure --ca-cert --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --remote-bucket)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --replicate)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --priority)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --bandwidth)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --prefix)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --healthcheck-seconds)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --ca-cert)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__export)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__help)
            opts="add update list status remove export import help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__help__subcmd__add)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__help__subcmd__export)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__help__subcmd__import)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__help__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__help__subcmd__status)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__help__subcmd__update)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__import)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__list)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__remove)
            opts="-q -H -h -V --id --all --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__status)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__replicate__subcmd__update)
            opts="-q -H -h -V --id --replicate --priority --storage-class --bandwidth --sync --prefix --healthcheck-seconds --disable-proxy --insecure --ca-cert --status --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --replicate)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --priority)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --storage-class)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --bandwidth)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --sync)
                    COMPREPLY=($(compgen -W "true false" -- "${cur}"))
                    return 0
                    ;;
                --prefix)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --healthcheck-seconds)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --disable-proxy)
                    COMPREPLY=($(compgen -W "true false" -- "${cur}"))
                    return 0
                    ;;
                --ca-cert)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --status)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__rm)
            opts="-r -f -q -H -h -V --recursive --force --dry-run --incomplete --versions --bypass --purge --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__share)
            opts="-e -q -H -h -V --expire --upload --content-type --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --expire)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -e)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --content-type)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__sql)
            opts="-q -H -h -V --query --input-format --output-format --compression --csv-file-header-info --csv-input-field-delimiter --csv-input-quote --csv-input-quote-escape --csv-input-comment --csv-output-field-delimiter --csv-output-record-delimiter --csv-output-quote --csv-output-quote-escape --csv-output-quote-fields --json-type --json-output-record-delimiter --scan-start --scan-end --sse-customer-algorithm --sse-customer-key --sse-customer-key-md5 --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --query)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --input-format)
                    COMPREPLY=($(compgen -W "csv json parquet" -- "${cur}"))
                    return 0
                    ;;
                --output-format)
                    COMPREPLY=($(compgen -W "csv json" -- "${cur}"))
                    return 0
                    ;;
                --compression)
                    COMPREPLY=($(compgen -W "none gzip bzip2" -- "${cur}"))
                    return 0
                    ;;
                --csv-file-header-info)
                    COMPREPLY=($(compgen -W "none ignore use" -- "${cur}"))
                    return 0
                    ;;
                --csv-input-field-delimiter)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --csv-input-quote)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --csv-input-quote-escape)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --csv-input-comment)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --csv-output-field-delimiter)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --csv-output-record-delimiter)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --csv-output-quote)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --csv-output-quote-escape)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --csv-output-quote-fields)
                    COMPREPLY=($(compgen -W "always as-needed" -- "${cur}"))
                    return 0
                    ;;
                --json-type)
                    COMPREPLY=($(compgen -W "lines document" -- "${cur}"))
                    return 0
                    ;;
                --json-output-record-delimiter)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --scan-start)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --scan-end)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --sse-customer-algorithm)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --sse-customer-key)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --sse-customer-key-md5)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__stat)
            opts="-q -H -h -V --version-id --rewind --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --version-id)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --rewind)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__tag)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version list set remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__tag__subcmd__help)
            opts="list set remove help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__tag__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__tag__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__tag__subcmd__help__subcmd__remove)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__tag__subcmd__help__subcmd__set)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__tag__subcmd__list)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__tag__subcmd__remove)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__tag__subcmd__set)
            opts="-t -q -H -h -V --tags --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --tags)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -t)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__tree)
            opts="-L -s -d -P -f -q -H -h -V --level --size --dirs-only --pattern --full-path --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --level)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -L)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --pattern)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -P)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__version)
            opts="-q -H -h -V --format --json --no-color --no-progress --quiet --debug --header --help --version enable suspend info list help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 2 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__version__subcmd__enable)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__version__subcmd__help)
            opts="enable suspend info list help"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__version__subcmd__help__subcmd__enable)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__version__subcmd__help__subcmd__help)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__version__subcmd__help__subcmd__info)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__version__subcmd__help__subcmd__list)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__version__subcmd__help__subcmd__suspend)
            opts=""
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 4 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__version__subcmd__info)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__version__subcmd__list)
            opts="-n -q -H -h -V --max --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --max)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -n)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
        rc__subcmd__version__subcmd__suspend)
            opts="-q -H -h -V --force --format --json --no-color --no-progress --quiet --debug --header --help --version"
            if [[ ${cur} == -* || ${COMP_CWORD} -eq 3 ]] ; then
                COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
                return 0
            fi
            case "${prev}" in
                --format)
                    COMPREPLY=($(compgen -W "auto human json" -- "${cur}"))
                    return 0
                    ;;
                --header)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                -H)
                    COMPREPLY=($(compgen -f "${cur}"))
                    return 0
                    ;;
                *)
                    COMPREPLY=()
                    ;;
            esac
            COMPREPLY=( $(compgen -W "${opts}" -- "${cur}") )
            return 0
            ;;
    esac
}

if [[ "${BASH_VERSINFO[0]}" -eq 4 && "${BASH_VERSINFO[1]}" -ge 4 || "${BASH_VERSINFO[0]}" -gt 4 ]]; then
    complete -F _rc -o nosort -o bashdefault -o default rc
else
    complete -F _rc -o bashdefault -o default rc
fi
