
using namespace System.Management.Automation
using namespace System.Management.Automation.Language

Register-ArgumentCompleter -Native -CommandName 'rc' -ScriptBlock {
    param($wordToComplete, $commandAst, $cursorPosition)

    $commandElements = $commandAst.CommandElements
    $command = @(
        'rc'
        for ($i = 1; $i -lt $commandElements.Count; $i++) {
            $element = $commandElements[$i]
            if ($element -isnot [StringConstantExpressionAst] -or
                $element.StringConstantType -ne [StringConstantType]::BareWord -or
                $element.Value.StartsWith('-') -or
                $element.Value -eq $wordToComplete) {
                break
        }
        $element.Value
    }) -join ';'

    $completions = @(switch ($command) {
        'rc' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('alias', 'alias', [CompletionResultType]::ParameterValue, 'Manage storage service aliases')
            [CompletionResult]::new('admin', 'admin', [CompletionResultType]::ParameterValue, 'Manage IAM users, policies, groups, and service accounts')
            [CompletionResult]::new('bucket', 'bucket', [CompletionResultType]::ParameterValue, 'Manage bucket-oriented workflows')
            [CompletionResult]::new('object', 'object', [CompletionResultType]::ParameterValue, 'Manage object-oriented workflows')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket list` or `rc object list`')
            [CompletionResult]::new('mb', 'mb', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket create`')
            [CompletionResult]::new('rb', 'rb', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket remove`')
            [CompletionResult]::new('cat', 'cat', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object show`')
            [CompletionResult]::new('head', 'head', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object head`')
            [CompletionResult]::new('stat', 'stat', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object stat`')
            [CompletionResult]::new('cp', 'cp', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object copy`')
            [CompletionResult]::new('mv', 'mv', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object move`')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object remove`')
            [CompletionResult]::new('pipe', 'pipe', [CompletionResultType]::ParameterValue, 'Stream stdin to an object')
            [CompletionResult]::new('find', 'find', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object find`')
            [CompletionResult]::new('event', 'event', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket event`')
            [CompletionResult]::new('cors', 'cors', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket cors`')
            [CompletionResult]::new('diff', 'diff', [CompletionResultType]::ParameterValue, 'Show differences between locations')
            [CompletionResult]::new('mirror', 'mirror', [CompletionResultType]::ParameterValue, 'Mirror objects between locations')
            [CompletionResult]::new('tree', 'tree', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object tree`')
            [CompletionResult]::new('share', 'share', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object share`')
            [CompletionResult]::new('sql', 'sql', [CompletionResultType]::ParameterValue, 'Run S3 Select SQL on an object')
            [CompletionResult]::new('version', 'version', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket version`')
            [CompletionResult]::new('tag', 'tag', [CompletionResultType]::ParameterValue, 'Manage bucket and object tags')
            [CompletionResult]::new('anonymous', 'anonymous', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket anonymous`')
            [CompletionResult]::new('quota', 'quota', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket quota`')
            [CompletionResult]::new('ilm', 'ilm', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket lifecycle`')
            [CompletionResult]::new('replicate', 'replicate', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket replication`')
            [CompletionResult]::new('completions', 'completions', [CompletionResultType]::ParameterValue, 'Generate shell completion scripts')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;alias' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Add or update an alias')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List all configured aliases')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove an alias')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;alias;set' {
            [CompletionResult]::new('--client-cert', '--client-cert', [CompletionResultType]::ParameterName, 'Path to PEM client certificate for mTLS')
            [CompletionResult]::new('--client-key', '--client-key', [CompletionResultType]::ParameterName, 'Path to PEM client private key for mTLS')
            [CompletionResult]::new('--region', '--region', [CompletionResultType]::ParameterName, 'AWS region (default: us-east-1)')
            [CompletionResult]::new('--signature', '--signature', [CompletionResultType]::ParameterName, 'Signature version (only v4 is currently supported)')
            [CompletionResult]::new('--bucket-lookup', '--bucket-lookup', [CompletionResultType]::ParameterName, 'Bucket lookup style: auto, path, or dns (default: auto)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--anonymous', '--anonymous', [CompletionResultType]::ParameterName, 'Send requests without SigV4 credentials')
            [CompletionResult]::new('--insecure', '--insecure', [CompletionResultType]::ParameterName, 'Allow insecure TLS connections')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;alias;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-l', '-l', [CompletionResultType]::ParameterName, 'Show full details including endpoints')
            [CompletionResult]::new('--long', '--long', [CompletionResultType]::ParameterName, 'Show full details including endpoints')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;alias;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;alias;help' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Add or update an alias')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List all configured aliases')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove an alias')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;alias;help;set' {
            break
        }
        'rc;alias;help;list' {
            break
        }
        'rc;alias;help;remove' {
            break
        }
        'rc;alias;help;help' {
            break
        }
        'rc;admin' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Display cluster information (servers, disks, usage)')
            [CompletionResult]::new('heal', 'heal', [CompletionResultType]::ParameterValue, 'Manage cluster healing operations')
            [CompletionResult]::new('pool', 'pool', [CompletionResultType]::ParameterValue, 'Manage server pools and expansion status')
            [CompletionResult]::new('expand', 'expand', [CompletionResultType]::ParameterValue, 'Manage post-expansion data rebalancing')
            [CompletionResult]::new('decommission', 'decommission', [CompletionResultType]::ParameterValue, 'Manage server pool decommissioning')
            [CompletionResult]::new('rebalance', 'rebalance', [CompletionResultType]::ParameterValue, 'Manage post-expansion rebalancing')
            [CompletionResult]::new('user', 'user', [CompletionResultType]::ParameterValue, 'Manage IAM users')
            [CompletionResult]::new('policy', 'policy', [CompletionResultType]::ParameterValue, 'Manage IAM policies')
            [CompletionResult]::new('group', 'group', [CompletionResultType]::ParameterValue, 'Manage IAM groups')
            [CompletionResult]::new('service-account', 'service-account', [CompletionResultType]::ParameterValue, 'Manage service accounts')
            [CompletionResult]::new('access-key', 'access-key', [CompletionResultType]::ParameterValue, 'Inspect access key identities')
            [CompletionResult]::new('service', 'service', [CompletionResultType]::ParameterValue, 'Control the server process (restart, stop, freeze, unfreeze)')
            [CompletionResult]::new('replicate', 'replicate', [CompletionResultType]::ParameterValue, 'Manage site replication across clusters')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('cluster', 'cluster', [CompletionResultType]::ParameterValue, 'Display cluster overview information')
            [CompletionResult]::new('server', 'server', [CompletionResultType]::ParameterValue, 'Display server information')
            [CompletionResult]::new('disk', 'disk', [CompletionResultType]::ParameterValue, 'Display disk information')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;info;cluster' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;info;server' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;info;disk' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--offline', '--offline', [CompletionResultType]::ParameterName, 'Show only offline disks')
            [CompletionResult]::new('--healing', '--healing', [CompletionResultType]::ParameterName, 'Show only healing disks')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;info;help' {
            [CompletionResult]::new('cluster', 'cluster', [CompletionResultType]::ParameterValue, 'Display cluster overview information')
            [CompletionResult]::new('server', 'server', [CompletionResultType]::ParameterValue, 'Display server information')
            [CompletionResult]::new('disk', 'disk', [CompletionResultType]::ParameterValue, 'Display disk information')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;info;help;cluster' {
            break
        }
        'rc;admin;info;help;server' {
            break
        }
        'rc;admin;info;help;disk' {
            break
        }
        'rc;admin;info;help;help' {
            break
        }
        'rc;admin;heal' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display current heal status')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a heal operation')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running heal operation')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;heal;status' {
            [CompletionResult]::new('-b', '-b', [CompletionResultType]::ParameterName, 'Bucket for token-scoped manual heal task status')
            [CompletionResult]::new('--bucket', '--bucket', [CompletionResultType]::ParameterName, 'Bucket for token-scoped manual heal task status')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Object prefix for token-scoped manual heal task status')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Object prefix for token-scoped manual heal task status')
            [CompletionResult]::new('--client-token', '--client-token', [CompletionResultType]::ParameterName, 'Client token returned by heal start')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;heal;start' {
            [CompletionResult]::new('-b', '-b', [CompletionResultType]::ParameterName, 'Bucket to heal; omit to recursively heal all buckets')
            [CompletionResult]::new('--bucket', '--bucket', [CompletionResultType]::ParameterName, 'Bucket to heal; omit to recursively heal all buckets')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Object prefix to heal')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Object prefix to heal')
            [CompletionResult]::new('--scan-mode', '--scan-mode', [CompletionResultType]::ParameterName, 'Scan mode (normal or deep)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--remove', '--remove', [CompletionResultType]::ParameterName, 'Remove dangling objects/parts')
            [CompletionResult]::new('--recreate', '--recreate', [CompletionResultType]::ParameterName, 'Recreate missing data')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Dry run mode - show what would be healed without actually healing')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;heal;stop' {
            [CompletionResult]::new('-b', '-b', [CompletionResultType]::ParameterName, 'Bucket for token-scoped manual heal task stop')
            [CompletionResult]::new('--bucket', '--bucket', [CompletionResultType]::ParameterName, 'Bucket for token-scoped manual heal task stop')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Object prefix for token-scoped manual heal task stop')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Object prefix for token-scoped manual heal task stop')
            [CompletionResult]::new('--client-token', '--client-token', [CompletionResultType]::ParameterName, 'Client token returned by heal start')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;heal;help' {
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display current heal status')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a heal operation')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running heal operation')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;heal;help;status' {
            break
        }
        'rc;admin;heal;help;start' {
            break
        }
        'rc;admin;heal;help;stop' {
            break
        }
        'rc;admin;heal;help;help' {
            break
        }
        'rc;admin;pool' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List server pools')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show server pool status')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;pool;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;pool;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--by-id', '--by-id', [CompletionResultType]::ParameterName, 'Interpret POOL as a zero-based pool ID')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;pool;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List server pools')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show server pool status')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;pool;help;list' {
            break
        }
        'rc;admin;pool;help;status' {
            break
        }
        'rc;admin;pool;help;help' {
            break
        }
        'rc;admin;expand' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start post-expansion data rebalancing')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show post-expansion rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running post-expansion rebalance')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;expand;start' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;expand;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;expand;stop' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;expand;help' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start post-expansion data rebalancing')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show post-expansion rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running post-expansion rebalance')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;expand;help;start' {
            break
        }
        'rc;admin;expand;help;status' {
            break
        }
        'rc;admin;expand;help;stop' {
            break
        }
        'rc;admin;expand;help;help' {
            break
        }
        'rc;admin;decommission' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start decommissioning a pool')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show decommissioning status')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Cancel decommissioning a pool')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear failed or canceled decommissioning metadata for a pool')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;decommission;start' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--by-id', '--by-id', [CompletionResultType]::ParameterName, 'Interpret POOL as zero-based pool ID values')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;decommission;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--by-id', '--by-id', [CompletionResultType]::ParameterName, 'Interpret POOL as a zero-based pool ID')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;decommission;cancel' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--by-id', '--by-id', [CompletionResultType]::ParameterName, 'Interpret POOL as a zero-based pool ID')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;decommission;clear' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--by-id', '--by-id', [CompletionResultType]::ParameterName, 'Interpret POOL as a zero-based pool ID')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;decommission;help' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start decommissioning a pool')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show decommissioning status')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Cancel decommissioning a pool')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear failed or canceled decommissioning metadata for a pool')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;decommission;help;start' {
            break
        }
        'rc;admin;decommission;help;status' {
            break
        }
        'rc;admin;decommission;help;cancel' {
            break
        }
        'rc;admin;decommission;help;clear' {
            break
        }
        'rc;admin;decommission;help;help' {
            break
        }
        'rc;admin;rebalance' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a rebalance operation')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running rebalance operation')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;rebalance;start' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;rebalance;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;rebalance;stop' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;rebalance;help' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a rebalance operation')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running rebalance operation')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;rebalance;help;start' {
            break
        }
        'rc;admin;rebalance;help;status' {
            break
        }
        'rc;admin;rebalance;help;stop' {
            break
        }
        'rc;admin;rebalance;help;help' {
            break
        }
        'rc;admin;user' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all users')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new user')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get user information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a user')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a user')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a user')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;user;ls' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;user;add' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;user;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;user;rm' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;user;enable' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;user;disable' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;user;help' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all users')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new user')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get user information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a user')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a user')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a user')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;user;help;ls' {
            break
        }
        'rc;admin;user;help;add' {
            break
        }
        'rc;admin;user;help;info' {
            break
        }
        'rc;admin;user;help;rm' {
            break
        }
        'rc;admin;user;help;enable' {
            break
        }
        'rc;admin;user;help;disable' {
            break
        }
        'rc;admin;user;help;help' {
            break
        }
        'rc;admin;policy' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all policies')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new policy')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get policy information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a policy')
            [CompletionResult]::new('attach', 'attach', [CompletionResultType]::ParameterValue, 'Attach policy to a user or group')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;policy;ls' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;policy;create' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;policy;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;policy;rm' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;policy;attach' {
            [CompletionResult]::new('--user', '--user', [CompletionResultType]::ParameterName, 'Target user access key')
            [CompletionResult]::new('--group', '--group', [CompletionResultType]::ParameterName, 'Target group name')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;policy;help' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all policies')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new policy')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get policy information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a policy')
            [CompletionResult]::new('attach', 'attach', [CompletionResultType]::ParameterValue, 'Attach policy to a user or group')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;policy;help;ls' {
            break
        }
        'rc;admin;policy;help;create' {
            break
        }
        'rc;admin;policy;help;info' {
            break
        }
        'rc;admin;policy;help;rm' {
            break
        }
        'rc;admin;policy;help;attach' {
            break
        }
        'rc;admin;policy;help;help' {
            break
        }
        'rc;admin;group' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all groups')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Create a new group')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get group information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a group')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a group')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a group')
            [CompletionResult]::new('add-members', 'add-members', [CompletionResultType]::ParameterValue, 'Add members to a group')
            [CompletionResult]::new('rm-members', 'rm-members', [CompletionResultType]::ParameterValue, 'Remove members from a group')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;group;ls' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;add' {
            [CompletionResult]::new('--members', '--members', [CompletionResultType]::ParameterName, 'Initial members (comma-separated access keys)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;rm' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;enable' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;disable' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;add-members' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;rm-members' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;group;help' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all groups')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Create a new group')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get group information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a group')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a group')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a group')
            [CompletionResult]::new('add-members', 'add-members', [CompletionResultType]::ParameterValue, 'Add members to a group')
            [CompletionResult]::new('rm-members', 'rm-members', [CompletionResultType]::ParameterValue, 'Remove members from a group')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;group;help;ls' {
            break
        }
        'rc;admin;group;help;add' {
            break
        }
        'rc;admin;group;help;info' {
            break
        }
        'rc;admin;group;help;rm' {
            break
        }
        'rc;admin;group;help;enable' {
            break
        }
        'rc;admin;group;help;disable' {
            break
        }
        'rc;admin;group;help;add-members' {
            break
        }
        'rc;admin;group;help;rm-members' {
            break
        }
        'rc;admin;group;help;help' {
            break
        }
        'rc;admin;service-account' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List service accounts')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new service account')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get service account information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a service account')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;service-account;ls' {
            [CompletionResult]::new('--user', '--user', [CompletionResultType]::ParameterName, 'Filter by parent user')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service-account;create' {
            [CompletionResult]::new('--name', '--name', [CompletionResultType]::ParameterName, 'Optional name for the service account')
            [CompletionResult]::new('--description', '--description', [CompletionResultType]::ParameterName, 'Optional description')
            [CompletionResult]::new('--policy', '--policy', [CompletionResultType]::ParameterName, 'Optional policy document (JSON file path)')
            [CompletionResult]::new('--expiry', '--expiry', [CompletionResultType]::ParameterName, 'Optional expiration time (ISO 8601 format)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service-account;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service-account;rm' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service-account;help' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List service accounts')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new service account')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get service account information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a service account')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;service-account;help;ls' {
            break
        }
        'rc;admin;service-account;help;create' {
            break
        }
        'rc;admin;service-account;help;info' {
            break
        }
        'rc;admin;service-account;help;rm' {
            break
        }
        'rc;admin;service-account;help;help' {
            break
        }
        'rc;admin;access-key' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get access key information')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;access-key;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;access-key;help' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get access key information')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;access-key;help;info' {
            break
        }
        'rc;admin;access-key;help;help' {
            break
        }
        'rc;admin;service' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('restart', 'restart', [CompletionResultType]::ParameterValue, 'Restart the server (graceful shutdown; process manager relaunches)')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop the server gracefully')
            [CompletionResult]::new('freeze', 'freeze', [CompletionResultType]::ParameterValue, 'Set the service freeze flag (advisory)')
            [CompletionResult]::new('unfreeze', 'unfreeze', [CompletionResultType]::ParameterValue, 'Clear the service freeze flag')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;service;restart' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service;stop' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service;freeze' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service;unfreeze' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;service;help' {
            [CompletionResult]::new('restart', 'restart', [CompletionResultType]::ParameterValue, 'Restart the server (graceful shutdown; process manager relaunches)')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop the server gracefully')
            [CompletionResult]::new('freeze', 'freeze', [CompletionResultType]::ParameterValue, 'Set the service freeze flag (advisory)')
            [CompletionResult]::new('unfreeze', 'unfreeze', [CompletionResultType]::ParameterValue, 'Clear the service freeze flag')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;service;help;restart' {
            break
        }
        'rc;admin;service;help;stop' {
            break
        }
        'rc;admin;service;help;freeze' {
            break
        }
        'rc;admin;service;help;unfreeze' {
            break
        }
        'rc;admin;service;help;help' {
            break
        }
        'rc;admin;replicate' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add sites (given as alias names) to a site replication cluster')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show site replication configuration')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show site replication status')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove sites from the site replication cluster')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;replicate;add' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;replicate;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;replicate;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--buckets', '--buckets', [CompletionResultType]::ParameterName, 'Include bucket replication status')
            [CompletionResult]::new('--users', '--users', [CompletionResultType]::ParameterName, 'Include user replication status')
            [CompletionResult]::new('--groups', '--groups', [CompletionResultType]::ParameterName, 'Include group replication status')
            [CompletionResult]::new('--policies', '--policies', [CompletionResultType]::ParameterName, 'Include policy replication status')
            [CompletionResult]::new('--metrics', '--metrics', [CompletionResultType]::ParameterName, 'Include replication metrics')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;replicate;remove' {
            [CompletionResult]::new('--site', '--site', [CompletionResultType]::ParameterName, 'Site names to remove from the cluster')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Remove all sites (dissolve the cluster)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;admin;replicate;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add sites (given as alias names) to a site replication cluster')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show site replication configuration')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show site replication status')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove sites from the site replication cluster')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;replicate;help;add' {
            break
        }
        'rc;admin;replicate;help;info' {
            break
        }
        'rc;admin;replicate;help;status' {
            break
        }
        'rc;admin;replicate;help;remove' {
            break
        }
        'rc;admin;replicate;help;help' {
            break
        }
        'rc;admin;help' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Display cluster information (servers, disks, usage)')
            [CompletionResult]::new('heal', 'heal', [CompletionResultType]::ParameterValue, 'Manage cluster healing operations')
            [CompletionResult]::new('pool', 'pool', [CompletionResultType]::ParameterValue, 'Manage server pools and expansion status')
            [CompletionResult]::new('expand', 'expand', [CompletionResultType]::ParameterValue, 'Manage post-expansion data rebalancing')
            [CompletionResult]::new('decommission', 'decommission', [CompletionResultType]::ParameterValue, 'Manage server pool decommissioning')
            [CompletionResult]::new('rebalance', 'rebalance', [CompletionResultType]::ParameterValue, 'Manage post-expansion rebalancing')
            [CompletionResult]::new('user', 'user', [CompletionResultType]::ParameterValue, 'Manage IAM users')
            [CompletionResult]::new('policy', 'policy', [CompletionResultType]::ParameterValue, 'Manage IAM policies')
            [CompletionResult]::new('group', 'group', [CompletionResultType]::ParameterValue, 'Manage IAM groups')
            [CompletionResult]::new('service-account', 'service-account', [CompletionResultType]::ParameterValue, 'Manage service accounts')
            [CompletionResult]::new('access-key', 'access-key', [CompletionResultType]::ParameterValue, 'Inspect access key identities')
            [CompletionResult]::new('service', 'service', [CompletionResultType]::ParameterValue, 'Control the server process (restart, stop, freeze, unfreeze)')
            [CompletionResult]::new('replicate', 'replicate', [CompletionResultType]::ParameterValue, 'Manage site replication across clusters')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;admin;help;info' {
            [CompletionResult]::new('cluster', 'cluster', [CompletionResultType]::ParameterValue, 'Display cluster overview information')
            [CompletionResult]::new('server', 'server', [CompletionResultType]::ParameterValue, 'Display server information')
            [CompletionResult]::new('disk', 'disk', [CompletionResultType]::ParameterValue, 'Display disk information')
            break
        }
        'rc;admin;help;info;cluster' {
            break
        }
        'rc;admin;help;info;server' {
            break
        }
        'rc;admin;help;info;disk' {
            break
        }
        'rc;admin;help;heal' {
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display current heal status')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a heal operation')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running heal operation')
            break
        }
        'rc;admin;help;heal;status' {
            break
        }
        'rc;admin;help;heal;start' {
            break
        }
        'rc;admin;help;heal;stop' {
            break
        }
        'rc;admin;help;pool' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List server pools')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show server pool status')
            break
        }
        'rc;admin;help;pool;list' {
            break
        }
        'rc;admin;help;pool;status' {
            break
        }
        'rc;admin;help;expand' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start post-expansion data rebalancing')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show post-expansion rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running post-expansion rebalance')
            break
        }
        'rc;admin;help;expand;start' {
            break
        }
        'rc;admin;help;expand;status' {
            break
        }
        'rc;admin;help;expand;stop' {
            break
        }
        'rc;admin;help;decommission' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start decommissioning a pool')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show decommissioning status')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Cancel decommissioning a pool')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear failed or canceled decommissioning metadata for a pool')
            break
        }
        'rc;admin;help;decommission;start' {
            break
        }
        'rc;admin;help;decommission;status' {
            break
        }
        'rc;admin;help;decommission;cancel' {
            break
        }
        'rc;admin;help;decommission;clear' {
            break
        }
        'rc;admin;help;rebalance' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a rebalance operation')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running rebalance operation')
            break
        }
        'rc;admin;help;rebalance;start' {
            break
        }
        'rc;admin;help;rebalance;status' {
            break
        }
        'rc;admin;help;rebalance;stop' {
            break
        }
        'rc;admin;help;user' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all users')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new user')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get user information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a user')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a user')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a user')
            break
        }
        'rc;admin;help;user;ls' {
            break
        }
        'rc;admin;help;user;add' {
            break
        }
        'rc;admin;help;user;info' {
            break
        }
        'rc;admin;help;user;rm' {
            break
        }
        'rc;admin;help;user;enable' {
            break
        }
        'rc;admin;help;user;disable' {
            break
        }
        'rc;admin;help;policy' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all policies')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new policy')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get policy information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a policy')
            [CompletionResult]::new('attach', 'attach', [CompletionResultType]::ParameterValue, 'Attach policy to a user or group')
            break
        }
        'rc;admin;help;policy;ls' {
            break
        }
        'rc;admin;help;policy;create' {
            break
        }
        'rc;admin;help;policy;info' {
            break
        }
        'rc;admin;help;policy;rm' {
            break
        }
        'rc;admin;help;policy;attach' {
            break
        }
        'rc;admin;help;group' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all groups')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Create a new group')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get group information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a group')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a group')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a group')
            [CompletionResult]::new('add-members', 'add-members', [CompletionResultType]::ParameterValue, 'Add members to a group')
            [CompletionResult]::new('rm-members', 'rm-members', [CompletionResultType]::ParameterValue, 'Remove members from a group')
            break
        }
        'rc;admin;help;group;ls' {
            break
        }
        'rc;admin;help;group;add' {
            break
        }
        'rc;admin;help;group;info' {
            break
        }
        'rc;admin;help;group;rm' {
            break
        }
        'rc;admin;help;group;enable' {
            break
        }
        'rc;admin;help;group;disable' {
            break
        }
        'rc;admin;help;group;add-members' {
            break
        }
        'rc;admin;help;group;rm-members' {
            break
        }
        'rc;admin;help;service-account' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List service accounts')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new service account')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get service account information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a service account')
            break
        }
        'rc;admin;help;service-account;ls' {
            break
        }
        'rc;admin;help;service-account;create' {
            break
        }
        'rc;admin;help;service-account;info' {
            break
        }
        'rc;admin;help;service-account;rm' {
            break
        }
        'rc;admin;help;access-key' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get access key information')
            break
        }
        'rc;admin;help;access-key;info' {
            break
        }
        'rc;admin;help;service' {
            [CompletionResult]::new('restart', 'restart', [CompletionResultType]::ParameterValue, 'Restart the server (graceful shutdown; process manager relaunches)')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop the server gracefully')
            [CompletionResult]::new('freeze', 'freeze', [CompletionResultType]::ParameterValue, 'Set the service freeze flag (advisory)')
            [CompletionResult]::new('unfreeze', 'unfreeze', [CompletionResultType]::ParameterValue, 'Clear the service freeze flag')
            break
        }
        'rc;admin;help;service;restart' {
            break
        }
        'rc;admin;help;service;stop' {
            break
        }
        'rc;admin;help;service;freeze' {
            break
        }
        'rc;admin;help;service;unfreeze' {
            break
        }
        'rc;admin;help;replicate' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add sites (given as alias names) to a site replication cluster')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show site replication configuration')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show site replication status')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove sites from the site replication cluster')
            break
        }
        'rc;admin;help;replicate;add' {
            break
        }
        'rc;admin;help;replicate;info' {
            break
        }
        'rc;admin;help;replicate;status' {
            break
        }
        'rc;admin;help;replicate;remove' {
            break
        }
        'rc;admin;help;help' {
            break
        }
        'rc;bucket' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List buckets for an alias, or objects within a bucket path')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a bucket')
            [CompletionResult]::new('event', 'event', [CompletionResultType]::ParameterValue, 'Manage bucket notification rules')
            [CompletionResult]::new('cors', 'cors', [CompletionResultType]::ParameterValue, 'Manage bucket CORS rules')
            [CompletionResult]::new('encryption', 'encryption', [CompletionResultType]::ParameterValue, 'Manage bucket default encryption')
            [CompletionResult]::new('version', 'version', [CompletionResultType]::ParameterValue, 'Manage bucket versioning')
            [CompletionResult]::new('quota', 'quota', [CompletionResultType]::ParameterValue, 'Manage bucket quota')
            [CompletionResult]::new('anonymous', 'anonymous', [CompletionResultType]::ParameterValue, 'Manage anonymous bucket access')
            [CompletionResult]::new('lifecycle', 'lifecycle', [CompletionResultType]::ParameterValue, 'Manage bucket lifecycle rules, tiers, and restores')
            [CompletionResult]::new('replication', 'replication', [CompletionResultType]::ParameterValue, 'Manage bucket replication rules and status')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'List recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'List recursively')
            [CompletionResult]::new('--versions', '--versions', [CompletionResultType]::ParameterName, 'Show versions (requires versioning support)')
            [CompletionResult]::new('--incomplete', '--incomplete', [CompletionResultType]::ParameterName, 'Include incomplete uploads')
            [CompletionResult]::new('--summarize', '--summarize', [CompletionResultType]::ParameterName, 'Summarize output (show totals only)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;create' {
            [CompletionResult]::new('--region', '--region', [CompletionResultType]::ParameterName, 'Region for the bucket (overrides alias default)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Ignore error if bucket already exists')
            [CompletionResult]::new('--ignore-existing', '--ignore-existing', [CompletionResultType]::ParameterName, 'Ignore error if bucket already exists')
            [CompletionResult]::new('--with-lock', '--with-lock', [CompletionResultType]::ParameterName, 'Enable object locking on the bucket')
            [CompletionResult]::new('--with-versioning', '--with-versioning', [CompletionResultType]::ParameterName, 'Enable versioning on the bucket')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force remove even if bucket is not empty (deletes all objects first)')
            [CompletionResult]::new('--dangerous', '--dangerous', [CompletionResultType]::ParameterName, 'Remove bucket even if it has incomplete multipart uploads')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;event' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add or replace a bucket notification rule for an ARN')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket notification rules')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket notification rules by target ARN')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;event;add' {
            [CompletionResult]::new('--event', '--event', [CompletionResultType]::ParameterName, 'Event pattern (repeatable; comma-separated values are also accepted)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;event;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;event;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;event;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add or replace a bucket notification rule for an ARN')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket notification rules')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket notification rules by target ARN')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;event;help;add' {
            break
        }
        'rc;bucket;event;help;list' {
            break
        }
        'rc;bucket;event;help;remove' {
            break
        }
        'rc;bucket;event;help;help' {
            break
        }
        'rc;bucket;cors' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket CORS rules')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Replace bucket CORS rules from a JSON or XML file')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket CORS rules')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;cors;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;cors;set' {
            [CompletionResult]::new('--file', '--file', [CompletionResultType]::ParameterName, 'Path to the CORS configuration file, or ''-'' to read from stdin')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;cors;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;cors;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket CORS rules')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Replace bucket CORS rules from a JSON or XML file')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket CORS rules')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;cors;help;list' {
            break
        }
        'rc;bucket;cors;help;set' {
            break
        }
        'rc;bucket;cors;help;remove' {
            break
        }
        'rc;bucket;cors;help;help' {
            break
        }
        'rc;bucket;encryption' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket default encryption')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket default encryption')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket default encryption')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;encryption;set' {
            [CompletionResult]::new('--mode', '--mode', [CompletionResultType]::ParameterName, 'Default encryption mode')
            [CompletionResult]::new('--key-id', '--key-id', [CompletionResultType]::ParameterName, 'Optional KMS key id for sse-kms mode')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;encryption;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;encryption;clear' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;encryption;help' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket default encryption')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket default encryption')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket default encryption')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;encryption;help;set' {
            break
        }
        'rc;bucket;encryption;help;info' {
            break
        }
        'rc;bucket;encryption;help;clear' {
            break
        }
        'rc;bucket;encryption;help;help' {
            break
        }
        'rc;bucket;version' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable versioning for a bucket')
            [CompletionResult]::new('suspend', 'suspend', [CompletionResultType]::ParameterValue, 'Suspend versioning for a bucket')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get versioning status for a bucket')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List object versions')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;version;enable' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;version;suspend' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;version;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;version;list' {
            [CompletionResult]::new('-n', '-n', [CompletionResultType]::ParameterName, 'Maximum number of versions to show')
            [CompletionResult]::new('--max', '--max', [CompletionResultType]::ParameterName, 'Maximum number of versions to show')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;version;help' {
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable versioning for a bucket')
            [CompletionResult]::new('suspend', 'suspend', [CompletionResultType]::ParameterValue, 'Suspend versioning for a bucket')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get versioning status for a bucket')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List object versions')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;version;help;enable' {
            break
        }
        'rc;bucket;version;help;suspend' {
            break
        }
        'rc;bucket;version;help;info' {
            break
        }
        'rc;bucket;version;help;list' {
            break
        }
        'rc;bucket;version;help;help' {
            break
        }
        'rc;bucket;quota' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket quota')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket quota information')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket quota')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;quota;set' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;quota;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;quota;clear' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;quota;help' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket quota')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket quota information')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket quota')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;quota;help;set' {
            break
        }
        'rc;bucket;quota;help;info' {
            break
        }
        'rc;bucket;quota;help;clear' {
            break
        }
        'rc;bucket;quota;help;help' {
            break
        }
        'rc;bucket;anonymous' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set anonymous access permission')
            [CompletionResult]::new('set-json', 'set-json', [CompletionResultType]::ParameterValue, 'Set anonymous access from a policy JSON file')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get anonymous access permission')
            [CompletionResult]::new('get-json', 'get-json', [CompletionResultType]::ParameterValue, 'Get anonymous policy JSON')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List anonymous policies')
            [CompletionResult]::new('links', 'links', [CompletionResultType]::ParameterValue, 'List public links for anonymous readable prefixes')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;anonymous;set' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;anonymous;set-json' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;anonymous;get' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;anonymous;get-json' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;anonymous;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;anonymous;links' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Recursively list links')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Recursively list links')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;anonymous;help' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set anonymous access permission')
            [CompletionResult]::new('set-json', 'set-json', [CompletionResultType]::ParameterValue, 'Set anonymous access from a policy JSON file')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get anonymous access permission')
            [CompletionResult]::new('get-json', 'get-json', [CompletionResultType]::ParameterValue, 'Get anonymous policy JSON')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List anonymous policies')
            [CompletionResult]::new('links', 'links', [CompletionResultType]::ParameterValue, 'List public links for anonymous readable prefixes')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;anonymous;help;set' {
            break
        }
        'rc;bucket;anonymous;help;set-json' {
            break
        }
        'rc;bucket;anonymous;help;get' {
            break
        }
        'rc;bucket;anonymous;help;get-json' {
            break
        }
        'rc;bucket;anonymous;help;list' {
            break
        }
        'rc;bucket;anonymous;help;links' {
            break
        }
        'rc;bucket;anonymous;help;help' {
            break
        }
        'rc;bucket;lifecycle' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('rule', 'rule', [CompletionResultType]::ParameterValue, 'Manage lifecycle rules on a bucket')
            [CompletionResult]::new('tier', 'tier', [CompletionResultType]::ParameterValue, 'Manage remote storage tiers')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Restore a transitioned (archived) object')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;lifecycle;rule' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;lifecycle;rule;add' {
            [CompletionResult]::new('--expiry-days', '--expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for current versions')
            [CompletionResult]::new('--expiry-date', '--expiry-date', [CompletionResultType]::ParameterName, 'Expiration date for current versions (ISO 8601)')
            [CompletionResult]::new('--transition-days', '--transition-days', [CompletionResultType]::ParameterName, 'Transition days for current versions')
            [CompletionResult]::new('--transition-date', '--transition-date', [CompletionResultType]::ParameterName, 'Transition date for current versions (ISO 8601)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Target storage class for transition')
            [CompletionResult]::new('--noncurrent-expiry-days', '--noncurrent-expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-days', '--noncurrent-transition-days', [CompletionResultType]::ParameterName, 'Transition days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-storage-class', '--noncurrent-transition-storage-class', [CompletionResultType]::ParameterName, 'Storage class for noncurrent version transition')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--newer-noncurrent-versions', '--newer-noncurrent-versions', [CompletionResultType]::ParameterName, 'Maximum number of noncurrent versions to retain')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--expired-object-delete-marker', '--expired-object-delete-marker', [CompletionResultType]::ParameterName, 'Remove expired delete markers')
            [CompletionResult]::new('--disable', '--disable', [CompletionResultType]::ParameterName, 'Create the rule in disabled state')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;rule;edit' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'ID of the rule to edit')
            [CompletionResult]::new('--expiry-days', '--expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for current versions')
            [CompletionResult]::new('--expiry-date', '--expiry-date', [CompletionResultType]::ParameterName, 'Expiration date for current versions (ISO 8601)')
            [CompletionResult]::new('--transition-days', '--transition-days', [CompletionResultType]::ParameterName, 'Transition days for current versions')
            [CompletionResult]::new('--transition-date', '--transition-date', [CompletionResultType]::ParameterName, 'Transition date for current versions (ISO 8601)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Target storage class for transition')
            [CompletionResult]::new('--noncurrent-expiry-days', '--noncurrent-expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-days', '--noncurrent-transition-days', [CompletionResultType]::ParameterName, 'Transition days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-storage-class', '--noncurrent-transition-storage-class', [CompletionResultType]::ParameterName, 'Storage class for noncurrent version transition')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--expired-object-delete-marker', '--expired-object-delete-marker', [CompletionResultType]::ParameterName, 'Remove expired delete markers')
            [CompletionResult]::new('--newer-noncurrent-versions', '--newer-noncurrent-versions', [CompletionResultType]::ParameterName, 'Maximum number of noncurrent versions to retain')
            [CompletionResult]::new('--disable', '--disable', [CompletionResultType]::ParameterName, 'Set the rule to disabled state')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;rule;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;rule;remove' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'ID of the rule to remove')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Remove all lifecycle rules')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;rule;export' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;rule;import' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;rule;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;lifecycle;rule;help;add' {
            break
        }
        'rc;bucket;lifecycle;rule;help;edit' {
            break
        }
        'rc;bucket;lifecycle;rule;help;list' {
            break
        }
        'rc;bucket;lifecycle;rule;help;remove' {
            break
        }
        'rc;bucket;lifecycle;rule;help;export' {
            break
        }
        'rc;bucket;lifecycle;rule;help;import' {
            break
        }
        'rc;bucket;lifecycle;rule;help;help' {
            break
        }
        'rc;bucket;lifecycle;tier' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;lifecycle;tier;add' {
            [CompletionResult]::new('--endpoint', '--endpoint', [CompletionResultType]::ParameterName, 'Remote endpoint URL')
            [CompletionResult]::new('--access-key', '--access-key', [CompletionResultType]::ParameterName, 'Access key for the remote backend')
            [CompletionResult]::new('--secret-key', '--secret-key', [CompletionResultType]::ParameterName, 'Secret key for the remote backend')
            [CompletionResult]::new('--bucket', '--bucket', [CompletionResultType]::ParameterName, 'Target bucket on the remote backend')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Object key prefix on the remote bucket')
            [CompletionResult]::new('--region', '--region', [CompletionResultType]::ParameterName, 'Region of the remote backend')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class on the remote backend (for S3/Azure/GCS tiers)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;tier;edit' {
            [CompletionResult]::new('--access-key', '--access-key', [CompletionResultType]::ParameterName, 'New access key')
            [CompletionResult]::new('--secret-key', '--secret-key', [CompletionResultType]::ParameterName, 'New secret key')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;tier;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;tier;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;tier;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force removal even if tier is in use')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;tier;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;lifecycle;tier;help;add' {
            break
        }
        'rc;bucket;lifecycle;tier;help;edit' {
            break
        }
        'rc;bucket;lifecycle;tier;help;list' {
            break
        }
        'rc;bucket;lifecycle;tier;help;info' {
            break
        }
        'rc;bucket;lifecycle;tier;help;remove' {
            break
        }
        'rc;bucket;lifecycle;tier;help;help' {
            break
        }
        'rc;bucket;lifecycle;restore' {
            [CompletionResult]::new('--days', '--days', [CompletionResultType]::ParameterName, 'Number of days to keep the restored copy')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;lifecycle;help' {
            [CompletionResult]::new('rule', 'rule', [CompletionResultType]::ParameterValue, 'Manage lifecycle rules on a bucket')
            [CompletionResult]::new('tier', 'tier', [CompletionResultType]::ParameterValue, 'Manage remote storage tiers')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Restore a transitioned (archived) object')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;lifecycle;help;rule' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            break
        }
        'rc;bucket;lifecycle;help;rule;add' {
            break
        }
        'rc;bucket;lifecycle;help;rule;edit' {
            break
        }
        'rc;bucket;lifecycle;help;rule;list' {
            break
        }
        'rc;bucket;lifecycle;help;rule;remove' {
            break
        }
        'rc;bucket;lifecycle;help;rule;export' {
            break
        }
        'rc;bucket;lifecycle;help;rule;import' {
            break
        }
        'rc;bucket;lifecycle;help;tier' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            break
        }
        'rc;bucket;lifecycle;help;tier;add' {
            break
        }
        'rc;bucket;lifecycle;help;tier;edit' {
            break
        }
        'rc;bucket;lifecycle;help;tier;list' {
            break
        }
        'rc;bucket;lifecycle;help;tier;info' {
            break
        }
        'rc;bucket;lifecycle;help;tier;remove' {
            break
        }
        'rc;bucket;lifecycle;help;restore' {
            break
        }
        'rc;bucket;lifecycle;help;help' {
            break
        }
        'rc;bucket;replication' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new replication rule')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing replication rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List replication rules for a bucket')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show replication status/metrics for a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove replication rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export replication configuration as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import replication configuration from a JSON file')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;replication;add' {
            [CompletionResult]::new('--remote-bucket', '--remote-bucket', [CompletionResultType]::ParameterName, 'Remote target bucket (TARGET_ALIAS/BUCKET)')
            [CompletionResult]::new('--replicate', '--replicate', [CompletionResultType]::ParameterName, 'Replication flags (comma-separated: delete,delete-marker,existing-objects)')
            [CompletionResult]::new('--priority', '--priority', [CompletionResultType]::ParameterName, 'Rule priority (higher = more important)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class override at destination')
            [CompletionResult]::new('--bandwidth', '--bandwidth', [CompletionResultType]::ParameterName, 'Bandwidth limit in bytes/sec (0 = unlimited)')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'Rule identifier (auto-generated if not specified)')
            [CompletionResult]::new('--healthcheck-seconds', '--healthcheck-seconds', [CompletionResultType]::ParameterName, 'Health check interval in seconds')
            [CompletionResult]::new('--ca-cert', '--ca-cert', [CompletionResultType]::ParameterName, 'Read a local PEM CA certificate file and upload its content for this bucket replication target. The path is resolved on the CLI machine, not on the RustFS server')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--sync', '--sync', [CompletionResultType]::ParameterName, 'Enable synchronous replication')
            [CompletionResult]::new('--disable-proxy', '--disable-proxy', [CompletionResultType]::ParameterName, 'Disable replication proxy')
            [CompletionResult]::new('--insecure', '--insecure', [CompletionResultType]::ParameterName, 'Skip TLS certificate verification for this bucket replication target. Intended for development or test environments')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;update' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'Rule ID to update')
            [CompletionResult]::new('--replicate', '--replicate', [CompletionResultType]::ParameterName, 'Replication flags (comma-separated: delete,delete-marker,existing-objects)')
            [CompletionResult]::new('--priority', '--priority', [CompletionResultType]::ParameterName, 'Rule priority (higher = more important)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class override at destination')
            [CompletionResult]::new('--bandwidth', '--bandwidth', [CompletionResultType]::ParameterName, 'Bandwidth limit in bytes/sec (0 = unlimited)')
            [CompletionResult]::new('--sync', '--sync', [CompletionResultType]::ParameterName, 'Enable or disable synchronous replication')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--healthcheck-seconds', '--healthcheck-seconds', [CompletionResultType]::ParameterName, 'Health check interval in seconds')
            [CompletionResult]::new('--disable-proxy', '--disable-proxy', [CompletionResultType]::ParameterName, 'Disable replication proxy')
            [CompletionResult]::new('--ca-cert', '--ca-cert', [CompletionResultType]::ParameterName, 'Read a local PEM CA certificate file and upload its content for this bucket replication target. The path is resolved on the CLI machine, not on the RustFS server')
            [CompletionResult]::new('--status', '--status', [CompletionResultType]::ParameterName, 'Enable or disable the rule')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--insecure', '--insecure', [CompletionResultType]::ParameterName, 'Skip TLS certificate verification for this bucket replication target. Intended for development or test environments')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;remove' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'Rule ID to remove (omit for --all)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Remove all replication rules')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;export' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;import' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;bucket;replication;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new replication rule')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing replication rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List replication rules for a bucket')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show replication status/metrics for a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove replication rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export replication configuration as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import replication configuration from a JSON file')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;replication;help;add' {
            break
        }
        'rc;bucket;replication;help;update' {
            break
        }
        'rc;bucket;replication;help;list' {
            break
        }
        'rc;bucket;replication;help;status' {
            break
        }
        'rc;bucket;replication;help;remove' {
            break
        }
        'rc;bucket;replication;help;export' {
            break
        }
        'rc;bucket;replication;help;import' {
            break
        }
        'rc;bucket;replication;help;help' {
            break
        }
        'rc;bucket;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List buckets for an alias, or objects within a bucket path')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a bucket')
            [CompletionResult]::new('event', 'event', [CompletionResultType]::ParameterValue, 'Manage bucket notification rules')
            [CompletionResult]::new('cors', 'cors', [CompletionResultType]::ParameterValue, 'Manage bucket CORS rules')
            [CompletionResult]::new('encryption', 'encryption', [CompletionResultType]::ParameterValue, 'Manage bucket default encryption')
            [CompletionResult]::new('version', 'version', [CompletionResultType]::ParameterValue, 'Manage bucket versioning')
            [CompletionResult]::new('quota', 'quota', [CompletionResultType]::ParameterValue, 'Manage bucket quota')
            [CompletionResult]::new('anonymous', 'anonymous', [CompletionResultType]::ParameterValue, 'Manage anonymous bucket access')
            [CompletionResult]::new('lifecycle', 'lifecycle', [CompletionResultType]::ParameterValue, 'Manage bucket lifecycle rules, tiers, and restores')
            [CompletionResult]::new('replication', 'replication', [CompletionResultType]::ParameterValue, 'Manage bucket replication rules and status')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;bucket;help;list' {
            break
        }
        'rc;bucket;help;create' {
            break
        }
        'rc;bucket;help;remove' {
            break
        }
        'rc;bucket;help;event' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add or replace a bucket notification rule for an ARN')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket notification rules')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket notification rules by target ARN')
            break
        }
        'rc;bucket;help;event;add' {
            break
        }
        'rc;bucket;help;event;list' {
            break
        }
        'rc;bucket;help;event;remove' {
            break
        }
        'rc;bucket;help;cors' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket CORS rules')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Replace bucket CORS rules from a JSON or XML file')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket CORS rules')
            break
        }
        'rc;bucket;help;cors;list' {
            break
        }
        'rc;bucket;help;cors;set' {
            break
        }
        'rc;bucket;help;cors;remove' {
            break
        }
        'rc;bucket;help;encryption' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket default encryption')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket default encryption')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket default encryption')
            break
        }
        'rc;bucket;help;encryption;set' {
            break
        }
        'rc;bucket;help;encryption;info' {
            break
        }
        'rc;bucket;help;encryption;clear' {
            break
        }
        'rc;bucket;help;version' {
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable versioning for a bucket')
            [CompletionResult]::new('suspend', 'suspend', [CompletionResultType]::ParameterValue, 'Suspend versioning for a bucket')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get versioning status for a bucket')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List object versions')
            break
        }
        'rc;bucket;help;version;enable' {
            break
        }
        'rc;bucket;help;version;suspend' {
            break
        }
        'rc;bucket;help;version;info' {
            break
        }
        'rc;bucket;help;version;list' {
            break
        }
        'rc;bucket;help;quota' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket quota')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket quota information')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket quota')
            break
        }
        'rc;bucket;help;quota;set' {
            break
        }
        'rc;bucket;help;quota;info' {
            break
        }
        'rc;bucket;help;quota;clear' {
            break
        }
        'rc;bucket;help;anonymous' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set anonymous access permission')
            [CompletionResult]::new('set-json', 'set-json', [CompletionResultType]::ParameterValue, 'Set anonymous access from a policy JSON file')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get anonymous access permission')
            [CompletionResult]::new('get-json', 'get-json', [CompletionResultType]::ParameterValue, 'Get anonymous policy JSON')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List anonymous policies')
            [CompletionResult]::new('links', 'links', [CompletionResultType]::ParameterValue, 'List public links for anonymous readable prefixes')
            break
        }
        'rc;bucket;help;anonymous;set' {
            break
        }
        'rc;bucket;help;anonymous;set-json' {
            break
        }
        'rc;bucket;help;anonymous;get' {
            break
        }
        'rc;bucket;help;anonymous;get-json' {
            break
        }
        'rc;bucket;help;anonymous;list' {
            break
        }
        'rc;bucket;help;anonymous;links' {
            break
        }
        'rc;bucket;help;lifecycle' {
            [CompletionResult]::new('rule', 'rule', [CompletionResultType]::ParameterValue, 'Manage lifecycle rules on a bucket')
            [CompletionResult]::new('tier', 'tier', [CompletionResultType]::ParameterValue, 'Manage remote storage tiers')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Restore a transitioned (archived) object')
            break
        }
        'rc;bucket;help;lifecycle;rule' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            break
        }
        'rc;bucket;help;lifecycle;rule;add' {
            break
        }
        'rc;bucket;help;lifecycle;rule;edit' {
            break
        }
        'rc;bucket;help;lifecycle;rule;list' {
            break
        }
        'rc;bucket;help;lifecycle;rule;remove' {
            break
        }
        'rc;bucket;help;lifecycle;rule;export' {
            break
        }
        'rc;bucket;help;lifecycle;rule;import' {
            break
        }
        'rc;bucket;help;lifecycle;tier' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            break
        }
        'rc;bucket;help;lifecycle;tier;add' {
            break
        }
        'rc;bucket;help;lifecycle;tier;edit' {
            break
        }
        'rc;bucket;help;lifecycle;tier;list' {
            break
        }
        'rc;bucket;help;lifecycle;tier;info' {
            break
        }
        'rc;bucket;help;lifecycle;tier;remove' {
            break
        }
        'rc;bucket;help;lifecycle;restore' {
            break
        }
        'rc;bucket;help;replication' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new replication rule')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing replication rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List replication rules for a bucket')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show replication status/metrics for a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove replication rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export replication configuration as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import replication configuration from a JSON file')
            break
        }
        'rc;bucket;help;replication;add' {
            break
        }
        'rc;bucket;help;replication;update' {
            break
        }
        'rc;bucket;help;replication;list' {
            break
        }
        'rc;bucket;help;replication;status' {
            break
        }
        'rc;bucket;help;replication;remove' {
            break
        }
        'rc;bucket;help;replication;export' {
            break
        }
        'rc;bucket;help;replication;import' {
            break
        }
        'rc;bucket;help;help' {
            break
        }
        'rc;object' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List objects within a bucket path')
            [CompletionResult]::new('copy', 'copy', [CompletionResultType]::ParameterValue, 'Copy objects between local and remote locations')
            [CompletionResult]::new('move', 'move', [CompletionResultType]::ParameterValue, 'Move objects between local and remote locations')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove objects')
            [CompletionResult]::new('stat', 'stat', [CompletionResultType]::ParameterValue, 'Show object metadata')
            [CompletionResult]::new('show', 'show', [CompletionResultType]::ParameterValue, 'Print the full object body')
            [CompletionResult]::new('head', 'head', [CompletionResultType]::ParameterValue, 'Print the first lines or bytes of an object')
            [CompletionResult]::new('find', 'find', [CompletionResultType]::ParameterValue, 'Search for objects by filters')
            [CompletionResult]::new('tree', 'tree', [CompletionResultType]::ParameterValue, 'Display objects in a tree view')
            [CompletionResult]::new('share', 'share', [CompletionResultType]::ParameterValue, 'Generate a presigned object URL')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;object;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'List recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'List recursively')
            [CompletionResult]::new('--versions', '--versions', [CompletionResultType]::ParameterName, 'Show versions (requires versioning support)')
            [CompletionResult]::new('--incomplete', '--incomplete', [CompletionResultType]::ParameterName, 'Include incomplete uploads')
            [CompletionResult]::new('--summarize', '--summarize', [CompletionResultType]::ParameterName, 'Summarize output (show totals only)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;copy' {
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class for destination (S3 only)')
            [CompletionResult]::new('--content-type', '--content-type', [CompletionResultType]::ParameterName, 'Content type for uploaded files')
            [CompletionResult]::new('--enc-s3', '--enc-s3', [CompletionResultType]::ParameterName, 'Apply SSE-S3 to the remote destination path')
            [CompletionResult]::new('--enc-kms', '--enc-kms', [CompletionResultType]::ParameterName, 'Apply SSE-KMS to the remote destination path as TARGET=KMS_KEY_ID')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Copy recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Copy recursively')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Preserve file attributes')
            [CompletionResult]::new('--preserve', '--preserve', [CompletionResultType]::ParameterName, 'Preserve file attributes')
            [CompletionResult]::new('--continue-on-error', '--continue-on-error', [CompletionResultType]::ParameterName, 'Continue on errors')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite destination if it exists')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Only show what would be copied (dry run)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;move' {
            [CompletionResult]::new('--enc-s3', '--enc-s3', [CompletionResultType]::ParameterName, 'Apply SSE-S3 to the remote destination path')
            [CompletionResult]::new('--enc-kms', '--enc-kms', [CompletionResultType]::ParameterName, 'Apply SSE-KMS to the remote destination path as TARGET=KMS_KEY_ID')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Move recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Move recursively')
            [CompletionResult]::new('--continue-on-error', '--continue-on-error', [CompletionResultType]::ParameterName, 'Continue on errors')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Only show what would be moved (dry run)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Remove recursively (remove all objects with the given prefix)')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Remove recursively (remove all objects with the given prefix)')
            [CompletionResult]::new('-f', '-f', [CompletionResultType]::ParameterName, 'Force removal without confirmation')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force removal without confirmation')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Only show what would be deleted (dry run)')
            [CompletionResult]::new('--incomplete', '--incomplete', [CompletionResultType]::ParameterName, 'Remove incomplete multipart uploads older than specified duration')
            [CompletionResult]::new('--versions', '--versions', [CompletionResultType]::ParameterName, 'Include versions (requires versioning support)')
            [CompletionResult]::new('--bypass', '--bypass', [CompletionResultType]::ParameterName, 'Bypass governance retention')
            [CompletionResult]::new('--purge', '--purge', [CompletionResultType]::ParameterName, 'Permanently delete objects using the RustFS force-delete header')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;stat' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Show version ID information')
            [CompletionResult]::new('--rewind', '--rewind', [CompletionResultType]::ParameterName, 'Rewind to a specific time')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;show' {
            [CompletionResult]::new('--enc-key', '--enc-key', [CompletionResultType]::ParameterName, 'Encrypt/decrypt with the given key (base64 encoded)')
            [CompletionResult]::new('--rewind', '--rewind', [CompletionResultType]::ParameterName, 'Rewind to a specific time')
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Specific version ID to retrieve')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;head' {
            [CompletionResult]::new('-n', '-n', [CompletionResultType]::ParameterName, 'Number of lines to display (default: 10)')
            [CompletionResult]::new('--lines', '--lines', [CompletionResultType]::ParameterName, 'Number of lines to display (default: 10)')
            [CompletionResult]::new('-c', '-c', [CompletionResultType]::ParameterName, 'Display first N bytes instead of lines')
            [CompletionResult]::new('--bytes', '--bytes', [CompletionResultType]::ParameterName, 'Display first N bytes instead of lines')
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Specific version ID to retrieve')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;find' {
            [CompletionResult]::new('--name', '--name', [CompletionResultType]::ParameterName, 'Pattern to match object names (glob-style: *, ?)')
            [CompletionResult]::new('--larger', '--larger', [CompletionResultType]::ParameterName, 'Match objects larger than size (e.g., 1K, 1M, 1G)')
            [CompletionResult]::new('--smaller', '--smaller', [CompletionResultType]::ParameterName, 'Match objects smaller than size (e.g., 1K, 1M, 1G)')
            [CompletionResult]::new('--newer', '--newer', [CompletionResultType]::ParameterName, 'Match objects newer than duration (e.g., 1h, 1d, 7d)')
            [CompletionResult]::new('--older', '--older', [CompletionResultType]::ParameterName, 'Match objects older than duration (e.g., 1h, 1d, 7d)')
            [CompletionResult]::new('--maxdepth', '--maxdepth', [CompletionResultType]::ParameterName, 'Maximum depth to search (0 = unlimited)')
            [CompletionResult]::new('--exec', '--exec', [CompletionResultType]::ParameterName, 'Execute command for each match (use {} as placeholder)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--count', '--count', [CompletionResultType]::ParameterName, 'Print only count of matches')
            [CompletionResult]::new('--print', '--print', [CompletionResultType]::ParameterName, 'Print full path (default: relative to search path)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;tree' {
            [CompletionResult]::new('-L', '-L ', [CompletionResultType]::ParameterName, 'Maximum depth to display')
            [CompletionResult]::new('--level', '--level', [CompletionResultType]::ParameterName, 'Maximum depth to display')
            [CompletionResult]::new('-P', '-P ', [CompletionResultType]::ParameterName, 'Pattern to include (glob-style)')
            [CompletionResult]::new('--pattern', '--pattern', [CompletionResultType]::ParameterName, 'Pattern to include (glob-style)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-s', '-s', [CompletionResultType]::ParameterName, 'Show file sizes')
            [CompletionResult]::new('--size', '--size', [CompletionResultType]::ParameterName, 'Show file sizes')
            [CompletionResult]::new('-d', '-d', [CompletionResultType]::ParameterName, 'Show only directories')
            [CompletionResult]::new('--dirs-only', '--dirs-only', [CompletionResultType]::ParameterName, 'Show only directories')
            [CompletionResult]::new('-f', '-f', [CompletionResultType]::ParameterName, 'Show full path prefix')
            [CompletionResult]::new('--full-path', '--full-path', [CompletionResultType]::ParameterName, 'Show full path prefix')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;share' {
            [CompletionResult]::new('-e', '-e', [CompletionResultType]::ParameterName, 'Expiration time (e.g., 1h, 1d, 7d). Default: 7d')
            [CompletionResult]::new('--expire', '--expire', [CompletionResultType]::ParameterName, 'Expiration time (e.g., 1h, 1d, 7d). Default: 7d')
            [CompletionResult]::new('--content-type', '--content-type', [CompletionResultType]::ParameterName, 'Content-Type for upload URL')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--upload', '--upload', [CompletionResultType]::ParameterName, 'Generate upload URL instead of download URL')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;object;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List objects within a bucket path')
            [CompletionResult]::new('copy', 'copy', [CompletionResultType]::ParameterValue, 'Copy objects between local and remote locations')
            [CompletionResult]::new('move', 'move', [CompletionResultType]::ParameterValue, 'Move objects between local and remote locations')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove objects')
            [CompletionResult]::new('stat', 'stat', [CompletionResultType]::ParameterValue, 'Show object metadata')
            [CompletionResult]::new('show', 'show', [CompletionResultType]::ParameterValue, 'Print the full object body')
            [CompletionResult]::new('head', 'head', [CompletionResultType]::ParameterValue, 'Print the first lines or bytes of an object')
            [CompletionResult]::new('find', 'find', [CompletionResultType]::ParameterValue, 'Search for objects by filters')
            [CompletionResult]::new('tree', 'tree', [CompletionResultType]::ParameterValue, 'Display objects in a tree view')
            [CompletionResult]::new('share', 'share', [CompletionResultType]::ParameterValue, 'Generate a presigned object URL')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;object;help;list' {
            break
        }
        'rc;object;help;copy' {
            break
        }
        'rc;object;help;move' {
            break
        }
        'rc;object;help;remove' {
            break
        }
        'rc;object;help;stat' {
            break
        }
        'rc;object;help;show' {
            break
        }
        'rc;object;help;head' {
            break
        }
        'rc;object;help;find' {
            break
        }
        'rc;object;help;tree' {
            break
        }
        'rc;object;help;share' {
            break
        }
        'rc;object;help;help' {
            break
        }
        'rc;ls' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'List recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'List recursively')
            [CompletionResult]::new('--versions', '--versions', [CompletionResultType]::ParameterName, 'Show versions (requires versioning support)')
            [CompletionResult]::new('--incomplete', '--incomplete', [CompletionResultType]::ParameterName, 'Include incomplete uploads')
            [CompletionResult]::new('--summarize', '--summarize', [CompletionResultType]::ParameterName, 'Summarize output (show totals only)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;mb' {
            [CompletionResult]::new('--region', '--region', [CompletionResultType]::ParameterName, 'Region for the bucket (overrides alias default)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Ignore error if bucket already exists')
            [CompletionResult]::new('--ignore-existing', '--ignore-existing', [CompletionResultType]::ParameterName, 'Ignore error if bucket already exists')
            [CompletionResult]::new('--with-lock', '--with-lock', [CompletionResultType]::ParameterName, 'Enable object locking on the bucket')
            [CompletionResult]::new('--with-versioning', '--with-versioning', [CompletionResultType]::ParameterName, 'Enable versioning on the bucket')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;rb' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force remove even if bucket is not empty (deletes all objects first)')
            [CompletionResult]::new('--dangerous', '--dangerous', [CompletionResultType]::ParameterName, 'Remove bucket even if it has incomplete multipart uploads')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;cat' {
            [CompletionResult]::new('--enc-key', '--enc-key', [CompletionResultType]::ParameterName, 'Encrypt/decrypt with the given key (base64 encoded)')
            [CompletionResult]::new('--rewind', '--rewind', [CompletionResultType]::ParameterName, 'Rewind to a specific time')
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Specific version ID to retrieve')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;head' {
            [CompletionResult]::new('-n', '-n', [CompletionResultType]::ParameterName, 'Number of lines to display (default: 10)')
            [CompletionResult]::new('--lines', '--lines', [CompletionResultType]::ParameterName, 'Number of lines to display (default: 10)')
            [CompletionResult]::new('-c', '-c', [CompletionResultType]::ParameterName, 'Display first N bytes instead of lines')
            [CompletionResult]::new('--bytes', '--bytes', [CompletionResultType]::ParameterName, 'Display first N bytes instead of lines')
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Specific version ID to retrieve')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;stat' {
            [CompletionResult]::new('--version-id', '--version-id', [CompletionResultType]::ParameterName, 'Show version ID information')
            [CompletionResult]::new('--rewind', '--rewind', [CompletionResultType]::ParameterName, 'Rewind to a specific time')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;cp' {
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class for destination (S3 only)')
            [CompletionResult]::new('--content-type', '--content-type', [CompletionResultType]::ParameterName, 'Content type for uploaded files')
            [CompletionResult]::new('--enc-s3', '--enc-s3', [CompletionResultType]::ParameterName, 'Apply SSE-S3 to the remote destination path')
            [CompletionResult]::new('--enc-kms', '--enc-kms', [CompletionResultType]::ParameterName, 'Apply SSE-KMS to the remote destination path as TARGET=KMS_KEY_ID')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Copy recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Copy recursively')
            [CompletionResult]::new('-p', '-p', [CompletionResultType]::ParameterName, 'Preserve file attributes')
            [CompletionResult]::new('--preserve', '--preserve', [CompletionResultType]::ParameterName, 'Preserve file attributes')
            [CompletionResult]::new('--continue-on-error', '--continue-on-error', [CompletionResultType]::ParameterName, 'Continue on errors')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite destination if it exists')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Only show what would be copied (dry run)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;mv' {
            [CompletionResult]::new('--enc-s3', '--enc-s3', [CompletionResultType]::ParameterName, 'Apply SSE-S3 to the remote destination path')
            [CompletionResult]::new('--enc-kms', '--enc-kms', [CompletionResultType]::ParameterName, 'Apply SSE-KMS to the remote destination path as TARGET=KMS_KEY_ID')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Move recursively')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Move recursively')
            [CompletionResult]::new('--continue-on-error', '--continue-on-error', [CompletionResultType]::ParameterName, 'Continue on errors')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Only show what would be moved (dry run)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;rm' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Remove recursively (remove all objects with the given prefix)')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Remove recursively (remove all objects with the given prefix)')
            [CompletionResult]::new('-f', '-f', [CompletionResultType]::ParameterName, 'Force removal without confirmation')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force removal without confirmation')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Only show what would be deleted (dry run)')
            [CompletionResult]::new('--incomplete', '--incomplete', [CompletionResultType]::ParameterName, 'Remove incomplete multipart uploads older than specified duration')
            [CompletionResult]::new('--versions', '--versions', [CompletionResultType]::ParameterName, 'Include versions (requires versioning support)')
            [CompletionResult]::new('--bypass', '--bypass', [CompletionResultType]::ParameterName, 'Bypass governance retention')
            [CompletionResult]::new('--purge', '--purge', [CompletionResultType]::ParameterName, 'Permanently delete objects using the RustFS force-delete header')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;pipe' {
            [CompletionResult]::new('--content-type', '--content-type', [CompletionResultType]::ParameterName, 'Content type for the uploaded object')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class for the object')
            [CompletionResult]::new('--enc-kms', '--enc-kms', [CompletionResultType]::ParameterName, 'Apply SSE-KMS to the upload target')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--enc-s3', '--enc-s3', [CompletionResultType]::ParameterName, 'Apply SSE-S3 to the upload target')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;find' {
            [CompletionResult]::new('--name', '--name', [CompletionResultType]::ParameterName, 'Pattern to match object names (glob-style: *, ?)')
            [CompletionResult]::new('--larger', '--larger', [CompletionResultType]::ParameterName, 'Match objects larger than size (e.g., 1K, 1M, 1G)')
            [CompletionResult]::new('--smaller', '--smaller', [CompletionResultType]::ParameterName, 'Match objects smaller than size (e.g., 1K, 1M, 1G)')
            [CompletionResult]::new('--newer', '--newer', [CompletionResultType]::ParameterName, 'Match objects newer than duration (e.g., 1h, 1d, 7d)')
            [CompletionResult]::new('--older', '--older', [CompletionResultType]::ParameterName, 'Match objects older than duration (e.g., 1h, 1d, 7d)')
            [CompletionResult]::new('--maxdepth', '--maxdepth', [CompletionResultType]::ParameterName, 'Maximum depth to search (0 = unlimited)')
            [CompletionResult]::new('--exec', '--exec', [CompletionResultType]::ParameterName, 'Execute command for each match (use {} as placeholder)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--count', '--count', [CompletionResultType]::ParameterName, 'Print only count of matches')
            [CompletionResult]::new('--print', '--print', [CompletionResultType]::ParameterName, 'Print full path (default: relative to search path)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;event' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add or replace a bucket notification rule for an ARN')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket notification rules')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket notification rules by target ARN')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;event;add' {
            [CompletionResult]::new('--event', '--event', [CompletionResultType]::ParameterName, 'Event pattern (repeatable; comma-separated values are also accepted)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;event;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;event;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;event;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add or replace a bucket notification rule for an ARN')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket notification rules')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket notification rules by target ARN')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;event;help;add' {
            break
        }
        'rc;event;help;list' {
            break
        }
        'rc;event;help;remove' {
            break
        }
        'rc;event;help;help' {
            break
        }
        'rc;cors' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket CORS rules')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Replace bucket CORS rules from a JSON or XML file')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket CORS rules')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;cors;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;cors;set' {
            [CompletionResult]::new('--file', '--file', [CompletionResultType]::ParameterName, 'Path to the CORS configuration file, or ''-'' to read from stdin')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;cors;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;cors;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket CORS rules')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Replace bucket CORS rules from a JSON or XML file')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket CORS rules')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;cors;help;list' {
            break
        }
        'rc;cors;help;set' {
            break
        }
        'rc;cors;help;remove' {
            break
        }
        'rc;cors;help;help' {
            break
        }
        'rc;diff' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Recursive comparison')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Recursive comparison')
            [CompletionResult]::new('--diff-only', '--diff-only', [CompletionResultType]::ParameterName, 'Show only differences (default: show all)')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;mirror' {
            [CompletionResult]::new('-P', '-P ', [CompletionResultType]::ParameterName, 'Number of parallel operations')
            [CompletionResult]::new('--parallel', '--parallel', [CompletionResultType]::ParameterName, 'Number of parallel operations')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--remove', '--remove', [CompletionResultType]::ParameterName, 'Remove extra objects at destination')
            [CompletionResult]::new('--overwrite', '--overwrite', [CompletionResultType]::ParameterName, 'Overwrite existing objects')
            [CompletionResult]::new('-n', '-n', [CompletionResultType]::ParameterName, 'Dry run (show what would be done without doing it)')
            [CompletionResult]::new('--dry-run', '--dry-run', [CompletionResultType]::ParameterName, 'Dry run (show what would be done without doing it)')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;tree' {
            [CompletionResult]::new('-L', '-L ', [CompletionResultType]::ParameterName, 'Maximum depth to display')
            [CompletionResult]::new('--level', '--level', [CompletionResultType]::ParameterName, 'Maximum depth to display')
            [CompletionResult]::new('-P', '-P ', [CompletionResultType]::ParameterName, 'Pattern to include (glob-style)')
            [CompletionResult]::new('--pattern', '--pattern', [CompletionResultType]::ParameterName, 'Pattern to include (glob-style)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-s', '-s', [CompletionResultType]::ParameterName, 'Show file sizes')
            [CompletionResult]::new('--size', '--size', [CompletionResultType]::ParameterName, 'Show file sizes')
            [CompletionResult]::new('-d', '-d', [CompletionResultType]::ParameterName, 'Show only directories')
            [CompletionResult]::new('--dirs-only', '--dirs-only', [CompletionResultType]::ParameterName, 'Show only directories')
            [CompletionResult]::new('-f', '-f', [CompletionResultType]::ParameterName, 'Show full path prefix')
            [CompletionResult]::new('--full-path', '--full-path', [CompletionResultType]::ParameterName, 'Show full path prefix')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;share' {
            [CompletionResult]::new('-e', '-e', [CompletionResultType]::ParameterName, 'Expiration time (e.g., 1h, 1d, 7d). Default: 7d')
            [CompletionResult]::new('--expire', '--expire', [CompletionResultType]::ParameterName, 'Expiration time (e.g., 1h, 1d, 7d). Default: 7d')
            [CompletionResult]::new('--content-type', '--content-type', [CompletionResultType]::ParameterName, 'Content-Type for upload URL')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--upload', '--upload', [CompletionResultType]::ParameterName, 'Generate upload URL instead of download URL')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;sql' {
            [CompletionResult]::new('--query', '--query', [CompletionResultType]::ParameterName, 'SQL expression (S3 Select)')
            [CompletionResult]::new('--input-format', '--input-format', [CompletionResultType]::ParameterName, 'Input object format')
            [CompletionResult]::new('--output-format', '--output-format', [CompletionResultType]::ParameterName, 'Select result format')
            [CompletionResult]::new('--compression', '--compression', [CompletionResultType]::ParameterName, 'Compression of the stored object (input decompression)')
            [CompletionResult]::new('--csv-file-header-info', '--csv-file-header-info', [CompletionResultType]::ParameterName, 'CSV input header handling')
            [CompletionResult]::new('--csv-input-field-delimiter', '--csv-input-field-delimiter', [CompletionResultType]::ParameterName, 'CSV input field delimiter')
            [CompletionResult]::new('--csv-input-quote', '--csv-input-quote', [CompletionResultType]::ParameterName, 'CSV input quote character')
            [CompletionResult]::new('--csv-input-quote-escape', '--csv-input-quote-escape', [CompletionResultType]::ParameterName, 'CSV input quote escape character')
            [CompletionResult]::new('--csv-input-comment', '--csv-input-comment', [CompletionResultType]::ParameterName, 'CSV input comment character')
            [CompletionResult]::new('--csv-output-field-delimiter', '--csv-output-field-delimiter', [CompletionResultType]::ParameterName, 'CSV output field delimiter')
            [CompletionResult]::new('--csv-output-record-delimiter', '--csv-output-record-delimiter', [CompletionResultType]::ParameterName, 'CSV output record delimiter')
            [CompletionResult]::new('--csv-output-quote', '--csv-output-quote', [CompletionResultType]::ParameterName, 'CSV output quote character')
            [CompletionResult]::new('--csv-output-quote-escape', '--csv-output-quote-escape', [CompletionResultType]::ParameterName, 'CSV output quote escape character')
            [CompletionResult]::new('--csv-output-quote-fields', '--csv-output-quote-fields', [CompletionResultType]::ParameterName, 'CSV output quote behavior')
            [CompletionResult]::new('--json-type', '--json-type', [CompletionResultType]::ParameterName, 'JSON input shape')
            [CompletionResult]::new('--json-output-record-delimiter', '--json-output-record-delimiter', [CompletionResultType]::ParameterName, 'JSON output record delimiter')
            [CompletionResult]::new('--scan-start', '--scan-start', [CompletionResultType]::ParameterName, 'Select ScanRange start byte')
            [CompletionResult]::new('--scan-end', '--scan-end', [CompletionResultType]::ParameterName, 'Select ScanRange end byte')
            [CompletionResult]::new('--sse-customer-algorithm', '--sse-customer-algorithm', [CompletionResultType]::ParameterName, 'SSE-C customer algorithm, usually AES256')
            [CompletionResult]::new('--sse-customer-key', '--sse-customer-key', [CompletionResultType]::ParameterName, 'SSE-C customer key')
            [CompletionResult]::new('--sse-customer-key-md5', '--sse-customer-key-md5', [CompletionResultType]::ParameterName, 'SSE-C customer key MD5')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;version' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable versioning for a bucket')
            [CompletionResult]::new('suspend', 'suspend', [CompletionResultType]::ParameterValue, 'Suspend versioning for a bucket')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get versioning status for a bucket')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List object versions')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;version;enable' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;version;suspend' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;version;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;version;list' {
            [CompletionResult]::new('-n', '-n', [CompletionResultType]::ParameterName, 'Maximum number of versions to show')
            [CompletionResult]::new('--max', '--max', [CompletionResultType]::ParameterName, 'Maximum number of versions to show')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;version;help' {
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable versioning for a bucket')
            [CompletionResult]::new('suspend', 'suspend', [CompletionResultType]::ParameterValue, 'Suspend versioning for a bucket')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get versioning status for a bucket')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List object versions')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;version;help;enable' {
            break
        }
        'rc;version;help;suspend' {
            break
        }
        'rc;version;help;info' {
            break
        }
        'rc;version;help;list' {
            break
        }
        'rc;version;help;help' {
            break
        }
        'rc;tag' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List tags for a bucket or object')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set tags for a bucket or object')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove all tags from a bucket or object')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;tag;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;tag;set' {
            [CompletionResult]::new('-t', '-t', [CompletionResultType]::ParameterName, 'Tags to set (key=value format, can specify multiple)')
            [CompletionResult]::new('--tags', '--tags', [CompletionResultType]::ParameterName, 'Tags to set (key=value format, can specify multiple)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;tag;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;tag;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List tags for a bucket or object')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set tags for a bucket or object')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove all tags from a bucket or object')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;tag;help;list' {
            break
        }
        'rc;tag;help;set' {
            break
        }
        'rc;tag;help;remove' {
            break
        }
        'rc;tag;help;help' {
            break
        }
        'rc;anonymous' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set anonymous access permission')
            [CompletionResult]::new('set-json', 'set-json', [CompletionResultType]::ParameterValue, 'Set anonymous access from a policy JSON file')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get anonymous access permission')
            [CompletionResult]::new('get-json', 'get-json', [CompletionResultType]::ParameterValue, 'Get anonymous policy JSON')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List anonymous policies')
            [CompletionResult]::new('links', 'links', [CompletionResultType]::ParameterValue, 'List public links for anonymous readable prefixes')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;anonymous;set' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;anonymous;set-json' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;anonymous;get' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;anonymous;get-json' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;anonymous;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;anonymous;links' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('-r', '-r', [CompletionResultType]::ParameterName, 'Recursively list links')
            [CompletionResult]::new('--recursive', '--recursive', [CompletionResultType]::ParameterName, 'Recursively list links')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;anonymous;help' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set anonymous access permission')
            [CompletionResult]::new('set-json', 'set-json', [CompletionResultType]::ParameterValue, 'Set anonymous access from a policy JSON file')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get anonymous access permission')
            [CompletionResult]::new('get-json', 'get-json', [CompletionResultType]::ParameterValue, 'Get anonymous policy JSON')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List anonymous policies')
            [CompletionResult]::new('links', 'links', [CompletionResultType]::ParameterValue, 'List public links for anonymous readable prefixes')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;anonymous;help;set' {
            break
        }
        'rc;anonymous;help;set-json' {
            break
        }
        'rc;anonymous;help;get' {
            break
        }
        'rc;anonymous;help;get-json' {
            break
        }
        'rc;anonymous;help;list' {
            break
        }
        'rc;anonymous;help;links' {
            break
        }
        'rc;anonymous;help;help' {
            break
        }
        'rc;quota' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket quota')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket quota information')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket quota')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;quota;set' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;quota;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;quota;clear' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;quota;help' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket quota')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket quota information')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket quota')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;quota;help;set' {
            break
        }
        'rc;quota;help;info' {
            break
        }
        'rc;quota;help;clear' {
            break
        }
        'rc;quota;help;help' {
            break
        }
        'rc;ilm' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('rule', 'rule', [CompletionResultType]::ParameterValue, 'Manage lifecycle rules on a bucket')
            [CompletionResult]::new('tier', 'tier', [CompletionResultType]::ParameterValue, 'Manage remote storage tiers')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Restore a transitioned (archived) object')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;ilm;rule' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;ilm;rule;add' {
            [CompletionResult]::new('--expiry-days', '--expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for current versions')
            [CompletionResult]::new('--expiry-date', '--expiry-date', [CompletionResultType]::ParameterName, 'Expiration date for current versions (ISO 8601)')
            [CompletionResult]::new('--transition-days', '--transition-days', [CompletionResultType]::ParameterName, 'Transition days for current versions')
            [CompletionResult]::new('--transition-date', '--transition-date', [CompletionResultType]::ParameterName, 'Transition date for current versions (ISO 8601)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Target storage class for transition')
            [CompletionResult]::new('--noncurrent-expiry-days', '--noncurrent-expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-days', '--noncurrent-transition-days', [CompletionResultType]::ParameterName, 'Transition days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-storage-class', '--noncurrent-transition-storage-class', [CompletionResultType]::ParameterName, 'Storage class for noncurrent version transition')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--newer-noncurrent-versions', '--newer-noncurrent-versions', [CompletionResultType]::ParameterName, 'Maximum number of noncurrent versions to retain')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--expired-object-delete-marker', '--expired-object-delete-marker', [CompletionResultType]::ParameterName, 'Remove expired delete markers')
            [CompletionResult]::new('--disable', '--disable', [CompletionResultType]::ParameterName, 'Create the rule in disabled state')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;rule;edit' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'ID of the rule to edit')
            [CompletionResult]::new('--expiry-days', '--expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for current versions')
            [CompletionResult]::new('--expiry-date', '--expiry-date', [CompletionResultType]::ParameterName, 'Expiration date for current versions (ISO 8601)')
            [CompletionResult]::new('--transition-days', '--transition-days', [CompletionResultType]::ParameterName, 'Transition days for current versions')
            [CompletionResult]::new('--transition-date', '--transition-date', [CompletionResultType]::ParameterName, 'Transition date for current versions (ISO 8601)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Target storage class for transition')
            [CompletionResult]::new('--noncurrent-expiry-days', '--noncurrent-expiry-days', [CompletionResultType]::ParameterName, 'Expiration days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-days', '--noncurrent-transition-days', [CompletionResultType]::ParameterName, 'Transition days for noncurrent versions')
            [CompletionResult]::new('--noncurrent-transition-storage-class', '--noncurrent-transition-storage-class', [CompletionResultType]::ParameterName, 'Storage class for noncurrent version transition')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--expired-object-delete-marker', '--expired-object-delete-marker', [CompletionResultType]::ParameterName, 'Remove expired delete markers')
            [CompletionResult]::new('--newer-noncurrent-versions', '--newer-noncurrent-versions', [CompletionResultType]::ParameterName, 'Maximum number of noncurrent versions to retain')
            [CompletionResult]::new('--disable', '--disable', [CompletionResultType]::ParameterName, 'Set the rule to disabled state')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;rule;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;rule;remove' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'ID of the rule to remove')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Remove all lifecycle rules')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;rule;export' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;rule;import' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;rule;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;ilm;rule;help;add' {
            break
        }
        'rc;ilm;rule;help;edit' {
            break
        }
        'rc;ilm;rule;help;list' {
            break
        }
        'rc;ilm;rule;help;remove' {
            break
        }
        'rc;ilm;rule;help;export' {
            break
        }
        'rc;ilm;rule;help;import' {
            break
        }
        'rc;ilm;rule;help;help' {
            break
        }
        'rc;ilm;tier' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;ilm;tier;add' {
            [CompletionResult]::new('--endpoint', '--endpoint', [CompletionResultType]::ParameterName, 'Remote endpoint URL')
            [CompletionResult]::new('--access-key', '--access-key', [CompletionResultType]::ParameterName, 'Access key for the remote backend')
            [CompletionResult]::new('--secret-key', '--secret-key', [CompletionResultType]::ParameterName, 'Secret key for the remote backend')
            [CompletionResult]::new('--bucket', '--bucket', [CompletionResultType]::ParameterName, 'Target bucket on the remote backend')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Object key prefix on the remote bucket')
            [CompletionResult]::new('--region', '--region', [CompletionResultType]::ParameterName, 'Region of the remote backend')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class on the remote backend (for S3/Azure/GCS tiers)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;tier;edit' {
            [CompletionResult]::new('--access-key', '--access-key', [CompletionResultType]::ParameterName, 'New access key')
            [CompletionResult]::new('--secret-key', '--secret-key', [CompletionResultType]::ParameterName, 'New secret key')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;tier;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;tier;info' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;tier;remove' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force removal even if tier is in use')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;tier;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;ilm;tier;help;add' {
            break
        }
        'rc;ilm;tier;help;edit' {
            break
        }
        'rc;ilm;tier;help;list' {
            break
        }
        'rc;ilm;tier;help;info' {
            break
        }
        'rc;ilm;tier;help;remove' {
            break
        }
        'rc;ilm;tier;help;help' {
            break
        }
        'rc;ilm;restore' {
            [CompletionResult]::new('--days', '--days', [CompletionResultType]::ParameterName, 'Number of days to keep the restored copy')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;ilm;help' {
            [CompletionResult]::new('rule', 'rule', [CompletionResultType]::ParameterValue, 'Manage lifecycle rules on a bucket')
            [CompletionResult]::new('tier', 'tier', [CompletionResultType]::ParameterValue, 'Manage remote storage tiers')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Restore a transitioned (archived) object')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;ilm;help;rule' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            break
        }
        'rc;ilm;help;rule;add' {
            break
        }
        'rc;ilm;help;rule;edit' {
            break
        }
        'rc;ilm;help;rule;list' {
            break
        }
        'rc;ilm;help;rule;remove' {
            break
        }
        'rc;ilm;help;rule;export' {
            break
        }
        'rc;ilm;help;rule;import' {
            break
        }
        'rc;ilm;help;tier' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            break
        }
        'rc;ilm;help;tier;add' {
            break
        }
        'rc;ilm;help;tier;edit' {
            break
        }
        'rc;ilm;help;tier;list' {
            break
        }
        'rc;ilm;help;tier;info' {
            break
        }
        'rc;ilm;help;tier;remove' {
            break
        }
        'rc;ilm;help;restore' {
            break
        }
        'rc;ilm;help;help' {
            break
        }
        'rc;replicate' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new replication rule')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing replication rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List replication rules for a bucket')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show replication status/metrics for a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove replication rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export replication configuration as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import replication configuration from a JSON file')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;replicate;add' {
            [CompletionResult]::new('--remote-bucket', '--remote-bucket', [CompletionResultType]::ParameterName, 'Remote target bucket (TARGET_ALIAS/BUCKET)')
            [CompletionResult]::new('--replicate', '--replicate', [CompletionResultType]::ParameterName, 'Replication flags (comma-separated: delete,delete-marker,existing-objects)')
            [CompletionResult]::new('--priority', '--priority', [CompletionResultType]::ParameterName, 'Rule priority (higher = more important)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class override at destination')
            [CompletionResult]::new('--bandwidth', '--bandwidth', [CompletionResultType]::ParameterName, 'Bandwidth limit in bytes/sec (0 = unlimited)')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'Rule identifier (auto-generated if not specified)')
            [CompletionResult]::new('--healthcheck-seconds', '--healthcheck-seconds', [CompletionResultType]::ParameterName, 'Health check interval in seconds')
            [CompletionResult]::new('--ca-cert', '--ca-cert', [CompletionResultType]::ParameterName, 'Read a local PEM CA certificate file and upload its content for this bucket replication target. The path is resolved on the CLI machine, not on the RustFS server')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--sync', '--sync', [CompletionResultType]::ParameterName, 'Enable synchronous replication')
            [CompletionResult]::new('--disable-proxy', '--disable-proxy', [CompletionResultType]::ParameterName, 'Disable replication proxy')
            [CompletionResult]::new('--insecure', '--insecure', [CompletionResultType]::ParameterName, 'Skip TLS certificate verification for this bucket replication target. Intended for development or test environments')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;update' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'Rule ID to update')
            [CompletionResult]::new('--replicate', '--replicate', [CompletionResultType]::ParameterName, 'Replication flags (comma-separated: delete,delete-marker,existing-objects)')
            [CompletionResult]::new('--priority', '--priority', [CompletionResultType]::ParameterName, 'Rule priority (higher = more important)')
            [CompletionResult]::new('--storage-class', '--storage-class', [CompletionResultType]::ParameterName, 'Storage class override at destination')
            [CompletionResult]::new('--bandwidth', '--bandwidth', [CompletionResultType]::ParameterName, 'Bandwidth limit in bytes/sec (0 = unlimited)')
            [CompletionResult]::new('--sync', '--sync', [CompletionResultType]::ParameterName, 'Enable or disable synchronous replication')
            [CompletionResult]::new('--prefix', '--prefix', [CompletionResultType]::ParameterName, 'Key prefix filter')
            [CompletionResult]::new('--healthcheck-seconds', '--healthcheck-seconds', [CompletionResultType]::ParameterName, 'Health check interval in seconds')
            [CompletionResult]::new('--disable-proxy', '--disable-proxy', [CompletionResultType]::ParameterName, 'Disable replication proxy')
            [CompletionResult]::new('--ca-cert', '--ca-cert', [CompletionResultType]::ParameterName, 'Read a local PEM CA certificate file and upload its content for this bucket replication target. The path is resolved on the CLI machine, not on the RustFS server')
            [CompletionResult]::new('--status', '--status', [CompletionResultType]::ParameterName, 'Enable or disable the rule')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--insecure', '--insecure', [CompletionResultType]::ParameterName, 'Skip TLS certificate verification for this bucket replication target. Intended for development or test environments')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;list' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;status' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;remove' {
            [CompletionResult]::new('--id', '--id', [CompletionResultType]::ParameterName, 'Rule ID to remove (omit for --all)')
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--all', '--all', [CompletionResultType]::ParameterName, 'Remove all replication rules')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;export' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;import' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--force', '--force', [CompletionResultType]::ParameterName, 'Force operation even if capability detection fails')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;replicate;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new replication rule')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing replication rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List replication rules for a bucket')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show replication status/metrics for a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove replication rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export replication configuration as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import replication configuration from a JSON file')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;replicate;help;add' {
            break
        }
        'rc;replicate;help;update' {
            break
        }
        'rc;replicate;help;list' {
            break
        }
        'rc;replicate;help;status' {
            break
        }
        'rc;replicate;help;remove' {
            break
        }
        'rc;replicate;help;export' {
            break
        }
        'rc;replicate;help;import' {
            break
        }
        'rc;replicate;help;help' {
            break
        }
        'rc;completions' {
            [CompletionResult]::new('--format', '--format', [CompletionResultType]::ParameterName, 'Output format: auto-detect, human-readable, or JSON')
            [CompletionResult]::new('-H', '-H ', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--header', '--header', [CompletionResultType]::ParameterName, 'Add an x-amz-* request header to signed S3 requests')
            [CompletionResult]::new('--json', '--json', [CompletionResultType]::ParameterName, 'Output format: human-readable or JSON')
            [CompletionResult]::new('--no-color', '--no-color', [CompletionResultType]::ParameterName, 'Disable colored output')
            [CompletionResult]::new('--no-progress', '--no-progress', [CompletionResultType]::ParameterName, 'Disable progress bar')
            [CompletionResult]::new('-q', '-q', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--quiet', '--quiet', [CompletionResultType]::ParameterName, 'Suppress non-error output')
            [CompletionResult]::new('--debug', '--debug', [CompletionResultType]::ParameterName, 'Enable debug logging')
            [CompletionResult]::new('-h', '-h', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('--help', '--help', [CompletionResultType]::ParameterName, 'Print help')
            [CompletionResult]::new('-V', '-V ', [CompletionResultType]::ParameterName, 'Print version')
            [CompletionResult]::new('--version', '--version', [CompletionResultType]::ParameterName, 'Print version')
            break
        }
        'rc;help' {
            [CompletionResult]::new('alias', 'alias', [CompletionResultType]::ParameterValue, 'Manage storage service aliases')
            [CompletionResult]::new('admin', 'admin', [CompletionResultType]::ParameterValue, 'Manage IAM users, policies, groups, and service accounts')
            [CompletionResult]::new('bucket', 'bucket', [CompletionResultType]::ParameterValue, 'Manage bucket-oriented workflows')
            [CompletionResult]::new('object', 'object', [CompletionResultType]::ParameterValue, 'Manage object-oriented workflows')
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket list` or `rc object list`')
            [CompletionResult]::new('mb', 'mb', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket create`')
            [CompletionResult]::new('rb', 'rb', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket remove`')
            [CompletionResult]::new('cat', 'cat', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object show`')
            [CompletionResult]::new('head', 'head', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object head`')
            [CompletionResult]::new('stat', 'stat', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object stat`')
            [CompletionResult]::new('cp', 'cp', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object copy`')
            [CompletionResult]::new('mv', 'mv', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object move`')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object remove`')
            [CompletionResult]::new('pipe', 'pipe', [CompletionResultType]::ParameterValue, 'Stream stdin to an object')
            [CompletionResult]::new('find', 'find', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object find`')
            [CompletionResult]::new('event', 'event', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket event`')
            [CompletionResult]::new('cors', 'cors', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket cors`')
            [CompletionResult]::new('diff', 'diff', [CompletionResultType]::ParameterValue, 'Show differences between locations')
            [CompletionResult]::new('mirror', 'mirror', [CompletionResultType]::ParameterValue, 'Mirror objects between locations')
            [CompletionResult]::new('tree', 'tree', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object tree`')
            [CompletionResult]::new('share', 'share', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc object share`')
            [CompletionResult]::new('sql', 'sql', [CompletionResultType]::ParameterValue, 'Run S3 Select SQL on an object')
            [CompletionResult]::new('version', 'version', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket version`')
            [CompletionResult]::new('tag', 'tag', [CompletionResultType]::ParameterValue, 'Manage bucket and object tags')
            [CompletionResult]::new('anonymous', 'anonymous', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket anonymous`')
            [CompletionResult]::new('quota', 'quota', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket quota`')
            [CompletionResult]::new('ilm', 'ilm', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket lifecycle`')
            [CompletionResult]::new('replicate', 'replicate', [CompletionResultType]::ParameterValue, 'Deprecated: use `rc bucket replication`')
            [CompletionResult]::new('completions', 'completions', [CompletionResultType]::ParameterValue, 'Generate shell completion scripts')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'rc;help;alias' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Add or update an alias')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List all configured aliases')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove an alias')
            break
        }
        'rc;help;alias;set' {
            break
        }
        'rc;help;alias;list' {
            break
        }
        'rc;help;alias;remove' {
            break
        }
        'rc;help;admin' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Display cluster information (servers, disks, usage)')
            [CompletionResult]::new('heal', 'heal', [CompletionResultType]::ParameterValue, 'Manage cluster healing operations')
            [CompletionResult]::new('pool', 'pool', [CompletionResultType]::ParameterValue, 'Manage server pools and expansion status')
            [CompletionResult]::new('expand', 'expand', [CompletionResultType]::ParameterValue, 'Manage post-expansion data rebalancing')
            [CompletionResult]::new('decommission', 'decommission', [CompletionResultType]::ParameterValue, 'Manage server pool decommissioning')
            [CompletionResult]::new('rebalance', 'rebalance', [CompletionResultType]::ParameterValue, 'Manage post-expansion rebalancing')
            [CompletionResult]::new('user', 'user', [CompletionResultType]::ParameterValue, 'Manage IAM users')
            [CompletionResult]::new('policy', 'policy', [CompletionResultType]::ParameterValue, 'Manage IAM policies')
            [CompletionResult]::new('group', 'group', [CompletionResultType]::ParameterValue, 'Manage IAM groups')
            [CompletionResult]::new('service-account', 'service-account', [CompletionResultType]::ParameterValue, 'Manage service accounts')
            [CompletionResult]::new('access-key', 'access-key', [CompletionResultType]::ParameterValue, 'Inspect access key identities')
            [CompletionResult]::new('service', 'service', [CompletionResultType]::ParameterValue, 'Control the server process (restart, stop, freeze, unfreeze)')
            [CompletionResult]::new('replicate', 'replicate', [CompletionResultType]::ParameterValue, 'Manage site replication across clusters')
            break
        }
        'rc;help;admin;info' {
            [CompletionResult]::new('cluster', 'cluster', [CompletionResultType]::ParameterValue, 'Display cluster overview information')
            [CompletionResult]::new('server', 'server', [CompletionResultType]::ParameterValue, 'Display server information')
            [CompletionResult]::new('disk', 'disk', [CompletionResultType]::ParameterValue, 'Display disk information')
            break
        }
        'rc;help;admin;info;cluster' {
            break
        }
        'rc;help;admin;info;server' {
            break
        }
        'rc;help;admin;info;disk' {
            break
        }
        'rc;help;admin;heal' {
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Display current heal status')
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a heal operation')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running heal operation')
            break
        }
        'rc;help;admin;heal;status' {
            break
        }
        'rc;help;admin;heal;start' {
            break
        }
        'rc;help;admin;heal;stop' {
            break
        }
        'rc;help;admin;pool' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List server pools')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show server pool status')
            break
        }
        'rc;help;admin;pool;list' {
            break
        }
        'rc;help;admin;pool;status' {
            break
        }
        'rc;help;admin;expand' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start post-expansion data rebalancing')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show post-expansion rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running post-expansion rebalance')
            break
        }
        'rc;help;admin;expand;start' {
            break
        }
        'rc;help;admin;expand;status' {
            break
        }
        'rc;help;admin;expand;stop' {
            break
        }
        'rc;help;admin;decommission' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start decommissioning a pool')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show decommissioning status')
            [CompletionResult]::new('cancel', 'cancel', [CompletionResultType]::ParameterValue, 'Cancel decommissioning a pool')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear failed or canceled decommissioning metadata for a pool')
            break
        }
        'rc;help;admin;decommission;start' {
            break
        }
        'rc;help;admin;decommission;status' {
            break
        }
        'rc;help;admin;decommission;cancel' {
            break
        }
        'rc;help;admin;decommission;clear' {
            break
        }
        'rc;help;admin;rebalance' {
            [CompletionResult]::new('start', 'start', [CompletionResultType]::ParameterValue, 'Start a rebalance operation')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show rebalance status')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop a running rebalance operation')
            break
        }
        'rc;help;admin;rebalance;start' {
            break
        }
        'rc;help;admin;rebalance;status' {
            break
        }
        'rc;help;admin;rebalance;stop' {
            break
        }
        'rc;help;admin;user' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all users')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new user')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get user information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a user')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a user')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a user')
            break
        }
        'rc;help;admin;user;ls' {
            break
        }
        'rc;help;admin;user;add' {
            break
        }
        'rc;help;admin;user;info' {
            break
        }
        'rc;help;admin;user;rm' {
            break
        }
        'rc;help;admin;user;enable' {
            break
        }
        'rc;help;admin;user;disable' {
            break
        }
        'rc;help;admin;policy' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all policies')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new policy')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get policy information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a policy')
            [CompletionResult]::new('attach', 'attach', [CompletionResultType]::ParameterValue, 'Attach policy to a user or group')
            break
        }
        'rc;help;admin;policy;ls' {
            break
        }
        'rc;help;admin;policy;create' {
            break
        }
        'rc;help;admin;policy;info' {
            break
        }
        'rc;help;admin;policy;rm' {
            break
        }
        'rc;help;admin;policy;attach' {
            break
        }
        'rc;help;admin;group' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List all groups')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Create a new group')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get group information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a group')
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable a group')
            [CompletionResult]::new('disable', 'disable', [CompletionResultType]::ParameterValue, 'Disable a group')
            [CompletionResult]::new('add-members', 'add-members', [CompletionResultType]::ParameterValue, 'Add members to a group')
            [CompletionResult]::new('rm-members', 'rm-members', [CompletionResultType]::ParameterValue, 'Remove members from a group')
            break
        }
        'rc;help;admin;group;ls' {
            break
        }
        'rc;help;admin;group;add' {
            break
        }
        'rc;help;admin;group;info' {
            break
        }
        'rc;help;admin;group;rm' {
            break
        }
        'rc;help;admin;group;enable' {
            break
        }
        'rc;help;admin;group;disable' {
            break
        }
        'rc;help;admin;group;add-members' {
            break
        }
        'rc;help;admin;group;rm-members' {
            break
        }
        'rc;help;admin;service-account' {
            [CompletionResult]::new('ls', 'ls', [CompletionResultType]::ParameterValue, 'List service accounts')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a new service account')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get service account information')
            [CompletionResult]::new('rm', 'rm', [CompletionResultType]::ParameterValue, 'Remove a service account')
            break
        }
        'rc;help;admin;service-account;ls' {
            break
        }
        'rc;help;admin;service-account;create' {
            break
        }
        'rc;help;admin;service-account;info' {
            break
        }
        'rc;help;admin;service-account;rm' {
            break
        }
        'rc;help;admin;access-key' {
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get access key information')
            break
        }
        'rc;help;admin;access-key;info' {
            break
        }
        'rc;help;admin;service' {
            [CompletionResult]::new('restart', 'restart', [CompletionResultType]::ParameterValue, 'Restart the server (graceful shutdown; process manager relaunches)')
            [CompletionResult]::new('stop', 'stop', [CompletionResultType]::ParameterValue, 'Stop the server gracefully')
            [CompletionResult]::new('freeze', 'freeze', [CompletionResultType]::ParameterValue, 'Set the service freeze flag (advisory)')
            [CompletionResult]::new('unfreeze', 'unfreeze', [CompletionResultType]::ParameterValue, 'Clear the service freeze flag')
            break
        }
        'rc;help;admin;service;restart' {
            break
        }
        'rc;help;admin;service;stop' {
            break
        }
        'rc;help;admin;service;freeze' {
            break
        }
        'rc;help;admin;service;unfreeze' {
            break
        }
        'rc;help;admin;replicate' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add sites (given as alias names) to a site replication cluster')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show site replication configuration')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show site replication status')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove sites from the site replication cluster')
            break
        }
        'rc;help;admin;replicate;add' {
            break
        }
        'rc;help;admin;replicate;info' {
            break
        }
        'rc;help;admin;replicate;status' {
            break
        }
        'rc;help;admin;replicate;remove' {
            break
        }
        'rc;help;bucket' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List buckets for an alias, or objects within a bucket path')
            [CompletionResult]::new('create', 'create', [CompletionResultType]::ParameterValue, 'Create a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a bucket')
            [CompletionResult]::new('event', 'event', [CompletionResultType]::ParameterValue, 'Manage bucket notification rules')
            [CompletionResult]::new('cors', 'cors', [CompletionResultType]::ParameterValue, 'Manage bucket CORS rules')
            [CompletionResult]::new('encryption', 'encryption', [CompletionResultType]::ParameterValue, 'Manage bucket default encryption')
            [CompletionResult]::new('version', 'version', [CompletionResultType]::ParameterValue, 'Manage bucket versioning')
            [CompletionResult]::new('quota', 'quota', [CompletionResultType]::ParameterValue, 'Manage bucket quota')
            [CompletionResult]::new('anonymous', 'anonymous', [CompletionResultType]::ParameterValue, 'Manage anonymous bucket access')
            [CompletionResult]::new('lifecycle', 'lifecycle', [CompletionResultType]::ParameterValue, 'Manage bucket lifecycle rules, tiers, and restores')
            [CompletionResult]::new('replication', 'replication', [CompletionResultType]::ParameterValue, 'Manage bucket replication rules and status')
            break
        }
        'rc;help;bucket;list' {
            break
        }
        'rc;help;bucket;create' {
            break
        }
        'rc;help;bucket;remove' {
            break
        }
        'rc;help;bucket;event' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add or replace a bucket notification rule for an ARN')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket notification rules')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket notification rules by target ARN')
            break
        }
        'rc;help;bucket;event;add' {
            break
        }
        'rc;help;bucket;event;list' {
            break
        }
        'rc;help;bucket;event;remove' {
            break
        }
        'rc;help;bucket;cors' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket CORS rules')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Replace bucket CORS rules from a JSON or XML file')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket CORS rules')
            break
        }
        'rc;help;bucket;cors;list' {
            break
        }
        'rc;help;bucket;cors;set' {
            break
        }
        'rc;help;bucket;cors;remove' {
            break
        }
        'rc;help;bucket;encryption' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket default encryption')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket default encryption')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket default encryption')
            break
        }
        'rc;help;bucket;encryption;set' {
            break
        }
        'rc;help;bucket;encryption;info' {
            break
        }
        'rc;help;bucket;encryption;clear' {
            break
        }
        'rc;help;bucket;version' {
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable versioning for a bucket')
            [CompletionResult]::new('suspend', 'suspend', [CompletionResultType]::ParameterValue, 'Suspend versioning for a bucket')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get versioning status for a bucket')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List object versions')
            break
        }
        'rc;help;bucket;version;enable' {
            break
        }
        'rc;help;bucket;version;suspend' {
            break
        }
        'rc;help;bucket;version;info' {
            break
        }
        'rc;help;bucket;version;list' {
            break
        }
        'rc;help;bucket;quota' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket quota')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket quota information')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket quota')
            break
        }
        'rc;help;bucket;quota;set' {
            break
        }
        'rc;help;bucket;quota;info' {
            break
        }
        'rc;help;bucket;quota;clear' {
            break
        }
        'rc;help;bucket;anonymous' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set anonymous access permission')
            [CompletionResult]::new('set-json', 'set-json', [CompletionResultType]::ParameterValue, 'Set anonymous access from a policy JSON file')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get anonymous access permission')
            [CompletionResult]::new('get-json', 'get-json', [CompletionResultType]::ParameterValue, 'Get anonymous policy JSON')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List anonymous policies')
            [CompletionResult]::new('links', 'links', [CompletionResultType]::ParameterValue, 'List public links for anonymous readable prefixes')
            break
        }
        'rc;help;bucket;anonymous;set' {
            break
        }
        'rc;help;bucket;anonymous;set-json' {
            break
        }
        'rc;help;bucket;anonymous;get' {
            break
        }
        'rc;help;bucket;anonymous;get-json' {
            break
        }
        'rc;help;bucket;anonymous;list' {
            break
        }
        'rc;help;bucket;anonymous;links' {
            break
        }
        'rc;help;bucket;lifecycle' {
            [CompletionResult]::new('rule', 'rule', [CompletionResultType]::ParameterValue, 'Manage lifecycle rules on a bucket')
            [CompletionResult]::new('tier', 'tier', [CompletionResultType]::ParameterValue, 'Manage remote storage tiers')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Restore a transitioned (archived) object')
            break
        }
        'rc;help;bucket;lifecycle;rule' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            break
        }
        'rc;help;bucket;lifecycle;rule;add' {
            break
        }
        'rc;help;bucket;lifecycle;rule;edit' {
            break
        }
        'rc;help;bucket;lifecycle;rule;list' {
            break
        }
        'rc;help;bucket;lifecycle;rule;remove' {
            break
        }
        'rc;help;bucket;lifecycle;rule;export' {
            break
        }
        'rc;help;bucket;lifecycle;rule;import' {
            break
        }
        'rc;help;bucket;lifecycle;tier' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            break
        }
        'rc;help;bucket;lifecycle;tier;add' {
            break
        }
        'rc;help;bucket;lifecycle;tier;edit' {
            break
        }
        'rc;help;bucket;lifecycle;tier;list' {
            break
        }
        'rc;help;bucket;lifecycle;tier;info' {
            break
        }
        'rc;help;bucket;lifecycle;tier;remove' {
            break
        }
        'rc;help;bucket;lifecycle;restore' {
            break
        }
        'rc;help;bucket;replication' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new replication rule')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing replication rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List replication rules for a bucket')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show replication status/metrics for a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove replication rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export replication configuration as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import replication configuration from a JSON file')
            break
        }
        'rc;help;bucket;replication;add' {
            break
        }
        'rc;help;bucket;replication;update' {
            break
        }
        'rc;help;bucket;replication;list' {
            break
        }
        'rc;help;bucket;replication;status' {
            break
        }
        'rc;help;bucket;replication;remove' {
            break
        }
        'rc;help;bucket;replication;export' {
            break
        }
        'rc;help;bucket;replication;import' {
            break
        }
        'rc;help;object' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List objects within a bucket path')
            [CompletionResult]::new('copy', 'copy', [CompletionResultType]::ParameterValue, 'Copy objects between local and remote locations')
            [CompletionResult]::new('move', 'move', [CompletionResultType]::ParameterValue, 'Move objects between local and remote locations')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove objects')
            [CompletionResult]::new('stat', 'stat', [CompletionResultType]::ParameterValue, 'Show object metadata')
            [CompletionResult]::new('show', 'show', [CompletionResultType]::ParameterValue, 'Print the full object body')
            [CompletionResult]::new('head', 'head', [CompletionResultType]::ParameterValue, 'Print the first lines or bytes of an object')
            [CompletionResult]::new('find', 'find', [CompletionResultType]::ParameterValue, 'Search for objects by filters')
            [CompletionResult]::new('tree', 'tree', [CompletionResultType]::ParameterValue, 'Display objects in a tree view')
            [CompletionResult]::new('share', 'share', [CompletionResultType]::ParameterValue, 'Generate a presigned object URL')
            break
        }
        'rc;help;object;list' {
            break
        }
        'rc;help;object;copy' {
            break
        }
        'rc;help;object;move' {
            break
        }
        'rc;help;object;remove' {
            break
        }
        'rc;help;object;stat' {
            break
        }
        'rc;help;object;show' {
            break
        }
        'rc;help;object;head' {
            break
        }
        'rc;help;object;find' {
            break
        }
        'rc;help;object;tree' {
            break
        }
        'rc;help;object;share' {
            break
        }
        'rc;help;ls' {
            break
        }
        'rc;help;mb' {
            break
        }
        'rc;help;rb' {
            break
        }
        'rc;help;cat' {
            break
        }
        'rc;help;head' {
            break
        }
        'rc;help;stat' {
            break
        }
        'rc;help;cp' {
            break
        }
        'rc;help;mv' {
            break
        }
        'rc;help;rm' {
            break
        }
        'rc;help;pipe' {
            break
        }
        'rc;help;find' {
            break
        }
        'rc;help;event' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add or replace a bucket notification rule for an ARN')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket notification rules')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket notification rules by target ARN')
            break
        }
        'rc;help;event;add' {
            break
        }
        'rc;help;event;list' {
            break
        }
        'rc;help;event;remove' {
            break
        }
        'rc;help;cors' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List bucket CORS rules')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Replace bucket CORS rules from a JSON or XML file')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove bucket CORS rules')
            break
        }
        'rc;help;cors;list' {
            break
        }
        'rc;help;cors;set' {
            break
        }
        'rc;help;cors;remove' {
            break
        }
        'rc;help;diff' {
            break
        }
        'rc;help;mirror' {
            break
        }
        'rc;help;tree' {
            break
        }
        'rc;help;share' {
            break
        }
        'rc;help;sql' {
            break
        }
        'rc;help;version' {
            [CompletionResult]::new('enable', 'enable', [CompletionResultType]::ParameterValue, 'Enable versioning for a bucket')
            [CompletionResult]::new('suspend', 'suspend', [CompletionResultType]::ParameterValue, 'Suspend versioning for a bucket')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Get versioning status for a bucket')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List object versions')
            break
        }
        'rc;help;version;enable' {
            break
        }
        'rc;help;version;suspend' {
            break
        }
        'rc;help;version;info' {
            break
        }
        'rc;help;version;list' {
            break
        }
        'rc;help;tag' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List tags for a bucket or object')
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set tags for a bucket or object')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove all tags from a bucket or object')
            break
        }
        'rc;help;tag;list' {
            break
        }
        'rc;help;tag;set' {
            break
        }
        'rc;help;tag;remove' {
            break
        }
        'rc;help;anonymous' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set anonymous access permission')
            [CompletionResult]::new('set-json', 'set-json', [CompletionResultType]::ParameterValue, 'Set anonymous access from a policy JSON file')
            [CompletionResult]::new('get', 'get', [CompletionResultType]::ParameterValue, 'Get anonymous access permission')
            [CompletionResult]::new('get-json', 'get-json', [CompletionResultType]::ParameterValue, 'Get anonymous policy JSON')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List anonymous policies')
            [CompletionResult]::new('links', 'links', [CompletionResultType]::ParameterValue, 'List public links for anonymous readable prefixes')
            break
        }
        'rc;help;anonymous;set' {
            break
        }
        'rc;help;anonymous;set-json' {
            break
        }
        'rc;help;anonymous;get' {
            break
        }
        'rc;help;anonymous;get-json' {
            break
        }
        'rc;help;anonymous;list' {
            break
        }
        'rc;help;anonymous;links' {
            break
        }
        'rc;help;quota' {
            [CompletionResult]::new('set', 'set', [CompletionResultType]::ParameterValue, 'Set bucket quota')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show bucket quota information')
            [CompletionResult]::new('clear', 'clear', [CompletionResultType]::ParameterValue, 'Clear bucket quota')
            break
        }
        'rc;help;quota;set' {
            break
        }
        'rc;help;quota;info' {
            break
        }
        'rc;help;quota;clear' {
            break
        }
        'rc;help;ilm' {
            [CompletionResult]::new('rule', 'rule', [CompletionResultType]::ParameterValue, 'Manage lifecycle rules on a bucket')
            [CompletionResult]::new('tier', 'tier', [CompletionResultType]::ParameterValue, 'Manage remote storage tiers')
            [CompletionResult]::new('restore', 'restore', [CompletionResultType]::ParameterValue, 'Restore a transitioned (archived) object')
            break
        }
        'rc;help;ilm;rule' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new lifecycle rule to a bucket')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit an existing lifecycle rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List lifecycle rules on a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove lifecycle rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export lifecycle rules as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import lifecycle rules from a JSON file')
            break
        }
        'rc;help;ilm;rule;add' {
            break
        }
        'rc;help;ilm;rule;edit' {
            break
        }
        'rc;help;ilm;rule;list' {
            break
        }
        'rc;help;ilm;rule;remove' {
            break
        }
        'rc;help;ilm;rule;export' {
            break
        }
        'rc;help;ilm;rule;import' {
            break
        }
        'rc;help;ilm;tier' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new remote storage tier')
            [CompletionResult]::new('edit', 'edit', [CompletionResultType]::ParameterValue, 'Edit tier credentials')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List configured storage tiers')
            [CompletionResult]::new('info', 'info', [CompletionResultType]::ParameterValue, 'Show tier statistics')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove a storage tier')
            break
        }
        'rc;help;ilm;tier;add' {
            break
        }
        'rc;help;ilm;tier;edit' {
            break
        }
        'rc;help;ilm;tier;list' {
            break
        }
        'rc;help;ilm;tier;info' {
            break
        }
        'rc;help;ilm;tier;remove' {
            break
        }
        'rc;help;ilm;restore' {
            break
        }
        'rc;help;replicate' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a new replication rule')
            [CompletionResult]::new('update', 'update', [CompletionResultType]::ParameterValue, 'Update an existing replication rule')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List replication rules for a bucket')
            [CompletionResult]::new('status', 'status', [CompletionResultType]::ParameterValue, 'Show replication status/metrics for a bucket')
            [CompletionResult]::new('remove', 'remove', [CompletionResultType]::ParameterValue, 'Remove replication rules from a bucket')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export replication configuration as JSON')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import replication configuration from a JSON file')
            break
        }
        'rc;help;replicate;add' {
            break
        }
        'rc;help;replicate;update' {
            break
        }
        'rc;help;replicate;list' {
            break
        }
        'rc;help;replicate;status' {
            break
        }
        'rc;help;replicate;remove' {
            break
        }
        'rc;help;replicate;export' {
            break
        }
        'rc;help;replicate;import' {
            break
        }
        'rc;help;completions' {
            break
        }
        'rc;help;help' {
            break
        }
    })

    $completions.Where{ $_.CompletionText -like "$wordToComplete*" } |
        Sort-Object -Property ListItemText
}
